@@ -19,7 +19,7 @@ class GenericImporterV0_2_0 {
      * @param int $logLevel
      * @throws Exception
      */
-    public static function import($jsonString, $logLevel=Log::LOGLEVEL_INFO){
+    public static function import(string $jsonString, int $logLevel=Log::LOGLEVEL_INFO): void {
         if(!Log::isInited()){
             //Caller should have initialized the log. If not, dump it to stdout.
             Log::init($logLevel);
@@ -109,8 +109,16 @@ class GenericImporterV0_2_0 {
 	    $count++;
         }
     }
-    
-    private static function importPlate($plate): void {
+
+	/**
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 * @throws Exception
+	 */
+	private static function importPlate($plate): void {
         Log::write(Log::LOGLEVEL_DEBUG, 'In importPlate');
         static::$currentPlate=null;
         static::$currentPlateOwner=null;
@@ -195,8 +203,14 @@ class GenericImporterV0_2_0 {
         
         Log::write(Log::LOGLEVEL_DEBUG, 'Returning from importPlate');
 	}
-    
-    private static function importPlateType($plateType){
+
+	/**
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 * @throws NotFoundException
+	 */
+	private static function importPlateType($plateType){
         Log::write(Log::LOGLEVEL_DEBUG, 'In importPlateType');
         $name=$plateType['name'];
         $rows=1*$plateType['rows'];
@@ -239,8 +253,14 @@ class GenericImporterV0_2_0 {
         Log::write(Log::LOGLEVEL_DEBUG, 'Returning from importPlateType');
         return $limsPlateType;
     }
-    
-    private static function importUser($user){
+
+	/**
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 * @throws NotFoundException
+	 */
+	private static function importUser($user){
         Log::write(Log::LOGLEVEL_DEBUG, 'In importUser');
         $username=$user['username'];
         $fullName=$user['name'];
@@ -273,8 +293,15 @@ class GenericImporterV0_2_0 {
         Log::write(Log::LOGLEVEL_DEBUG, 'returning from importUser');
         return $limsUser;
     }
-    
-    private static function updateInterestingDrop($drop){
+
+	/**
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 * @throws ForbiddenException
+	 * @throws BadRequestException
+	 * @throws Exception
+	 */
+	private static function updateInterestingDrop(array $drop): void {
         $limsDrop=null;
         $row=$drop['rowNumber'];
         $col=$drop['columnNumber'];
@@ -463,8 +490,14 @@ class GenericImporterV0_2_0 {
             
         }
     }
-    
-    private static function getDummyPlateInspection(){
+
+	/**
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+	private static function getDummyPlateInspection(){
         $limsPlate=static::$currentPlate;
         $barcode=$limsPlate['name'];
         $dummyInspection=imagingsession::getByName($barcode.'_dummy');
@@ -484,8 +517,14 @@ class GenericImporterV0_2_0 {
             }
         return $dummyInspection;
     }
-    
-    private static function importProteinConstruct($proteinConstruct){
+
+	/**
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 * @throws ForbiddenException
+	 * @throws BadRequestException
+	 */
+	private static function importProteinConstruct($proteinConstruct){
         
         /**
          * TODO REWORK
