@@ -138,7 +138,10 @@ try{
 
     //Bail if database dump failed
     if(!empty($output)){
-        throw new Exception($output);
+		foreach ($output as $line) {
+			Log::error($line);
+		}
+        throw new Exception('Database dump failed');
     }
 
     if($dbOnly){
@@ -230,7 +233,10 @@ try{
             $output='';
             exec($cmd,$output);
             if(!empty($output)){
-                throw new Exception($output);
+				foreach ($output as $line){
+					Log::error($line);
+				}
+                throw new Exception('Could not rsync file uploads backup');
             }
         }
         Log::write(Log::LOGLEVEL_DEBUG, '...Done');
