@@ -1,20 +1,20 @@
 <?php class audiorecording extends baseobject {
 
-    protected static $fields=array(
+    protected static array $fields=array(
         'name'=>validator::REQUIRED,
         'userid'=>validator::ANY, //required, but pulled from session
         'parentid'=>array(validator::REQUIRED, validator::INTEGER),
         'datetime'=>array(validator::REQUIRED, validator::DATETIME),
         'audiodata'=>validator::ANY //required, but code will validate
     );
-    protected static $helpTexts=array();
+    protected static array $helpTexts=array();
 
-    protected static $adminSelect='SELECT audiorecording.*, user.fullname AS userfullname FROM audiorecording, user, project 
+    protected static string $adminSelect='SELECT audiorecording.*, user.fullname AS userfullname FROM audiorecording, user, project 
                 WHERE audiorecording.userid=user.id AND audiorecording.projectid=project.id ';
-    protected static $normalSelect='SELECT audiorecording.*, user.fullname AS userfullname FROM audiorecording, user, project 
+    protected static string $normalSelect='SELECT audiorecording.*, user.fullname AS userfullname FROM audiorecording, user, project 
                 WHERE audiorecording.userid=user.id AND audiorecording.projectid=project.id ';
 
-    public static function create(array $request=array()): array {
+    public static function create(array $request=[]): array {
         if(!isset($_FILES['audiodata'])){
             throw new BadRequestException("No audio data file");
         }
@@ -55,25 +55,24 @@
         return $ret;
     }
 
-    /**
-     * @param $projectId
-     * @return bool
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function canCreateRecordingsInProject($projectId){
+	/**
+	 * @param int $projectId
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function canCreateRecordingsInProject(int $projectId): bool {
         if (session::isAdmin() || session::isShipper()){ return true; }
         return in_array($projectId, session::getCreateProjects());
     }
 
-    /**
-     * @param $parentId
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function setProjectIdsToMatchParent($parentId){
+	/**
+	 * @param int $parentId
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function setProjectIdsToMatchParent(int $parentId): void {
         $parent=baseobject::getById($parentId);
         if(!$parent){ throw new ServerException('Attempted to set project IDs on audio recordings for object with ID '.$parentId.' but it does not exist'); }
         $projectId=$parent['projectid'];
