@@ -2,7 +2,7 @@
 
 class databaseauthenticator implements authenticator {
 	
-	static function authenticate($username, $password){
+	static function authenticate(string $username, string $password): bool {
 		$result=database::queryGetOne('SELECT password FROM user WHERE name=:username', array(':username'=>$username));
 		if(!$result){
 			return false;
