@@ -1,21 +1,21 @@
 <?php class basenote extends baseobject {
 
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::ANY, //actually required but is auto generated
 			'text'=>validator::ANY,
 			'userid'=>array(validator::REQUIRED, validator::INTEGER),
 			'parentid'=>array(validator::REQUIRED),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 	);
 
-    /**
-     * @param $parentId
-     * @throws BadRequestException
+	/**
+	 * @param int $parentId
+	 * @throws BadRequestException
 	 * @throws ServerException
-     */
-    public static function setProjectIdsToMatchParent($parentId){
+	 */
+    public static function setProjectIdsToMatchParent(int $parentId): void {
         $parent=baseobject::getById($parentId);
         if(!$parent){ throw new ServerException('Attempted to set project IDs on notes for object with ID '.$parentId.' but it does not exist'); }
         $projectId=$parent['projectid'];
@@ -31,11 +31,11 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getByProperty($key, $value, $request=array()): ?array {
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
         return static::getByProperties( array($key=>$value), $request);
 	}
 
-    public static function getByProperties(array $keyValuePairs, array $request=array()): ?array {
+    public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
         $keys=array_keys(self::getFieldValidations());
         $params=[];
         $sqlStatement='SELECT SQL_CALC_FOUND_ROWS baseobject.createtime AS createtime, user.fullname AS username, note.*
@@ -64,7 +64,7 @@
      * @return array|void
      * @throws BadRequestException
      */
-	public static function getAll(array $request=array()): ?array {
+	public static function getAll(array $request=[]): ?array {
 		throw new BadRequestException('getAll not implemented on note');
 	}
 
@@ -73,7 +73,7 @@
      * @return array|void
      * @throws BadRequestException
      */
-	public static function getByName($name): ?array {
+	public static function getByName(string $name): ?array {
 		throw new BadRequestException('getByName not implemented on note');
 	}
 
@@ -85,7 +85,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
         $request['userid']=session::getUserId();
 	    if(database::$nullValue===$request['parentid']){
 	        if(!isset($request['projectid'])){
