@@ -1,8 +1,8 @@
 <?php class baseobject implements crudable {
 
-	protected static $fields=array();
-	protected static $helpTexts=array();
-	protected static $aliasedColumns=array(); //Returned in $adminSelect/$normalSelect but NOT in called class's columns
+	protected static array $fields=array();
+	protected static array $helpTexts=array();
+	protected static array $aliasedColumns=array(); //Returned in $adminSelect/$normalSelect but NOT in called class's columns
 
 	public static function getFieldValidations(): array {
 		return static::$fields; //static, not self - use the child class's.
@@ -10,11 +10,11 @@
     public static function getFieldHelpTexts(): array {
         return static::$helpTexts; //static, not self - use the child class's.
     }
-    public static function getAliasedColumns(){
+    public static function getAliasedColumns(): array {
         return static::$aliasedColumns; //static, not self - use the child class's.
     }
 
-    public static $defaultSortOrder='name ASC';
+    public static string $defaultSortOrder='name ASC';
 
 	/**
 	 * The terms used where this class is included in a "get by name like" search.
@@ -22,11 +22,11 @@
 	 * to override this so that search is done on a more relevant property.
 	 * @var string
 	 */
-	protected static $searchClause='[[classname]].name';
+	protected static string $searchClause='[[classname]].name';
 	
-	protected static $adminSelect= /** @lang text */
+	protected static string $adminSelect= /** @lang text */
         'SELECT SQL_CALC_FOUND_ROWS [[classname]].*,project.name AS projectname, project.isarchived AS isarchived FROM [[classname]], project WHERE project.id=[[classname]].projectid ';
-	protected static $normalSelect= /** @lang text */
+	protected static string $normalSelect= /** @lang text */
         'SELECT SQL_CALC_FOUND_ROWS [[classname]].*,project.name AS projectname, project.isarchived AS isarchived FROM [[classname]], project WHERE project.id=[[classname]].projectid ';
 
     /**
@@ -51,7 +51,7 @@
      * @throws NotFoundException if the project does not exist or the user cannot read it
      * @throws ServerException
      */
-	protected static function createBaseObject($projectId, $className){
+	protected static function createBaseObject(int $projectId, string $className): int {
 		//$className=get_called_class();
 		if(empty($projectId)){
 			throw new BadRequestException('Project ID not provided.');
@@ -90,7 +90,7 @@
 	 * @throws BadRequestException
 	 * @throws NotFoundException
 	 */
-	public static function getUuid($id, $setIfNull=false) {
+	public static function getUuid(int $id, bool $setIfNull=false): ?string {
 		$className=get_called_class();
 		$obj=static::getById($id);
 		if(!$obj){
@@ -108,7 +108,7 @@
 	 * @throws NotFoundException
 	 * @throws BadRequestException
 	 */
-	public static function setUuid($id, $uuid=null) {
+	public static function setUuid(int $id, $uuid=null): string {
 		$className=get_called_class();
 		$obj=static::getById($id);
 		if(!$obj){
@@ -129,7 +129,7 @@
 		return $uuid;
 	}
 
-	public static function generateUuid() {
+	public static function generateUuid(): string {
 		$timestamp = intval(microtime(true) * 1000);
 
 		return sprintf('%02x%02x%02x%02x-%02x%02x-%04x-%04x-%012x',
@@ -152,7 +152,7 @@
 		);
 	}
 
-	public static function getByUuid($uuid): ?array {
+	public static function getByUuid(string $uuid): ?array {
 		return static::getBy('uuid',$uuid);
 	}
 
@@ -163,7 +163,7 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
 		return static::getBy('id', $id);
 	}
 
@@ -174,11 +174,15 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getByName($name): ?array {
+	public static function getByName(string $name): ?array {
 		return static::getBy('name',$name);
 	}
 
-	private static function getBy($key, $value): ?array {
+	/**
+	 * @throws ServerException
+	 * @throws BadRequestException
+	 */
+	private static function getBy(string $key, string $value): ?array {
 		$className=get_called_class();
 		if(session::isAdmin()){
 			$sqlStatement=static::$adminSelect;
@@ -220,14 +224,14 @@
 		return database::queryGetAll($sqlStatement,$params);
 	}
 
-    /**
-     * @param $searchTerms
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static final function getByNameLikeMultiClass($searchTerms, $request=array()){
+	/**
+	 * @param string $searchTerms
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static final function getByNameLikeMultiClass(string $searchTerms, array $request=[]): ?array {
 		if(!isset($request['classes'])){
 			throw new BadRequestException('Specify classes to search for in querystring, e.g., ?classes=type1,type2,type3');
 		}
@@ -307,20 +311,20 @@
      * @throws BadRequestException
 	 * @throws ServerException
      */
-	public static function getReadConditionsForMultiClassSearch(){
+	public static function getReadConditionsForMultiClassSearch(): string {
 		return static::getProjectClause('read');
 	}
 
-    /**
-     * Returns the records with the specified property.
-     * @param string $key The name of the property
-     * @param string $value The value of the property
-     * @param array $request The request object, used for filtering, limit clause, etc.
-     * @return array
-     * @throws BadRequestException
+	/**
+	 * Returns the records with the specified property.
+	 * @param string $key The name of the property
+	 * @param string $value The value of the property
+	 * @param array $request The request object, used for filtering, limit clause, etc.
+	 * @return array|null
+	 * @throws BadRequestException
 	 * @throws ServerException
-     */
-	public static function getByProperty($key,$value,$request=array()): ?array {
+	 */
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		$className=get_called_class();
 		//verify key in fields array
 		$keys=array_keys(self::getFieldValidations());
@@ -356,7 +360,7 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getByProperties(array $keyValuePairs, array $request=array()): ?array {
+	public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
 		$className=get_called_class();
 		if(session::isAdmin()){
 			$sqlStatement=static::$adminSelect;
@@ -385,14 +389,14 @@
 		return database::queryGetAll($sqlStatement,$params);
 	}
 
-    /**
-     * Returns all records, subject to any limits or filters in the request.
-     * @param array $request The request object, used for filtering, limit clause, etc.
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
+	/**
+	 * Returns all records, subject to any limits or filters in the request.
+	 * @param array $request The request object, used for filtering, limit clause, etc.
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
 	 */
-	public static function getAll(array $request=array()): ?array {
+	public static function getAll(array $request=[]): ?array {
 		$className=get_called_class();
 		//verify key in fields array
 		if(session::isAdmin()){
@@ -410,61 +414,59 @@
 		return database::queryGetAll($sqlStatement,$params);
 	}
 
-    /**
-     * Gets the files associated with the record.
-     * @param int $id The ID of the parent record
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
+	/**
+	 * Gets the files associated with the record.
+	 * @param int $id The ID of the parent record
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
 	 * @throws ServerException
-     */
-	public static function getFiles($id, $request=array()){
+	 */
+	public static function getFiles(int $id, array $request=[]): ?array {
         return file::getByProperty('parentid',$id,$request);
 	}
 
-    /**
-     * Gets the notes associated with the record.
-     * @param int $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getNotes($id, $request=array()){
+	/**
+	 * Gets the notes associated with the record.
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getNotes(int $id, array $request=[]): ?array {
         $request['all']='1';
         $request['sortby']='entered';
         return note::getByProperty('parentid',$id,$request);
     }
 
-    /**
-     * Gets the audio recordings associated with the record.
-     * @param int $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getRecordings($id, $request=array()){
+	/**
+	 * Gets the audio recordings associated with the record.
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getRecordings(int $id, array $request=[]): ?array {
         $request['all']='1';
         $request['sortby']='id';
         $request['sortdescending']='yes';
         return audiorecording::getByProperty('parentid',$id,$request);
     }
 
-    /**
-     * Forces the files, notes, and audio recordings attached to an object to have the same project ID
-     * as that object.
-     * @param $parentParentId
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function updateFileNoteAndRecordingProjectIds($parentParentId){
-        file::setProjectIdsToMatchParent($parentParentId);
-        note::setProjectIdsToMatchParent($parentParentId);
-        audiorecording::setProjectIdsToMatchParent($parentParentId);
+	/**
+	 * Forces the files, notes, and audio recordings attached to an object to have the same project ID
+	 * as that object.
+	 * @param int $parentId
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function updateFileNoteAndRecordingProjectIds(int $parentId): void {
+        file::setProjectIdsToMatchParent($parentId);
+        note::setProjectIdsToMatchParent($parentId);
+        audiorecording::setProjectIdsToMatchParent($parentId);
     }
 
     /**
@@ -476,34 +478,34 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 	    $className=get_called_class();
 	    return baseobject::doCreate($request, $className);
 	}
 
-    /**
-     * @param array $request
-     * @param $className
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function createByClassName($request,$className){
+	/**
+	 * @param array $request
+	 * @param string $className
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function createByClassName(array $request, string $className): array {
 	    return static::doCreate($request, $className);
 	}
 
-    /**
-     * @param $request
-     * @param $className
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	private static function doCreate($request, $className){
+	/**
+	 * @param array $request
+	 * @param string $className
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	private static function doCreate(array $request, string $className): array {
 		if(null==$className){ $className=get_called_class(); }
 		$fields=array();
 		if(!isset($request['projectid'])){
@@ -550,7 +552,6 @@
 		return $ret;
 	}
 
-
     /**
      * Updates one or more fields for a given record. Fields are updated if the field name is found in the fields array of the calling class.
      * @param int $id The ID of the record
@@ -561,7 +562,7 @@
      * @throws ServerException
      * @throws NotFoundException
      */
-	public static function update($id,$request=array()): array {
+	public static function update(int $id,array $request=[]): array {
 		$className=get_called_class();
 		if(isset($request['_classname'])){
 		    $className=$request['_classname'];
@@ -629,7 +630,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function delete($id): array {
+	public static function delete(int $id): array {
 	    $className=get_called_class();
         /** @noinspection PhpUndefinedMethodInspection */
         if(!session::isAdmin() && !$className::canDelete($id)){
@@ -676,22 +677,22 @@
      * @throws BadRequestException
      * @throws ServerException
 	 */
-	public static function canUpdate($id): bool {
+	public static function canUpdate(int $id): bool {
 		$projects=session::getUpdateProjects();
 		$item=static::getById($id);
 		return in_array($item['projectid'], $projects);
 	}
 
 
-    /**
-     * Whether the current user can delete the record with this ID.
-     * This default implementation returns true if the user (a) is an administrator, or (b) has "delete" permissions on the record's project.
-     * @param $id
-     * @return bool
-     * @throws BadRequestException
-     * @throws ServerException
+	/**
+	 * Whether the current user can delete the record with this ID.
+	 * This default implementation returns true if the user (a) is an administrator, or (b) has "delete" permissions on the record's project.
+	 * @param int $id
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws ServerException
 	 */
-	public static function canDelete($id): bool {
+	public static function canDelete(int $id): bool {
 		if(session::isAdmin()){ return true; }
 		if(!config::get('delete_allowed')){ return false; }
 		$projects=session::getDeleteProjects();
@@ -709,7 +710,7 @@
      * @noinspection PhpUnused*@throws BadRequestException if the class or method does not exist
      * @throws BadRequestException
      */
-	public static function callOrThrow($className, $methodName, $args){
+	public static function callOrThrow(string $className, string $methodName, array $args): mixed {
 	    if(!class_exists($className)){
 	        throw new BadRequestException('Class '.$className.' does not exist');
 	    }
@@ -719,7 +720,7 @@
 	    return forward_static_call_array(array($className, $methodName), $args);
 	}
 	
-	public static function canMakeQrCodes(){
+	public static function canMakeQrCodes(): bool {
 	    if(!extension_loaded('gd')){ return false; }
 	    if(PHP_MAJOR_VERSION<7){ return false; }
 	    if(PHP_MAJOR_VERSION==7 && PHP_MINOR_VERSION<2){ return false; }
@@ -738,7 +739,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function makeQrCode($id, $url, $filename, $description){
+	public static function makeQrCode(int $id, string $url, string $filename, string $description): bool|array {
 	    if(!static::canMakeQrCodes()){ return false; }
 	    $saveTo=rtrim(config::get('core_filestore'),'/').'/qr_'.str_replace('.','_',$filename).'_'.str_replace(' ','_',microtime()).'.png';
 
@@ -762,46 +763,49 @@
 
     //Hook functions
 
-    /**
-     * @param $request
-     * @throws ServerException
-     */
-    public static function beforeCreateHook($request, $className=null){
+	/**
+	 * @param array $request
+	 * @param string|null $className
+	 * @throws ServerException
+	 */
+    public static function beforeCreateHook(array $request, string $className=null): void {
         static::doHook('before','create',array(
             'request'=>$request
         ), $className);
     }
 
-    /**
-     * @param $createdObject
-     * @throws ServerException
-     */
-    public static function afterCreateHook($createdObject, $className=null){
+	/**
+	 * @param array $createdObject
+	 * @param null $className
+	 * @throws ServerException
+	 */
+    public static function afterCreateHook(array $createdObject, $className=null): void {
         static::doHook('after','create',array(
             'created'=>$createdObject,
             'id'=>$createdObject['id']
         ), $className);
     }
 
-    /**
-     * @param $id
-     * @param $request
-     * @throws ServerException
-     */
-    public static function beforeUpdateHook($id, $request, $className=null){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @param null $className
+	 * @throws ServerException
+	 */
+    public static function beforeUpdateHook(int $id, array $request, $className=null): void {
         static::doHook('before','update',array(
             'id'=>$id,
             'request'=>$request
         ), $className);
     }
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function afterUpdateHook($id, $className=null){
+	/**
+	 * @param int $id
+	 * @param string|null $className
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function afterUpdateHook(int $id, string $className=null): void {
         $updatedObject=static::getById($id);
         static::doHook('after','update',array(
             'updated'=>$updatedObject,
@@ -810,11 +814,11 @@
     }
 
 	/**
-	 * @param $objectToDelete
-	 * @param null $className
+	 * @param array $objectToDelete
+	 * @param string|null $className
 	 * @throws ServerException
 	 */
-    public static function beforeDeleteHook($objectToDelete, $className=null){
+    public static function beforeDeleteHook(array $objectToDelete, string $className=null): void {
 		if(!$objectToDelete){ return; }
         static::doHook('before','delete',array(
             'toDelete'=>$objectToDelete,
@@ -824,11 +828,11 @@
     }
 
 	/**
-	 * @param $deletedObject
-	 * @param null $className
+	 * @param array $deletedObject
+	 * @param string|null $className
 	 * @throws ServerException
 	 */
-    public static function afterDeleteHook($deletedObject, $className=null){
+    public static function afterDeleteHook(array $deletedObject, string $className=null): void {
 		if(!$deletedObject){ return; }
         static::doHook('after','delete',array(
             'deleted'=>$deletedObject,
@@ -841,10 +845,10 @@
      * @param $when string 'before' or 'after'
      * @param $action string What is being done (create,update,delete)
      * @param $args array The arguments to be made available in the hook file
-     * @param null|string $className
+     * @param string|null $className
      * @throws ServerException
      */
-    private static function doHook($when, $action, $args, $className=null){
+    private static function doHook(string $when, string $action, array $args, string $className=null): void {
         if(null===$className){ $className=get_called_class(); }
         if(!in_array($when,array('before','after'))){
             throw new ServerException('Bad when in doHook: '.$when.' (should be one of before,after)');
