@@ -726,22 +726,22 @@ class DummySession {
 		session_id(DummySession::DUMMYSESSION);
 	}
 
-    /**
-     * @param $name
-     * @return mixed
-     */
-	public function get($name): mixed {
+	/**
+	 * @param string $name
+	 * @return mixed
+	 */
+	public function get(string $name): mixed {
 		if(isset($this->session[$name])){
 			return $this->session[$name];
 		} 
 		return null;
 	}
 
-    /**
-     * @param $name
-     * @param $value
-     */
-	public function set($name, $value): void {
+	/**
+	 * @param string $name
+	 * @param mixed $value
+	 */
+	public function set(string $name, mixed $value): void {
 		$this->session[$name]=$value;
 	}
 
