@@ -235,13 +235,13 @@ class baseusergroup implements crudable {
 	}
 
 	/**
-	 * @param int|array $groupid
+	 * @param int|string|array $groupid
 	 * @param int|null $userid
 	 * @return bool
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function userisingroup(int|array $groupid, int $userid=null): bool {
+	public static function userisingroup(int|string|array $groupid, int $userid=null): bool {
 		if(!$userid){ $userid=session::getUserId(); }
 		if(empty($userid)){ return false; }
 		if(0==(int)$groupid){ $groupid=static::nameToId($groupid); }
@@ -253,13 +253,13 @@ class baseusergroup implements crudable {
 	}
 
 	/**
-	 * @param $groupid
+	 * @param int|string|array $groupid
 	 * @param int|null $userid
 	 * @return bool
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function userisgroupadmin($groupid, int $userid=null): bool {
+	public static function userisgroupadmin(int|string|array $groupid, int $userid=null): bool {
 		if(!$userid){ $userid=session::getUserId(); }
 		if(empty($userid)){ return false; }
 		if(0==(int)$groupid){ $groupid=static::nameToId($groupid); }
@@ -270,12 +270,12 @@ class baseusergroup implements crudable {
 	}
 
 	/**
-	 * @param $name
+	 * @param string $name
 	 * @return int|null
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	private static function nameToId($name): ?int {
+	private static function nameToId(string $name): ?int {
 			if(empty($name)){ return null; }
 			$sqlStatement='SELECT id FROM usergroup WHERE name=:name';
 			$group=database::queryGetOne($sqlStatement, array(':name'=>$name));
@@ -324,7 +324,7 @@ class baseusergroup implements crudable {
      * @throws NotFoundException
 	 * @throws ServerException
      */
-	public static function canUpdate($id): bool {
+	public static function canUpdate(int $id): bool {
 		self::getById($id); //Throws exception if user can't read
 		if(session::isAdmin()){ return true; }
 		return usergroup::userisgroupadmin($id);
@@ -339,7 +339,7 @@ class baseusergroup implements crudable {
 	 * @throws NotFoundException
 	 * @throws ServerException
 	 */
-	public static function getmembers(int $id, array $request=array()): array {
+	public static function getmembers(int $id, array $request=[]): array {
 		$grp=self::getById($id); //Throws exception if user can't read
 		if(!session::isAdmin() /*&& !session::canCreateUsergroups()*/){
 			$isInGroup=self::userisingroup($id);
@@ -380,7 +380,7 @@ class baseusergroup implements crudable {
 	 * @throws NotFoundException
 	 * @throws ServerException
 	 */
-	public static function getnonmembers(int $id, array $request=array()): array {
+	public static function getnonmembers(int $id, array $request=[]): array {
 		if(!session::isAdmin()){
 			$grp=static::getById($id); //Throws exception if user can't read
 			$isInGroup=static::userisingroup($id);
@@ -406,7 +406,7 @@ class baseusergroup implements crudable {
 	 * @throws NotFoundException
 	 * @throws ServerException
 	 */
-	public static function getpermissions(int $id, array $request=array()): array {
+	public static function getpermissions(int $id, array $request=[]): array {
 		$sqlStatement='SELECT id,name,isarchived, owner, "project" AS objecttype FROM project WHERE 1=1 ';
 //		if(!session::isAdmin()){
 			self::getById($id); //Throws exception if the current user can't read
