@@ -8,9 +8,9 @@
 
 class caching {
 
-    private static $datetimeformat = 'Y-m-d H:i:s';
+    private static string $datetimeformat = 'Y-m-d H:i:s';
 
-    public static function setContent($file, $content, $expires){
+    public static function setContent(string $file, mixed $content, string $expires): void {
     
         //expires: string + 1 day or DateTime
         if(gettype($expires)=='string'){
@@ -27,7 +27,7 @@ class caching {
     }
 
     
-    private static function getFile($file){
+    private static function getFile(string $file): ?string {
         if(!preg_match('/^[A-Za-z0-9_-]+$/', $file)){
             die('Possible directory traversal attempt found in caching::getFile');
         }
@@ -39,14 +39,14 @@ class caching {
     }
 
     
-    public static function getContent($file, $full=false){
+    public static function getContent(string $file, bool $full=false): string|array {
         $content=file_get_contents(self::getFile($file));
         $content=json_decode($content, true);
         return $full?$content:$content['content'];
     }
 
 
-    public static function has($file){
+    public static function has(string $file): bool {
         $path=self::getFile($file);
         if(null===$path || !file_exists($path)){
             return false;
