@@ -35,12 +35,11 @@ class config {
 		return session::isAdmin();
 	}
 
-    /**
-     * @param $id
-     * @return bool
-     * @noinspection PhpUnusedParameterInspection
-     */
-    public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 */
+    public static function canUpdate(int $id): bool {
 		return session::isAdmin();
 	}
 
@@ -48,21 +47,21 @@ class config {
 	 * @throws ServerException
 	 * @throws BadRequestException
 	 */
-	static function get($name): ?string {
+	static function get(string $name): ?string {
 		$result=database::queryGetOne('SELECT value FROM config WHERE name=:name', array(':name'=>$name));
 		if(!$result){ return null; }
 		return trim($result['value']);
 	}
 
 	/**
-	 * @param $name
-	 * @param $value
+	 * @param string $name
+	 * @param string $value
 	 * @return bool
 	 * @throws BadRequestException
 	 * @throws ForbiddenException
 	 * @throws ServerException
 	 */
-	public static function set($name, $value): bool {
+	public static function set(string $name, string $value): bool {
 		if(!session::isAdmin()){ throw new ForbiddenException('Only administrators can see or change the configuration'); }
 		$item=database::queryGetOne('SELECT * FROM config WHERE name=:name', array(':name'=>$name));
 		if(!$item){ throw new BadRequestException('No config item called '.$name); }
@@ -82,50 +81,47 @@ class config {
 	 * @throws BadRequestException
      * @noinspection PhpUnusedParameterInspection
      */
-	public static function getAll(array $request=array()): ?array{
+	public static function getAll(array $request=[]): ?array{
 		if(!session::isAdmin()){ throw new ForbiddenException('Only administrators can see the configuration'); }
 		$result=database::queryGetAll('SELECT * FROM config ORDER BY name ');
 		if(!$result){ return null; }
 		return $result;
 	}
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	static function getById($id){
+	/**
+	 * @param int $id
+	 * @throws BadRequestException
+	 */
+	static function getById(int $id): ?array {
 		throw new BadRequestException('getById not implemented on config');
 	}
 
-    /**
-     * @param $name
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	static function getByName($name){
+	/**
+	 * @param string $name
+	 * @throws BadRequestException
+	 */
+	static function getByName(string $name): ?array {
 		throw new BadRequestException('getByName not implemented on config');
 	}
 
 	/**
-	 * @param $key
-	 * @param $value
+	 * @param string $key
+	 * @param string $value
 	 * @param array $request
 	 * @throws BadRequestException
 	 * @noinspection PhpUnusedParameterInspection
 	 */
-	static function getByProperty($key,$value,$request=array()){
+	static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		throw new BadRequestException('getByProperty not implemented on config');
 	}
 
 	/**
-	 * @param $key
-	 * @param $value
+	 * @param $keyValuePairs
 	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
-	 * @noinspection PhpUnusedParameterInspection
 	 */
-	static function getByProperties($keyValuePairs,$request=array()){
+	static function getByProperties($keyValuePairs, array $request=array()): ?array {
 		throw new BadRequestException('getByProperties not implemented on config');
 	}
 
@@ -209,27 +205,14 @@ class config {
 	 * @throws ServerException
 	 */
 	public static function getDatabaseVersion(): string {
-		$databaseVersion=config::get('core_icebearversion');
-		if(empty($databaseVersion)){
-			if(Log::isInited()){
-				Log::write(Log::LOGLEVEL_WARN,'Database version not set. Assuming and setting 1.0');
-			}
-			database::query(
-				"INSERT INTO config(name,description,type,defaultvalue,value) 
-                    VALUES('core_icebearversion','IceBear database version number','text','','1.0')"
-			);
-			$databaseVersion='1.0';
-		}
-		return trim($databaseVersion);
+		return updater::getDatabaseVersion();
 	}
 
+	/**
+	 * @throws ServerException
+	 */
 	public static function getCodeVersion(): string {
-		$fileName=__DIR__.'/../../conf/codeversion';
-		if(!file_exists($fileName)){
-			throw new ServerException('IceBear directory does not contain file conf/codeversion.');
-		}
-		$contents=@file_get_contents($fileName);
-		return trim($contents);
+		return updater::getCodeVersion();
 	}
 
 }
\ No newline at end of file
