@@ -10,35 +10,37 @@
 class corsproxy {
 
 
-    /**
-     *
-     * @param array $request
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-    public static function create($request=array()){
+	/**
+	 *
+	 * @param array $request
+	 * @return string|bool
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+    public static function create(array $request=[]): string|bool {
 		if(!isset($request['url'])){ throw new BadRequestException('IceBear corsproxy: request has no url parameter'); }
         $url=$request['url'].'';
         unset($request['url']);
         if('put'==strtolower($_SERVER['REQUEST_METHOD'])){
-            static::doPut($url, $request, true);
+            return static::doPut($url, $request, true);
         } else {
-            static::doPost($url, $request, true);
+            return static::doPost($url, $request, true);
         }
     }
 
-    /**
-     * @param array $request
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-    public static function getAll($request=array()){
+	/**
+	 * @param array $request
+	 * @return string|bool
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+    public static function getAll(array $request=[]): string|bool {
 		if(!isset($request['url'])){ throw new BadRequestException('IceBear corsproxy: request has no url parameter'); }
         $url=$request['url'].'';
         unset($request['url']);
-        static::doGet($url, $request, true);
+        return static::doGet($url, $request, true);
     }
 
     /**
@@ -50,7 +52,7 @@ class corsproxy {
      * @throws ForbiddenException
      * @throws ServerException
      */
-    public static function doGet($url, $request, $echoAndExit=false){
+    public static function doGet($url, $request, bool $echoAndExit=false): bool|string {
         return static::doRequest($url, $request, 'get', $echoAndExit);
     }
 
@@ -63,7 +65,7 @@ class corsproxy {
      * @throws ForbiddenException
      * @throws ServerException
      */
-    public static function doPost($url, $request, $echoAndExit=false){
+    public static function doPost($url, $request, bool $echoAndExit=false): bool|string {
         return static::doRequest($url, $request, 'post', $echoAndExit);
     }
 
@@ -76,21 +78,21 @@ class corsproxy {
      * @throws ForbiddenException
      * @throws ServerException
      */
-    public static function doPut($url, $request, $echoAndExit=false){
+    public static function doPut($url, $request, bool $echoAndExit=false): bool|string {
         return static::doRequest($url, $request, 'put', $echoAndExit);
     }
 
-    /**
-     * @param $url
-     * @param $request
-     * @param $method
-     * @param bool $echoAndExit If true, echoes the response and exits. Otherwise, returns it.
-     * @return bool|string
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-    private static function doRequest($url, $request, $method, $echoAndExit){
+	/**
+	 * @param string $url
+	 * @param array $request
+	 * @param string $method
+	 * @param bool $echoAndExit If true, echoes the response and exits. Otherwise, returns it.
+	 * @return bool|string
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+    private static function doRequest(string $url, array $request, string $method, bool $echoAndExit): bool|string {
         if(!function_exists('curl_init')){
             throw new ServerException('Cannot communicate directly with remote server because their configuration does not allow it. Cannot use IceBear to relay messages. Your IceBear administrator needs to fix this: PHP cURL extension not installed.');
         }
@@ -104,7 +106,7 @@ class corsproxy {
         
         //what we got from the client - cache on first sight, cURL may redirect to itself and eat them.
         //NB function_exists('apache_request_headers') is FALSE if running unit tests
-        if(!static::$apacheRequestHeaders && function_exists('apache_request_headers')){
+        if(!isset(static::$apacheRequestHeaders) && function_exists('apache_request_headers')){
             static::$apacheRequestHeaders=apache_request_headers();
         } else {
             static::$apacheRequestHeaders=array();
@@ -202,8 +204,14 @@ class corsproxy {
         }
     }
 
-    private static function curlResponseHeaderCallback($curlHandle, $headerLine){
-        if(null===static::$responseCookies){
+	/**
+	 * @param mixed $curlHandle
+	 * @param string $headerLine
+	 * @return int
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	private static function curlResponseHeaderCallback(mixed $curlHandle, string $headerLine): int {
+        if(!isset(static::$responseCookies)){
             static::$responseCookies=array();
         }
         if (preg_match('/^Set-Cookie:\s*([^;]*)/mi', $headerLine) == 1){
@@ -211,10 +219,10 @@ class corsproxy {
         }
         return strlen($headerLine); // Needed by curl
     }
-    private static $responseCookies;
+    private static array $responseCookies;
 
-    private static $responseHeaders;
+    private static array $responseHeaders;
 
-    private static $apacheRequestHeaders;
+    private static array $apacheRequestHeaders;
 
  }
\ No newline at end of file
