@@ -2,10 +2,10 @@
 
 class database {
 
-	static $connection;
+	static PDO $connection;
 
 	static string $nullValue='NULL';
-	static $lastAffectedRowCount;
+	static int $lastAffectedRowCount;
 	/**
 	 * Connect to the database using credentials supplied in the config file.
 	 */
@@ -59,15 +59,15 @@ class database {
 		return (int)self::$lastAffectedRowCount;
 	}
 
-    /**
-     * @param $sqlStatement
-     * @param $parameters
-     * @param $returnType
-     * @return array|int|null
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    private static function doQuery($sqlStatement, $parameters, $returnType): mixed {
+	/**
+	 * @param string $sqlStatement
+	 * @param array $parameters
+	 * @param string|null $returnType
+	 * @return array|int|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    private static function doQuery(string $sqlStatement, array $parameters, string $returnType=null): mixed {
 	    try {
 	        //Original - cant handle null
 	        foreach($parameters as $k=>$v){
@@ -120,7 +120,7 @@ class database {
      * @throws BadRequestException
      * @throws ServerException
      */
-	public static function query(string $sqlStatement, array $parameters=array()): mixed {
+	public static function query(string $sqlStatement, array $parameters=[]): mixed {
 		return self::doQuery($sqlStatement, $parameters, null);
 	}
 
@@ -132,21 +132,21 @@ class database {
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function queryGetOne($sqlStatement, $parameters=array()): ?array {
+	public static function queryGetOne(string $sqlStatement, array $parameters=[]): ?array {
 		return self::doQuery($sqlStatement, $parameters, 'one');
 	}
 
-    /**
-     * Prepares and executes a PDO statement using the supplied SQL and parameters, and returns an array containing two keys: "total" and "rows".
-     * "total" is the number of rows that would have been matched, ignoring any LIMIT clause.
-     * "rows" contains the actual data, one item per result row, as key-value pairs.
-     * @param string $sqlStatement The SQL statement, with placeholders
-     * @param array $parameters The array of placeholders and values
-     * @return array The results, along with the total rows matched
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function queryGetAll($sqlStatement, $parameters=array()): ?array {
+	/**
+	 * Prepares and executes a PDO statement using the supplied SQL and parameters, and returns an array containing two keys: "total" and "rows".
+	 * "total" is the number of rows that would have been matched, ignoring any LIMIT clause.
+	 * "rows" contains the actual data, one item per result row, as key-value pairs.
+	 * @param string $sqlStatement The SQL statement, with placeholders
+	 * @param array $parameters The array of placeholders and values
+	 * @return array|null The results, along with the total rows matched
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function queryGetAll(string $sqlStatement, array $parameters=[]): ?array {
 		$result=self::doQuery($sqlStatement, $parameters, 'all');
 		if(!$result){ return null; }
 		$total=self::getFoundRows();
@@ -159,7 +159,7 @@ class database {
     /**
      * @return mixed
      */
-	public static function getLastInsertId(){
+	public static function getLastInsertId(): mixed {
 		return self::$connection->lastInsertId();
 	}
 
@@ -170,7 +170,7 @@ class database {
      * @throws BadRequestException
      * @throws ServerException
      */
-	private static function handlePDOException($e, $sqlStatement, $parameters){
+	private static function handlePDOException(Exception $e, string $sqlStatement, array $parameters){
 		$message=$e->getMessage();
 		database::abort();
 		if(str_contains($message, 'constraint violation')){
@@ -188,13 +188,13 @@ class database {
 		}
 	}
 
-    /**
-     * Returns a LIMIT clause for pagination, using $request['pagenumber'] and $request['pagesize'].
+	/**
+	 * Returns a LIMIT clause for pagination, using $request['pagenumber'] and $request['pagesize'].
 	 * If either is missing, or if $request['all'] is present, returns an empty string.
-     * @param $requestParameters
-     * @return string the Limit clause if both parameters found, or an empty string
-     */
-	public static function getLimitClause($requestParameters): string {
+	 * @param array $requestParameters
+	 * @return string the Limit clause if both parameters found, or an empty string
+	 */
+	public static function getLimitClause(array $requestParameters=[]): string {
 		if(isset($requestParameters["all"])){ return ''; }
 		if(!isset($requestParameters['pagenumber']) && !isset($requestParameters['pagesize'])){
 			$requestParameters['pagenumber']=1;
@@ -209,13 +209,13 @@ class database {
 		return '';
 	}
 
-    /**
-     * @param $requestParameters
-     * @param string $className
-     * @return string
-     * @throws BadRequestException
-     */
-	public static function getOrderClause($requestParameters, string $className=''): string {
+	/**
+	 * @param array $requestParameters
+	 * @param string $className
+	 * @return string
+	 * @throws BadRequestException
+	 */
+	public static function getOrderClause(array $requestParameters, string $className=''): string {
 		$sortOrder='ASC';
 		if(''!=$className && !preg_match('/^[a-z0-9_]+$/',$className)){
 			throw new BadRequestException('Class name not recognised');
@@ -340,17 +340,17 @@ class database {
 		}
 	}
 
-    /**
-     * Adds the column to the table, if it doesn't exist, otherwise alters it to the supplied definition.
-     * @param $table
-     * @param $column
-     * @param $definition
-     * @param string $comment
-     * @return boolean true if created, false if already existed
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function addOrAlterColumn($table, $column, $definition, string $comment=''): bool {
+	/**
+	 * Adds the column to the table, if it doesn't exist, otherwise alters it to the supplied definition.
+	 * @param string $table
+	 * @param string $column
+	 * @param string $definition
+	 * @param string $comment
+	 * @return boolean true if created, false if already existed
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function addOrAlterColumn(string $table, string $column, string $definition, string $comment=''): bool {
 	    if(!Log::isInited()){
 	        throw new ServerException('Log must be init()ed before calling database::addOrAlterColumn');
 	    }
