@@ -4,12 +4,12 @@
     const FILESYSTEM_CACHE_FORMULATRIX = 'filesystem_formulatrix';
     const FILESYSTEM_CACHE_RIGAKU = 'filesystem_rigaku';
 
-    /**
-     * @param array $request
-     * @return array
-     * @throws ServerException
-     */
-    public static function getAll(array $request = array()): ?array {
+	/**
+	 * @param array $request
+	 * @return array|null
+	 * @throws ServerException
+	 */
+    public static function getAll(array $request=[]): ?array {
         if (strtoupper(substr(PHP_OS, 0, 3)) !== 'LIN') {
             throw new ServerException('Disk usage information is not available because the server is not running Linux.');
         }
@@ -42,27 +42,30 @@
      */
     public static function getFieldHelpTexts(): array { throw new BadRequestException('Not implemented'); }
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-    public static function getById($id): ?array { throw new BadRequestException('Not implemented'); }
+	/**
+	 * @param int $id
+	 * @return array|null
+	 * @throws BadRequestException
+	 */
+    public static function getById(int $id): ?array { throw new BadRequestException('Not implemented'); }
 
-    /**
-     * @param $name
-     * @throws BadRequestException
-     */
-    public static function getByName($name): ?array {
+	/**
+	 * @param string $name
+	 * @return array|null
+	 * @throws BadRequestException
+	 */
+    public static function getByName(string $name): ?array {
         throw new BadRequestException('Not implemented');
     }
 
 	/**
-	 * @param $key
-	 * @param $value
+	 * @param string $key
+	 * @param string $value
 	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
 	 */
-	public static function getByProperty($key, $value, $request = array()): ?array {
+	public static function getByProperty(string $key, string $value, array $request = []): ?array {
 		throw new BadRequestException('Not implemented');
 	}
 
@@ -72,7 +75,7 @@
 	 * @return array|null
 	 * @throws BadRequestException
 	 */
-	public static function getByProperties(array $keyValuePairs, array $request = array()): ?array {
+	public static function getByProperties(array $keyValuePairs, array $request = []): ?array {
 		throw new BadRequestException('Not implemented');
 	}
 
@@ -80,24 +83,26 @@
      * @param array $request
      * @throws BadRequestException
      */
-    public static function create($request = array()): array {
+    public static function create(array $request=[]): array {
         throw new BadRequestException('Not implemented');
     }
 
-    /**
-     * @param $id
-     * @param array $request
-     * @throws BadRequestException
-     */
-    public static function update($id, $request = array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 */
+    public static function update(int $id, array $request=[]): array {
         throw new BadRequestException('Not implemented');
     }
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-    public static function delete($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 */
+    public static function delete(int $id): array {
         throw new BadRequestException('Not implemented');
     }
 
@@ -108,11 +113,12 @@
         throw new BadRequestException('Not implemented');
     }
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-    public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 * @throws BadRequestException
+	 */
+    public static function canUpdate(int $id): bool {
         throw new BadRequestException('Not implemented');
     }
 
