@@ -1,8 +1,9 @@
-<?php 
+<?php /** @noinspection PhpUnused */
+
 class AccessException extends Exception {
 
     /** @noinspection PhpUnused */
-    function __construct($message){
+    function __construct(string $message){
         parent::__construct($message);
 		$this->message=$message;
 		$this->code=403;
