@@ -1,7 +1,7 @@
 <?php 
 class ServerException extends Exception {
 
-	function __construct($message){
+	function __construct(string $message){
 	    parent::__construct($message);
 		$this->message=$message;
 		$this->code=500;
