@@ -1,6 +1,6 @@
 <?php class file extends baseobject {
 
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::ANY,
 			'filename'=>validator::ANY,
 			'mimetype'=>validator::ANY,
@@ -9,19 +9,18 @@
 			'parentid'=>array(validator::REQUIRED, validator::INTEGER),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 	);
 
-	protected static $adminSelect= 'SELECT file.*, baseobject.createtime AS uploaddatetime FROM baseobject,file,project WHERE project.id=file.projectid AND file.id=baseobject.id';
-	protected static $normalSelect='SELECT file.*, baseobject.createtime AS uploaddatetime FROM baseobject,file,project WHERE project.id=file.projectid AND file.id=baseobject.id';
+	protected static string $adminSelect= 'SELECT file.*, baseobject.createtime AS uploaddatetime FROM baseobject,file,project WHERE project.id=file.projectid AND file.id=baseobject.id';
+	protected static string $normalSelect='SELECT file.*, baseobject.createtime AS uploaddatetime FROM baseobject,file,project WHERE project.id=file.projectid AND file.id=baseobject.id';
 
-    /**
-     * @param $parentId
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function setProjectIdsToMatchParent($parentId){
+	/**
+	 * @param int $parentId
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function setProjectIdsToMatchParent(int $parentId): void {
 	    $parent=baseobject::getById($parentId);
         if(!$parent){ throw new ServerException('Attempted to set project IDs on files for object with ID '.$parentId.' but it does not exist'); }
         $projectId=$parent['projectid'];
@@ -36,7 +35,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
 		$file=parent::getById($id);
 		$path=static::getPathToFile($file);
 		if(!$file || !file_exists($path)){
@@ -49,13 +48,13 @@
 		exit;
 	}
 
-    /**
-     * Required for interface compatibility but no implementation. Throws a BadRequestException.
-     * @param $name
-     * @return array|void
-     * @throws BadRequestException
-     */
-	public static function getByName($name): ?array {
+	/**
+	 * Required for interface compatibility but no implementation. Throws a BadRequestException.
+	 * @param string $name
+	 * @return array|void
+	 * @throws BadRequestException
+	 */
+	public static function getByName(string $name): ?array {
 		throw new BadRequestException('getByName not implemented in file class');		
 	}
 
@@ -67,7 +66,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 	    if(empty($_FILES) || empty($_FILES['file'])){
 	        throw new BadRequestException('file::create called but no file was supplied');
 	    }
@@ -123,7 +122,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function createFromTempFile($request=array()){
+	public static function createFromTempFile(array $request=[]): array {
 	    $request['name']='file'.microtime();
 	    if(!$request['tempfile']){
 	        throw new BadRequestException('file::createFromTempFile called but no file was supplied');
@@ -157,7 +156,7 @@
 	    return array("created"=>parent::getById($record['id']) );
 	}
 
-	public static function delete($id): array {
+	public static function delete(int $id): array {
 	    $file=parent::getById($id);
         if(!$file){ throw new BadRequestException('No file with ID '.$id.', cannot delete'); }
 	    if(!isset($file['mimetype'])){
@@ -174,10 +173,10 @@
 	    return array('deleted'=>$id);
     }
 	
-	private static function getFileParentDirectory($fileRecord){
+	private static function getFileParentDirectory(array $fileRecord): string {
 		return rtrim(config::get('core_filestore'),'/').'/files/project'.$fileRecord['projectid'];
 	}
-	public static function getPathToFile($fileRecord){
+	public static function getPathToFile(array $fileRecord): string {
 		return static::getFileParentDirectory($fileRecord).'/file'.$fileRecord['id'];
 	}
 
@@ -195,7 +194,7 @@
      * @throws BadRequestException if the file is not a valid PNG
      * @see http://www.libpng.org/pub/png/spec/1.2/PNG-Chunks.html#C.tEXt for the PNG specification
      */
-	public static function getPngPixelsPerUnit($filePath){
+	public static function getPngPixelsPerUnit(string $filePath): ?array {
 
 	    if(!file_exists($filePath)){
 	        throw new ServerException('Tried to parse PNG headers but file does not exist');
