@@ -1,22 +1,22 @@
 <?php 
 class groupmembership implements crudable {
 
-	private static $fields=array(
+	private static array $fields=array(
 		'userid'=>validator::INTEGER,
 		'usergroupid'=>validator::INTEGER,
 		'isgroupadmin'=>validator::BOOLEAN
 	);
 
-	public static $helpTexts=array(
+	public static array $helpTexts=array(
 			'userid'=>'The ID of the user who is in the group',
 			'usergroupid'=>'The id of the group the user belongs to',
 			'isgroupadmin'=>'Whether the user can administer the group'
 	);
 	
-	private static $adminSelect='';
-	private static $normalSelect='';
+	private static string $adminSelect='';
+	private static string $normalSelect='';
 
-	private static function getSelectClause(){
+	private static function getSelectClause(): string {
 		if(session::isAdmin()){
 			return self::$adminSelect;
 		}
@@ -37,9 +37,11 @@ class groupmembership implements crudable {
 		throw new ServerException('getFieldHelpTexts not implemented on groupmembership');
 	}
 
-    /**
-     * @return bool
-     */
+	/**
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
 	public static function canCreate(): bool {
 		if(session::isAdmin()){ return true; }
 		$sqlStatement='SELECT * FROM groupmembership WHERE userid=:userid AND isgroupadmin=1';
@@ -49,38 +51,38 @@ class groupmembership implements crudable {
 
 
 	/**
-	 * @param $id
+	 * @param int $id
 	 * @return array|null
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
 		//TODO ACCESS CONTROLS ON THIS
 		return database::queryGetOne('SELECT * FROM groupmembership WHERE id=:id', array(':id'=>$id));
 	}
 
-    /**
-     * @param $name
-     * @throws BadRequestException
-     */
-	public static function getByName($name): ?array {
+	/**
+	 * @param string $name
+	 * @return array|null
+	 * @throws BadRequestException
+	 */
+	public static function getByName(string $name): ?array {
 		throw new BadRequestException ('GetByName not implemented on groupmembership');
 	}
 
-    /**
-     * @param $key
-     * @param $value
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function getByProperty($key,$value,$request=array()): ?array {
+	/**
+	 * @param string $key
+	 * @param string $value
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		$className=get_called_class();
 		//verify key in fields array
 		$keys=array_keys(self::$fields);
-		if(!in_array($keys, $key)){
+		if(!in_array($key, $keys)){
 			throw new BadRequestException('Property '.$key.' not recognised on '.$className);
 		}
 		$sqlStatement=self::getSelectClause().' AND '.$key.'=?:val';
@@ -103,18 +105,19 @@ class groupmembership implements crudable {
      * @param array $request
      * @throws ServerException
      */
-	public static function getAll($request=array()): ?array {
+	public static function getAll(array $request=[]): ?array {
 		throw new ServerException('getAll not implemented on groupmembership');
 	}
 
-    /**
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     */
-	public static function create($request=array()): array {
+	/**
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function create(array $request=[]): array {
 		if(!isset($request['userid'])|| !isset($request['usergroupid'])){
 			throw new BadRequestException('Both userid and usergroupid are required');
 		}
@@ -135,15 +138,16 @@ class groupmembership implements crudable {
 		return array('type'=>'groupmembership', 'created'=>static::getById($createdId));
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     */
-	public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=array()): array {
 		$membership=self::getById($id);
 		$group=usergroup::getById($membership['usergroupid']);
 		static::checkCanManageMembership($group['id']);
@@ -157,13 +161,15 @@ class groupmembership implements crudable {
 		return array('updated'=>static::getById($id));
 	}
 
-    /**
-     * @param $id
-     * @return array
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     */
-	public static function delete($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function delete(int $id): array {
 		$membership=self::getById($id);
 		$group=usergroup::getById($membership['usergroupid']);
 		static::checkCanManageMembership($group['id']);
@@ -175,29 +181,31 @@ class groupmembership implements crudable {
 		return array('deleted'=>$id);
 	}
 
-    /**
-     * @param $id
-     * @return bool
-     */
-	public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 */
+	public static function canUpdate(int $id): bool {
 		return static::canManageMembership($id);
 	}
 
-    /**
-     * @param $groupid
-     * @throws ForbiddenException
-     */
-	private static function checkCanManageMembership($groupid){
-		if(!static::canManageMembership($groupid)){
+	/**
+	 * @param int $groupId
+	 * @throws ForbiddenException
+	 */
+	private static function checkCanManageMembership(int $groupId): void {
+		if(!static::canManageMembership($groupId)){
 			throw new ForbiddenException('You do not have permission to do that');
 		}
 	}
 
-    /**
-     * @param $groupid
-     * @return bool
-     */
-	private static function canManageMembership($groupid){
+	/**
+	 * @param int $groupid
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	private static function canManageMembership(int $groupid): bool {
 		if(session::isAdmin() || session::canCreateUsergroups()){ return true; }
 		$sqlStatement='SELECT * FROM groupmembership WHERE userid=:userid AND usergroupid=:groupid AND isgroupadmin=1';
 		$result=database::queryGetOne($sqlStatement, array(':userid'=>session::getUserId(), ':groupid'=>$groupid));
