@@ -7,77 +7,76 @@
 
 class homepagebrick {
 	
-	private static $adminSelect='SELECT SQL_CALC_FOUND_ROWS id,name,height,width FROM homepagebrick WHERE 1=1 ';
-	private static $normalSelect='SELECT SQL_CALC_FOUND_ROWS id,name,height,width FROM homepagebrick WHERE adminonly=false ';
-	private static function getSelect(){
+	private static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS id,name,height,width FROM homepagebrick WHERE 1=1 ';
+	private static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS id,name,height,width FROM homepagebrick WHERE adminonly=false ';
+	private static function getSelect(): string {
 		if(session::isAdmin()){ return static::$adminSelect; }
 		return static::$normalSelect;
 	}
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function getById($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getById(int $id): array {
 		$sqlStatement=static::getSelect().' AND id=:id';
 		$parameters=array(':id'=>$id);
         return database::queryGetOne($sqlStatement, $parameters);
 	}
 
 	/**
-	 * @param $name
+	 * @param string $name
 	 * @return array|null
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getByName($name): ?array {
+	public static function getByName(string $name): ?array {
 	    $sqlStatement=static::getSelect().' AND name=:name';
 	    $parameters=array(':name'=>$name);
         return database::queryGetOne($sqlStatement, $parameters);
 	}
 
 	/**
-	 * @param $name
-	 * @param $value
+	 * @param string $key
+	 * @param string $value
 	 * @param array $request
 	 * @throws BadRequestException
-	 * @noinspection PhpUnusedParameterInspection
 	 */
-	public static function getByProperty($name,$value,$request=array()){
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		throw new BadRequestException('getByProperty not implemented on homepagebrick');
 	}
 
 	/**
-	 * @param $keyValuePairs
+	 * @param array $keyValuePairs
 	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
 	 */
-	public static function getByProperties($keyValuePairs,$request=array()){
+	public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
 		throw new BadRequestException('getByProperties not implemented on homepagebrick');
 	}
 
-    /**
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function getAll($request=array()){
+	/**
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getAll(array $request=[]): ?array {
 		$sqlStatement=static::getSelect();
 		$parameters=array();
         return database::queryGetAll($sqlStatement, $parameters);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function update($id,$request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function update(int $id, array $request=[]): array {
 		throw new BadRequestException('homepagebrick::update not implemented');
 	}
 
@@ -89,7 +88,7 @@ class homepagebrick {
      * @throws BadRequestException
      * @throws ServerException
      */
-    public static function parseBrickFiles(){
+    public static function parseBrickFiles(): void {
         if(!Log::isInited()){
             throw new ServerException('homepageBrick::parseBrickFiles - log not init()ed');
         }
@@ -187,11 +186,12 @@ class homepagebrick {
         homepagebrick::purgeCachedHomepageBricksJavascript();
     }
 
-    /**
-     * @return string
-     * @throws ServerException
-     */
-    public static function getCachedHomepageBricksJavascriptPath(){
+	/**
+	 * @return string
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getCachedHomepageBricksJavascriptPath(): string {
         $path=rtrim(config::get('core_filestore'),'/').'/cache';
         if(!file_exists($path) &&!@mkdir($path, 0777, true)){
             throw new ServerException('Could not create cache location for homepage bricks: '.$path);
@@ -199,11 +199,12 @@ class homepagebrick {
         return $path.'/homepagebricks.js';
     }
 
-    /**
-     * @return bool
-     * @throws ServerException
-     */
-    public static function purgeCachedHomepageBricksJavascript(){
+	/**
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function purgeCachedHomepageBricksJavascript(): bool {
         $path=static::getCachedHomepageBricksJavascriptPath();
         return @unlink($path);
     }
@@ -212,7 +213,7 @@ class homepagebrick {
      * @throws ServerException
      * @throws BadRequestException
      */
-    public static function echoHomepageBricksJavascript(){
+    public static function echoHomepageBricksJavascript(): void {
         $path=static::getCachedHomepageBricksJavascriptPath();
         if(!file_exists($path)){
             static::writeCachedHomepageJavascript();
@@ -228,7 +229,7 @@ class homepagebrick {
     /**
      * @throws ServerException|BadRequestException
      */
-    private static function writeCachedHomepageJavascript(){
+    private static function writeCachedHomepageJavascript(): void {
         $cachedJsPath = static::getCachedHomepageBricksJavascriptPath();
         $bricksDir = dirname(__DIR__, 2) . '/client/bricks/';
         $files = scandir($bricksDir);
