@@ -8,7 +8,7 @@
 
 class homepagedefaultbrick {
 	
-	private static $select='SELECT db.id AS id, b.id AS homepagebrickid,
+	private static string $select='SELECT db.id AS id, b.id AS homepagebrickid,
 				db.row AS `row`, db.col AS `col`,
 				b.name AS name, b.version AS version, b.title AS title,
 				b.description AS description, db.height AS height, db.width AS width,
@@ -19,45 +19,48 @@ class homepagedefaultbrick {
     /**
      * @throws ForbiddenException
      */
-	private static function checkCanUpdate(){
+	private static function checkCanUpdate(): void {
 		if(!session::isAdmin()){
 			throw new ForbiddenException('Only administrators can configure the default homepage');
 		}
 	}
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function getById($id){
+	/**
+	 * @param int $id
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getById(int $id): ?array {
 	    return database::queryGetOne(
 	        static::$select.' AND db.id=:id',
 	        array(':id'=>$id)
 	        );
 	}
 
-    /**
-     * @param $name
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function getByName($name){
+	/**
+	 * @param string $name
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	public static function getByName(string $name): ?array {
 	    throw new BadRequestException('getByName not implemented on homepagedefaultbrick');
 	}
 
 	/**
 	 * @throws ServerException
+	 * @noinspection PhpUnusedParameterInspection
 	 */
-	public static function getByProperty($key, $value, $request=array()) {
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		throw new ServerException('getByProperty not implemented on homepagedefaultbrick');
 	}
 
 	/**
 	 * @throws ServerException
+	 * @noinspection PhpUnusedParameterInspection
 	 */
-	public static function getByProperties($keyValuePairs, $request=array()) {
+	public static function getByProperties(array$keyValuePairs, array $request=[]): ?array {
 		throw new ServerException('getByProperties not implemented on homepagedefaultbrick');
 	}
 
@@ -77,14 +80,14 @@ class homepagedefaultbrick {
     /**
      * @return array
      */
-	public static function getFieldHelpTexts(){
+	public static function getFieldHelpTexts(): array {
 		return array();
 	}
 
     /**
      * @return array
      */
-	public static function getFieldValidations(){
+	public static function getFieldValidations(): array {
 		return array();
 	}
 
@@ -95,7 +98,7 @@ class homepagedefaultbrick {
      * @throws ForbiddenException
      * @throws ServerException
      */
-	public static function create($request=array()){
+	public static function create(array $request=[]): array {
 		static::checkCanUpdate();
 		if(!isset($request['homepagebrickid']) || !isset($request['row']) || !isset($request['col'])){
 			throw new BadRequestException('Brick ID, row and col are required');
@@ -118,16 +121,16 @@ class homepagedefaultbrick {
 		return array('type'=>'homepageuserbrick', 'created'=>self::getById($newId));
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function update($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array{
 		static::checkCanUpdate();
 		$defaultBrick=static::getById($id);
 		if(!$defaultBrick){
@@ -153,14 +156,14 @@ class homepagedefaultbrick {
 	}
 
     /**
-     * @param $id
+     * @param int $id
      * @return array
      * @throws BadRequestException
      * @throws ForbiddenException
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function delete($id){
+	public static function delete(int $id): array {
 		static::checkCanUpdate();
 		$defaultBrick=static::getById($id);
 		if(!$defaultBrick){
