@@ -7,7 +7,7 @@
 
 class homepageuserbrick {
 	
-	private static $select='SELECT 
+	private static string $select='SELECT 
 			 homepageuserbrick.id AS id, homepagebrick.id AS homepagebrickid,
 			 homepagebrick.name, /*homepagebrick.title, homepagebrick.version, homepagebrick.description, 
 			 homepagebrick.apiurl, homepagebrick.scriptblock, homepagebrick.content,
@@ -18,47 +18,49 @@ class homepageuserbrick {
 			WHERE homepagebrick.id=homepageuserbrick.homepagebrickid 
 			 ';
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function getById($id){
+	/**
+	 * @param int $id
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getById(int $id): ?array {
 		$sqlStatement=static::$select.' AND homepageuserbrick.id=:id';
 		$parameters=array(':id'=>$id);
-		// 		$result['rowtemplates']=static::explodeStringToArray($result['rowtemplates']);
-// 		$result['headertemplates']=static::explodeStringToArray($result['headertemplates']);
 		return database::queryGetOne($sqlStatement, $parameters);
 	}
 
-    /**
-     * @param $name
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function getByName($name){
+	/**
+	 * @param string $name
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	public static function getByName(string $name): ?array {
 		throw new BadRequestException('getByName not implemented on homepageuserbrick');
 	}
 
 	/**
-	 * @param $name
-	 * @param $value
+	 * @param string $name
+	 * @param string $value
 	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
 	 * @noinspection PhpUnusedParameterInspection
 	 */
-	public static function getByProperty($name, $value, array $request=array()){
+	public static function getByProperty(string $name, string $value, array $request=[]): ?array {
 		throw new BadRequestException('getByProperty not implemented on homepageuserbrick');
 	}
 
 	/**
-	 * @param $keyValuePairs
+	 * @param array $keyValuePairs
 	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
+	 * @noinspection PhpUnusedParameterInspection
 	 */
-	public static function getByProperties($keyValuePairs, array $request=array()){
-		throw new BadRequestException('getByProperty not implemented on homepageuserbrick');
+	public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
+		throw new BadRequestException('getByProperties not implemented on homepageuserbrick');
 	}
 
     /**
@@ -68,24 +70,20 @@ class homepageuserbrick {
      * @throws ServerException
      * @noinspection PhpUnusedParameterInspection
      */
-	public static function getAll($request=array()){
+	public static function getAll(array $request=[]): array {
 		$sqlStatement=static::$select.' AND homepageuserbrick.userid=:userid ORDER BY homepageuserbrick.row, homepageuserbrick.col';
 		$parameters=array(':userid'=>session::getUserId());
-		//		foreach($result['rows'] as &$row){
-//	 		$row['rowtemplates']=static::explodeStringToArray($row['rowtemplates']);
-//	 		$row['headertemplates']=static::explodeStringToArray($row['headertemplates']);
-//		}
 		return database::queryGetAll($sqlStatement, $parameters);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function update($id,$request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
 		$userBrick=static::getById($id);
 		if(!$userBrick || $userBrick['userid']!=session::getUserId()){
 			throw new BadRequestException('homeuserpagebrick ID '.$id.' does not exist or is not yours');
@@ -115,7 +113,7 @@ class homepageuserbrick {
      * @throws ServerException
      * @throws ForbiddenException
      */
-	public static function create($request=array()){
+	public static function create(array $request=[]): array{
         if(!isset($request['homepagebrickid']) || !isset($request['row']) || !isset($request['col'])){
             throw new BadRequestException('Brick ID, row and col are required');
         }
@@ -162,13 +160,13 @@ class homepageuserbrick {
 		return array('type'=>'homepageuserbrick', 'created'=>self::getById($newId));
 	}
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function delete($id){
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function delete(int $id): array{
 		$userBrick=static::getById($id);
 		if(!$userBrick || $userBrick['userid']!=session::getUserId()){
 			throw new BadRequestException('homepageuserbrick ID '.$id.' does not exist or is not yours');
@@ -181,11 +179,5 @@ class homepageuserbrick {
 		database::query($sqlStatement, $parameters);
 		return array('deleted'=>$id);
 	}
-	
-	private static function explodeStringToArray($str){
-// 		$str=trim($str,"'[]");
-// 		$str=explode("','",$str);
-		return $str;
-	}
-	
+
 }
\ No newline at end of file
