@@ -1,13 +1,13 @@
 <?php 
 class permission implements crudable {
 
-	protected static $fields=array(
+	protected static array $fields=array(
 			'projectid'=>validator::INTEGER,
 			'usergroupid'=>validator::INTEGER,
 			'type'=>validator::PERMISSIONTYPE
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'projectid'=>'The ID of the project',
 			'usergroupid'=>'The ID of the usergroup',
 			'type'=>'What permission is being granted - create, read, update or delete'
@@ -20,34 +20,36 @@ class permission implements crudable {
 		return self::$helpTexts;
 	}
 
-	private static $changePermissions=array('create','update','delete');
+	private static array $changePermissions=array('create','update','delete');
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function getById($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getById(int $id): array {
 		$sqlStatement='SELECT * FROM permission WHERE id=:id';
 		return database::queryGetOne($sqlStatement, array(':id'=>$id));
 	}
 
-    /**
-     * @param $name
-     * @throws ServerException
-     */
-	public static function getByName($name): ?array {
+	/**
+	 * @param string $name
+	 * @return array|null
+	 * @throws ServerException
+	 */
+	public static function getByName(string $name): ?array {
 		throw new ServerException('getByName not implemented on permission');
 	}
 
 	/**
-	 * @param $key
-	 * @param $value
+	 * @param string $key
+	 * @param string $value
 	 * @param array $request
+	 * @return array|null
 	 * @throws ServerException
 	 */
-	public static function getByProperty($key,$value,$request=array()): ?array {
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		throw new ServerException('getByProperty not implemented on permission');
 	}
 
@@ -57,7 +59,7 @@ class permission implements crudable {
 	 * @return array|null
 	 * @throws ServerException
 	 */
-	public static function getByProperties(array $keyValuePairs, array $request=array()): ?array {
+	public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
 		throw new ServerException('getByProperties not implemented on permission');
 	}
 
@@ -65,7 +67,7 @@ class permission implements crudable {
 	 * @param array $request
 	 * @throws ServerException
 	 */
-	public static function getAll($request=array()): array {
+	public static function getAll(array $request=[]): array {
 		throw new ServerException('getAll not implemented on permission');
 	}
 
@@ -77,7 +79,7 @@ class permission implements crudable {
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create($request=array()): array {
+	public static function create(array $request=[]): array {
 		$projectId=$request['projectid'];
 		$usergroupId=$request['usergroupid'];
 		$type=$request['type'];
@@ -117,26 +119,27 @@ class permission implements crudable {
 		return array('created'=>$created);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @throws ServerException
-     */
-	public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
 		throw new ServerException('Update not implemented on permission');
 	}
 
-    /**
-     * Deletes the permission. If permission type is one of "create","update","delete",
-     * all create/update/delete permissions for this project and usergroup will be deleted.
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function delete($id): array {
+	/**
+	 * Deletes the permission. If permission type is one of "create","update","delete",
+	 * all create/update/delete permissions for this project and usergroup will be deleted.
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function delete(int $id): array {
 		$permission=self::getbyid($id);
 		$project=project::getbyid($permission['projectid']);
 		$usergroup=usergroup::getbyid($permission['usergroupid']);
@@ -177,11 +180,11 @@ class permission implements crudable {
 		return true; // and let the actual create sort it out
 	}
 
-    /**
-     * @param $id
-     * @return bool
-     */
-	public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 */
+	public static function canUpdate(int $id): bool {
 		return true; // and let the actual update sort it out
 	}
 
@@ -190,7 +193,7 @@ class permission implements crudable {
 	 * @throws ServerException
 	 * @throws BadRequestException
 	 */
-	public static function getPermissionId($projectId, $usergroupId, $permissionType) {
+	public static function getPermissionId(int $projectId, int $usergroupId, string $permissionType): ?int {
 		$permission=database::queryGetOne('SELECT id FROM permission WHERE projectid=:projectid 
                             AND usergroupid=:usergroupid AND type=:type',
 			[':projectid'=>$projectId, ':usergroupid'=>$usergroupId, ':type'=>$permissionType]
