@@ -1,6 +1,6 @@
 <?php class skin implements crudable {
 
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'friendlyname'=>validator::REQUIRED,
     	    'description'=>validator::REQUIRED,
@@ -11,7 +11,7 @@
     	    'bodyicontheme'=>validator::REQUIRED,
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 	);
 
 	/**
@@ -22,7 +22,7 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getByProperty($key, $value, $request=array()): ?array {
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 	    if('name'==$key){
 	        return static::getByName($value);
 	    }
@@ -43,7 +43,7 @@
 	 * @throws BadRequestException
 	 * @throws BadRequestException
 	 */
-	public static function getByProperties($keyValuePairs, $request=array()): ?array {
+	public static function getByProperties(array $keyValuePairs, $request=[]): ?array {
 		$keys=array_keys(self::getFieldValidations());
 		$sqlStatement='SELECT SQL_CALC_FOUND_ROWS * FROM skin WHERE 1=1 ';
 		$params=[];
@@ -80,7 +80,7 @@
 	 * @throws ServerException
 	 * @throws BadRequestException
 	 */
-	public static function getAll($request=array()): ?array {
+	public static function getAll(array $request=[]): ?array {
 	    return database::queryGetAll('SELECT * FROM skin ORDER BY friendlyname ');
 	}
 
@@ -88,7 +88,7 @@
 	 * @throws ServerException
 	 * @throws BadRequestException
 	 */
-	public static function getByName($name): ?array {
+	public static function getByName(string $name): ?array {
 	    return database::queryGetOne('SELECT * FROM skin WHERE name=:name',array(':name'=>$name));
 	}
 
@@ -96,7 +96,7 @@
 	 * @throws ServerException
 	 * @throws BadRequestException
 	 */
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
 	    return database::queryGetOne('SELECT * FROM skin WHERE id=:id',array(':id'=>$id));
 	}
 
@@ -104,24 +104,26 @@
      * @param array $request
      * @throws BadRequestException
      */
-	public static function create($request=array()): array {
+	public static function create(array $request=[]): array {
 	    throw new BadRequestException('Cannot create skins');
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @throws BadRequestException
-     */
-	public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function update(int $id, array $request=[]): array {
 	    throw new BadRequestException('Cannot update skins');
 	}
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-	public static function delete($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function delete(int $id): array {
 	    throw new BadRequestException('Cannot delete skins');
 	}
 
