@@ -5,23 +5,21 @@
  */
 class updater extends baseobject {
     
-    private static $completed=false;
-    private static $exceptionHandled=false;
-    private static $updaterModified=false;
-    private static $codeTainted=false;
-    private static $databaseTainted=false;
-    private static $codeBackedUp=false;
-    private static $previousBackupExists=false;
-    private static $databaseBackedUp=false;
-    private static $codeRestoreAttempted=false;
-    
-    private static $updatePath;
+    private static bool $completed=false;
+    private static bool $exceptionHandled=false;
+    private static bool $updaterModified=false;
+    private static bool $codeTainted=false;
+    private static bool $databaseTainted=false;
+    private static bool $codeBackedUp=false;
+    private static bool $previousBackupExists=false;
+    private static bool $databaseBackedUp=false;
+    private static string $updatePath;
     
     /**
      * These paths are preserved when copying the new IceBear files over the old ones.
      * @var array The paths to preserve. Paths are relative to the www-root
      */
-    private static $preservePaths=array(
+    private static array $preservePaths=array(
         'conf/config.ini', //Don't wipe out the IceBear database credentials or other configuration!
         'genericimporter/config.ini', //Don't wipe out the IceBear database credentials or other configuration!
         'install/', //Don't write an installation directory, IceBear is already installed!
@@ -30,15 +28,15 @@ class updater extends baseobject {
         //'client/templates/core/config/list.php', //The config page
     );
 
-    /**
-     * Handle GETs from update page, e.g., requesting list of updates.
-     * @param array $request
-     * @return array|void
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-    public static function getAll($request=array()): ?array {
+	/**
+	 * Handle GETs from update page, e.g., requesting list of updates.
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+    public static function getAll(array $request=[]): ?array {
         if(!session::isAdmin()){ throw new ForbiddenException('Only administrators can install updates'); }
         if(isset($request['getupdatelog'])){
             //Retrieve the log of the ongoing update
@@ -54,7 +52,11 @@ class updater extends baseobject {
         } else {
             //Fetch the list of releases from the website
             $request['url']=rtrim(config::get('update_baseuri'),'/').'/releases/releases_json.php';
-            return corsproxy::getAll($request);
+            $response=corsproxy::getAll($request);
+			if(!$response){ return null; }
+			$response=json_decode($response, true);
+			if(!$response){ return null; }
+			return $response;
         }
     }
 
@@ -66,32 +68,47 @@ class updater extends baseobject {
      * @throws ForbiddenException
      * @throws ServerException
      */
-    public static function update($id, $request=array()): array {
+    public static function update(int $id, array $request=[]): array {
         if(!session::isAdmin()){ throw new ForbiddenException('Only administrators can install updates'); }
         $request['username']=session::getUsername();
         $request['gmtDate']=gmdate('d M y H:i:s');
         $request['rawPostBody']=json_encode($request);
         $request['url']=rtrim(config::get('update_baseuri'),'/').'/releases/confirmed.php';
-        return corsproxy::create($request);
+        $response=corsproxy::create($request);
+		if(!$response){
+			return ['confirmationSucceeded'=>false];
+		} else {
+			$json=json_encode($response);
+			if(!$json){
+				return ['confirmation'=>$response];
+			} else {
+				return ['confirmation'=>$json];
+			}
+		}
+
     }
 
-    /**
-     * Handle POSTs from update page, e.g., final confirmation and start of upgrade.
-     * @param array $request
-     * @return array
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-    public static function create($request=array()): array {
+	/**
+	 * Handle POSTs from update page, e.g., final confirmation and start of upgrade.
+	 * @param array $request
+	 * @return array
+	 * @throws ForbiddenException
+	 * @throws ServerException|BadRequestException
+	 * @throws NotFoundException
+	 */
+    public static function create(array $request=[]): array {
         if(!session::isAdmin()){ throw new ForbiddenException('Only administrators can install updates'); }
         return static::doUpdate($request);
     }
 
-    /**
-     * @param $newVersion
-     * @return string
-     */
-    private static function getUpdatePath($newVersion){
+	/**
+	 * @param string $newVersion
+	 * @return string
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    private static function getUpdatePath(string $newVersion): string {
+		if(isset(static::$updatePath)){ return static::$updatePath; }
         $newVersion=str_replace('.', '_', $newVersion);
         $path=rtrim(config::get('core_filestore'),'/').'/update/';
         @mkdir($path);
@@ -101,22 +118,25 @@ class updater extends baseobject {
         return $path;
     }
 
-    /**
-     * @return string
-     */
-    private static function getLogPath(){
+	/**
+	 * @return string
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    private static function getLogPath(): string {
         $filestore=rtrim(config::get('core_filestore'),'/').'/';
         @mkdir($filestore.'updatelogs/');
         return $filestore.'updatelogs/update.log';
     }
 
-    /**
-     * @param $request
-     * @return array
-     * @throws ServerException
-     * @throws Exception
-     */
-    private static function doUpdate($request): array {
+	/**
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException|NotFoundException
+	 */
+    private static function doUpdate(array $request): array {
         set_time_limit(0);
         $newVersion=$request['newversion'];
         if(!Log::isInited()){
@@ -144,12 +164,12 @@ class updater extends baseobject {
             if(!$newVersion || !preg_match('/^(\d+\.)?(\d+\.)?(\d+)$/', $newVersion)){
                 throw new BadRequestException('Bad or missing update version specified');
             }
-            Log::write(Log::LOGLEVEL_INFO, 'Current version: '.config::getCodeVersion());
+            Log::write(Log::LOGLEVEL_INFO, 'Current version: '.updater::getCodeVersion());
             Log::write(Log::LOGLEVEL_INFO, 'Updating to version: '.$newVersion);
             
             $updatePath=static::getUpdatePath($newVersion);
-            if(!@file_exists(static::$updatePath)){
-                throw new ServerException('Could not create directory for updates at '.static::$updatePath);
+            if(!@file_exists($updatePath)){
+                throw new ServerException('Could not create directory for updates at '.$updatePath);
             }
             
             if(isset($request['secondpass'])){
@@ -165,13 +185,13 @@ class updater extends baseobject {
                 Log::write(Log::LOGLEVEL_INFO, 'Updater was not changed on this pass, continuing');
                 static::matchSslRedirectStatusInHtaccess();
                 static::copyUnpackedFilesIntoWebRoot();
-                static::updateDatabase(rtrim(static::$updatePath,'/').'/unpacked');
+                static::updateDatabase(rtrim($updatePath,'/').'/unpacked');
                 static::loadReferenceData();
                 static::parseHomepageBricks();
                 static::$completed=true;
             } else {
-                Log::write(Log::LOGLEVEL_WARN, 'Updater was changed on this pass');
-            }
+				Log::warn('Updater was changed on this pass');
+			}
             
         } catch(Exception $e){
             static::$exceptionHandled=true;
@@ -184,7 +204,6 @@ class updater extends baseobject {
                 Log::write(Log::LOGLEVEL_WARN, 'These database changes should roll back immediately, but you may need to restore from back-ups.');
             }
             if(static::$codeTainted){
-                $codeRestored=false;
                 Log::write(Log::LOGLEVEL_WARN, 'Your IceBear code has been modified.');
                 if(static::$codeBackedUp || static::$previousBackupExists){
                     try {
@@ -197,7 +216,6 @@ class updater extends baseobject {
                         static::restoreOriginalCode();
                         Log::write(Log::LOGLEVEL_INFO, 'Restored the IceBear code.');
                         Log::write(Log::LOGLEVEL_WARN, 'Your IceBear was modified but a restore was attempted.');
-                        $codeRestored=true;
                     } catch (Exception $e2){
                         Log::write(Log::LOGLEVEL_ERROR, 'Attempting to restore IceBear code threw an exception:');
                         Log::write(Log::LOGLEVEL_ERROR, $e2->getMessage());
@@ -218,8 +236,8 @@ class updater extends baseobject {
             throw $e;
             //throw new ServerException($e->getMessage());
         } finally {
-            $codeVersion=config::getCodeVersion();
-            $databaseVersion=config::getDatabaseVersion();
+            $codeVersion=updater::getCodeVersion();
+            $databaseVersion=updater::getDatabaseVersion();
             Log::write(Log::LOGLEVEL_INFO, 'Code version: '.$codeVersion);
             Log::write(Log::LOGLEVEL_INFO, 'Database version: '.$databaseVersion);
             if(static::$completed){
@@ -261,7 +279,6 @@ class updater extends baseobject {
     private static function backUpCodeAndDatabase(): void {
         Log::write(Log::LOGLEVEL_INFO, 'Attempting copy of database and IceBear www directory into file store...');
         Log::write(Log::LOGLEVEL_INFO, '...(should work regardless of whether IceBear backups are configured)...');
-        
         //Don't overwrite a previous backup - multiple failed attempts would wipe good backup.
         if(file_exists(static::$updatePath.'beforeUpdate')){
             Log::write(Log::LOGLEVEL_WARN, '...Backup exists from previous attempt to update to this version. Leaving in place.');
@@ -279,9 +296,6 @@ class updater extends baseobject {
         if(!$dbDetails){
             throw new Exception('Could not read database connection details from config file');
         }
-//        $db = new PDO('mysql:host='.$dbDetails['dbHost'].';dbname='.$dbDetails['dbName'], $dbDetails['dbUser'], $dbDetails['dbPass'], array(PDO::MYSQL_ATTR_FOUND_ROWS => true));
-//        $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
-        
         //Write lock file to prevent importers beginning during dump
         Log::write(Log::LOGLEVEL_DEBUG, 'Writing lock file before database backup...');
         $fileStoreRoot=rtrim(config::get('core_filestore'),'/\\').'/';
@@ -307,7 +321,10 @@ class updater extends baseobject {
         //Bail if database dump failed
         if(!empty($output)){
             Log::write(Log::LOGLEVEL_ERROR, 'Database dump failed.');
-            throw new Exception($output);
+			foreach ($output as $line){
+				Log::error($line);
+			}
+            throw new Exception('Database dump failed');
         }
         
         $dumpSize=@filesize($sqlDumpFile);
@@ -403,7 +420,8 @@ class updater extends baseobject {
             $tar=new PharData(static::$updatePath.$updateFilename);
             $tar->extractTo(static::$updatePath.'unpacked');
         } catch (Exception $e) {
-            Log::write(Log::LOGLEVEL_ERROR, 'Could not unpack update after downloading.');
+			Log::write(Log::LOGLEVEL_ERROR, 'Could not unpack update after downloading.');
+			Log::write(Log::LOGLEVEL_ERROR, 'Exception message: '.$e->getMessage());
             throw new ServerException('Could not unpack update after downloading.');
         }
         
@@ -442,6 +460,11 @@ class updater extends baseobject {
         Log::write(Log::LOGLEVEL_WARN, 'IceBear updater changed');
         Log::write(Log::LOGLEVEL_WARN, 'The IceBear updater code has changed in the new version.');
         Log::write(Log::LOGLEVEL_WARN, 'The new updater has been copied into place. Now the updater needs to run again.');
+
+		Log::info('Copying all unpacked files into web root...');
+		static::copyUnpackedFilesIntoWebRoot();
+		Log::info('...done');
+
         Log::write(Log::LOGLEVEL_WARN, 'Please wait...');
         return true;
     }
@@ -538,7 +561,6 @@ class updater extends baseobject {
             $excludeFullPaths[]=static::$updatePath.'beforeUpdate/www/'.ltrim($p,'/');
         }
         static::recursiveCopy(static::$updatePath.'beforeUpdate/www', config::getWwwRoot(), $excludeFullPaths);
-        static::$codeRestoreAttempted=true;
         Log::write(Log::LOGLEVEL_INFO, 'Attempted restore of original IceBear files.');
         Log::write(Log::LOGLEVEL_DEBUG, 'restoreOriginalCode finished');
     }
@@ -573,6 +595,9 @@ class updater extends baseobject {
 		$paths=scandir($icebearRoot.'upgrade');
 		if($paths){
 			$paths=array_diff($paths, ['..', '.']);
+			if(!$paths){
+				$paths=[];
+			}
 		} else {
 			$paths=[];
 		}
@@ -632,8 +657,8 @@ class updater extends baseobject {
         }
         Log::write(Log::LOGLEVEL_INFO, 'Database update is complete.');
         
-        $codeVersion=config::getCodeVersion();
-        $databaseVersion=config::getDatabaseVersion();
+        $codeVersion=updater::getCodeVersion();
+        $databaseVersion=updater::getDatabaseVersion();
         Log::write(Log::LOGLEVEL_INFO, 'Database version: '.$databaseVersion);
         Log::write(Log::LOGLEVEL_INFO, 'Code version: '.$codeVersion);
         if($databaseVersion!=$codeVersion){
@@ -642,8 +667,11 @@ class updater extends baseobject {
         Log::write(Log::LOGLEVEL_DEBUG, 'updateDatabase complete');
     }
 
-    /**
-     * @throws ServerException
+	/**
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
 	 */
     public static function loadReferenceData(): void {
         Log::write(Log::LOGLEVEL_DEBUG, 'In loadReferenceData');
@@ -753,16 +781,34 @@ class updater extends baseobject {
      * @throws ServerException
      * @throws BadRequestException
      */
-    private static function getDatabaseVersion(): string {
-		return config::getDatabaseVersion();
+    public static function getDatabaseVersion(): string {
+		$databaseVersion=config::get('core_icebearversion');
+		if(empty($databaseVersion)){
+			if(Log::isInited()){
+				Log::write(Log::LOGLEVEL_WARN,'Database version not set. Assuming and setting 1.0');
+			}
+			database::query(
+				"INSERT INTO config(name,description,type,defaultvalue,value) 
+                    VALUES('core_icebearversion','IceBear database version number','text','','1.0')"
+			);
+			$databaseVersion='1.0';
+		}
+		return trim($databaseVersion);
+
 	}
 
     /**
      * @return string
      * @throws ServerException
      */
-    private static function getCodeVersion(): string {
-		return config::getCodeVersion();
+    public static function getCodeVersion(): string {
+		$fileName=__DIR__.'/../../conf/codeversion';
+		if(!file_exists($fileName)){
+			throw new ServerException('IceBear directory does not contain file conf/codeversion.');
+		}
+		$contents=@file_get_contents($fileName);
+		return trim($contents);
+
     }
 
 }
\ No newline at end of file
