@@ -2,13 +2,13 @@
 
 class userconfig {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
     	    'userid'=>validator::REQUIRED,
 			'value'=>validator::ANY,
 	);
 	
-	static function get($name){
+	static function get(string $name): ?string {
 	    $config=session::get('userConfig');
 	    if(isset($config[$name])){
 	        return $config[$name];
@@ -21,14 +21,14 @@ class userconfig {
 	}
 
 	/**
-	 * @param $name
-	 * @param $value
+	 * @param string $name
+	 * @param string $value
 	 * @return bool
+	 * @throws AuthorizationRequiredException
 	 * @throws BadRequestException
 	 * @throws ServerException
-	 * @throws AuthorizationRequiredException
 	 */
-	public static function set($name, $value){
+	public static function set(string $name, string $value): bool {
 	    $userid=session::getUserId();
 		if(!$userid){
 			throw new AuthorizationRequiredException('You must be logged in to set user config values');
@@ -46,7 +46,7 @@ class userconfig {
      * @throws ServerException
      * @noinspection PhpUnusedParameterInspection
      */
-	public static function getAll($request=array()){
+	public static function getAll(array $request=[]): array {
 	    $userid=session::getUserId();
 	    if(!$userid){ return static::$loggedOutConfig; }
 	    $config=session::get('userConfig');
@@ -62,36 +62,39 @@ class userconfig {
 		return $ret;
 	}
 
-	private static $loggedOutConfig=array(
+	private static array $loggedOutConfig=array(
 	    'skin'=>'default'
 	);
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	static function getById($id){
+	/**
+	 * @param int $id
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	static function getById(int $id): ?array {
 		throw new BadRequestException('getById not implemented on userconfig');
 	}
 
-    /**
-     * @param $name
-     * @throws BadRequestException
-     * @noinspection PhpUnusedParameterInspection
-     */
-	static function getByName($name){
+	/**
+	 * @param string $name
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	static function getByName(string $name): ?array {
 		throw new BadRequestException('getByName not implemented on userconfig');
 	}
 
 	/**
-	 * @param $key
-	 * @param $value
+	 * @param string $key
+	 * @param string $value
 	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
 	 * @noinspection PhpUnusedParameterInspection
 	 */
-	static function getByProperty($key,$value,$request=array()){
+	static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		throw new BadRequestException('getByProperty not implemented on userconfig');
 	}
 
@@ -101,7 +104,7 @@ class userconfig {
 	 * @throws BadRequestException
 	 * @noinspection PhpUnusedParameterInspection
 	 */
-	static function getByProperties($keyValuePairs,$request=array()){
+	static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
 		throw new BadRequestException('getByProperty not implemented on userconfig');
 	}
 
