@@ -39,13 +39,7 @@ class validator {
      * @throws ServerException
      * @throws BadRequestException
      */
-    public static function validateAll($keyValuePairs, $validations, $enforceRequired){
-        if(!is_array($keyValuePairs)){
-            throw new ServerException('keyValuePairs must be an array');
-        }
-        if(!is_array($validations)){
-            throw new ServerException('validations must be an array');
-        }
+    public static function validateAll(array $keyValuePairs, array $validations, bool $enforceRequired): bool {
         foreach ($keyValuePairs as $key=>$value) {
             if(isset($validations[$key])){
                 validator::validate($key, $value, $validations[$key]);
@@ -73,7 +67,7 @@ class validator {
      * @throws BadRequestException if $fieldValue is not valid.
      * @throws ServerException
      */
-	public static function validate(string $fieldName, $fieldValue, $validationNames): bool {
+	public static function validate(string $fieldName, ?string $fieldValue, array|string $validationNames): bool {
 		if(!is_array($validationNames)){
 			$validationNames=array($validationNames);
 		}
@@ -97,7 +91,7 @@ class validator {
 	 * @return boolean true if $fieldname validates, false otherwise
 	 *@throws ServerException if $validationName is not a known validation.
 	 */
-	public static function isValid($fieldValue, $validationNames): bool {
+	public static function isValid(?string $fieldValue, array|string $validationNames): bool {
 		if(!is_array($validationNames)){
 			$validationNames=array($validationNames);
 		}
@@ -131,7 +125,7 @@ class validator {
 	 * 
 	 * NOTE: If adding helper functions, these need to be mirrored in the client Javascript validator.
 	 */
-	private static $validations=array(
+	private static array $validations=array(
 			validator::ANY=>array(
 				'message'=>'' //No validation, so shouldn't ever need a message
 			),
@@ -252,55 +246,52 @@ class validator {
 			)
 	);
 
-	private static function isValidJSON($json) {
+	private static function isValidJSON(string $json): bool {
 		if(!@json_decode($json)) { return false; }
 		return true;
 	}
 
-    /**
-     * @param $seq
-     * @return bool
-     * @noinspection PhpUnusedPrivateMethodInspection
-     */
-	private static function isValidDnaSequence($seq): bool {
+	/**
+	 * @param string $seq
+	 * @return bool
+	 */
+	private static function isValidDnaSequence(string $seq): bool {
 		$seq=strtoupper(str_replace(' ','',$seq));
 		if(!preg_match('/^[ACGT]*$/', $seq)){ return false; }
 		if(strlen($seq)%3 != 0){ return false; }
 		return true;
 	}
 
-    /**
-     * @param $email
-     * @return bool
-     * @noinspection PhpUnusedPrivateMethodInspection
-     */
-    private static function isValidEmailAddress($email): bool {
+	/**
+	 * @param string $email
+	 * @return bool
+	 */
+    private static function isValidEmailAddress(string $email): bool {
         if(filter_var($email, FILTER_VALIDATE_EMAIL)===false){
             return false;
         }
         return true;
     }
 
-    /**
-     * @param $ip
-     * @return bool
-     * @noinspection PhpUnusedPrivateMethodInspection
-     */
-    private static function isValidIPv4Address($ip): bool {
+	/**
+	 * @param string $ip
+	 * @return bool
+	 */
+    private static function isValidIPv4Address(string $ip): bool {
         if(filter_var($ip, FILTER_VALIDATE_IP)===false){
             return false;
         }
         return true;
     }
 
-    /**
-     * Checks whether a string is a valid geofence. A valid geofence is a comma-separated list of numbers, either
-     * lat,long,radius(m) or at least three lat,long pairs. Note that this validation DOES NOT check whether the
-     * sides of a closed-polygon geofence cross; caller must avoid this by sensible point selection.
-     * @param $geofence
-     * @return false
-     */
-    private static function isValidGeofence($geofence):bool {
+	/**
+	 * Checks whether a string is a valid geofence. A valid geofence is a comma-separated list of numbers, either
+	 * lat,long,radius(m) or at least three lat,long pairs. Note that this validation DOES NOT check whether the
+	 * sides of a closed-polygon geofence cross; caller must avoid this by sensible point selection.
+	 * @param string $geofence
+	 * @return false
+	 */
+    private static function isValidGeofence(string $geofence):bool {
         $parts=explode(',', $geofence);
         $numParts=count($parts);
         foreach($parts as $part){
