@@ -8,51 +8,49 @@
     const BARCODE_PATTERN='AAAA'; // Four alphanumeric, e.g., 9a62
 
     /**
-     * @return array|mixed
-     * @throws BadRequestException
+     * @return array
+	 * @throws BadRequestException
      * @throws ServerException
-     * @throws NotFoundException
-     */
-    public static function getScores(){
+	 */
+    public static function getScores(): array {
         return static::getScoresWithScoringSystemName(static::SCORING_SYSTEM_NAME);
     }
 
-    /**
-     * Does the actual work of getScores - split for testing.
-     * @param $scoringSystemName
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ServerException
-     * @throws NotFoundException
-     */
-    public static function getScoresWithScoringSystemName($scoringSystemName){
+	/**
+	 * Does the actual work of getScores - split for testing.
+	 * @param string $scoringSystemName
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getScoresWithScoringSystemName(string $scoringSystemName): array{
         return ImageScoring::getScoresWithScoringSystemName($scoringSystemName);
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createScores($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createScores(array $params): array {
         return static::createScoresWithScoringSystemName($params, static::SCORING_SYSTEM_NAME);
     }
 
-    /**
-     * Does the actual work of createScores. We split it out like this so that we can test the code doing the actual
-     * work - testing creation with a pre-existing "Formulatrix" scoring system will fail.
-     * @param $params
-     * @param $scoringSystemName
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createScoresWithScoringSystemName($params, $scoringSystemName){
+	/**
+	 * Does the actual work of createScores. We split it out like this so that we can test the code doing the actual
+	 * work - testing creation with a pre-existing "Formulatrix" scoring system will fail.
+	 * @param array $params
+	 * @param string $scoringSystemName
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createScoresWithScoringSystemName(array $params, string $scoringSystemName): array {
         Log::debug('In createScoresWithScoringSystemName');
         $params['name']=$scoringSystemName;
         $system=ImageScoring::createScoringSystem($params);
@@ -65,28 +63,28 @@
      * @throws ServerException
      * @return array containing keys "fxImagingTaskId" and "numImages" (how many images are registered to this task in IceBear)
      */
-    public static function getLatestImagingTask(){
+    public static function getLatestImagingTask(): array {
         return static::getImageCountTotalAndImagedTime();
     }
 
-    /**
-     * @param $params
-     * @return int[]
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    public static function getImagingTaskByFormulatrixId($params){
+	/**
+	 * @param array $params
+	 * @return int[]
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getImagingTaskByFormulatrixId(array $params): array {
         static::require('id', $params);
         return static::getImageCountTotalAndImagedTime($params['id']);
     }
 
     /**
-     * @param $fxImagingTaskId
+     * @param bool $fxImagingTaskId
      * @return int[]
      * @throws BadRequestException
      * @throws ServerException
      */
-    private static function getImageCountTotalAndImagedTime($fxImagingTaskId=false){
+    private static function getImageCountTotalAndImagedTime(int $fxImagingTaskId=0): array {
         session::becomeAdmin();
         $ret=array(
             "fxImagingTaskId"=>0,
@@ -127,58 +125,58 @@
         return $ret;
     }
 
-    /**
-     * @param array $params
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createUser($params=array()){
+	/**
+	 * @param array $params
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createUser(array $params=[]): ?array {
         return UserManagement::createUser($params);
     }
 
-    /**
-     * @param $params
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createPlateType($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createPlateType(array $params): array{
         Log::debug('In FormulatrixImport::createPlateType');
         $plateType=PlateImport::createPlateType($params);
         Log::debug('Returning from FormulatrixImport::createPlateType');
         return $plateType;
     }
 
-    /**
-     * @param $params
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws NotModifiedException
-     * @throws ServerException
-     */
-    public static function createPlate($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function createPlate(array $params): array {
         Log::debug('In FormulatrixImport::createPlate');
         $plate=PlateImport::createPlate($params);
         Log::debug('Returning from FormulatrixImport::createPlate');
         return $plate;
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createImager($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImager(array $params): array {
         Log::debug('In FormulatrixImport::createImager');
         static::require('name', $params);
         static::requireOneOf(['temperature','nominalTemperature'], $params);
@@ -199,15 +197,15 @@
     }
 
 
-    /**
-     * @param $params
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createImagingSettings($params){
+	/**
+	 * @param array $params
+	 * @return mixed
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImagingSettings(array $params): array {
         /*
                 {
                     "captureProfile":{
@@ -297,15 +295,15 @@
         return $ibImagingParameters;
     }
 
-    /**
-     * @param $params
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createImagingSession($params){
+	/**
+	 * @param array $params
+	 * @return mixed
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImagingSession(array $params): array {
         static::require(['imagingTaskId','plateBarcode','temperature','imagerName','imagedDateTime','captureProfileVersionId'], $params);
         session::becomeAdmin();
         $imagingParametersVersion=imagingparametersversion::getByProperties(array(
@@ -398,12 +396,12 @@
         return $imagingSession;
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     */
-    public static function createImages($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 */
+    public static function createImages(array $params): array {
         static::require('images',$params);
         $ret=[];
         foreach($params['images'] as $image) {
@@ -425,7 +423,7 @@
      * @throws ServerException
      * @throws Exception
      */
-    public static function createImage($params){
+    public static function createImage(array $params): array {
         static::require(['iceBearImagingSessionId','wellRowNumber','wellColumnNumber','wellDropNumber','image','thumb'],$params);
         static::requireOneOf(['plateBarcode','iceBearPlateId'], $params);
 
@@ -534,16 +532,16 @@
         return $image['created'];
     }
 
-    /**
-     * @param $params
-     * @return array[]
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws NotModifiedException
-     * @throws ServerException
-     */
-    public static function updateImagerInventories($params){
+	/**
+	 * @param array $params
+	 * @return array[]
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function updateImagerInventories(array $params): array {
         static::require('imagers',$params);
         session::becomeAdmin();
         $sharedProject=project::getByName(baseproject::SHARED);
@@ -617,12 +615,13 @@
         return array('updatedImagers'=>$updatedImagers);
     }
 
-    /**
-     * @param $params
-     * @return array[]
-     * @throws BadRequestException
-     */
-    public static function updateDiskSpaces($params){
+	/**
+	 * @param array $params
+	 * @return array[]
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function updateDiskSpaces(array $params): array {
         $updatedDrives=Device::updateDiskSpaces($params);
         $content=array(
             'total'=>count($updatedDrives),
@@ -632,14 +631,14 @@
         return $content;
     }
 
-    /**
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getPlateForReimport(){
+	/**
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getPlateForReimport(): array {
         return PlateImport::getPlateForReimport(['imagerType'=>'Formulatrix']);
     }
 
