@@ -1,6 +1,10 @@
 <?php class ImageView extends Device {
 
-	public static function get($parameters) {
+	/**
+	 * @throws ServerException
+	 * @throws BadRequestException
+	 */
+	public static function get(array $parameters): void {
 		if(empty($parameters)){ throw new BadRequestException('No parameters'); }
 		$imageId=(int)$parameters[0];
 		if($imageId<1){
