@@ -13,19 +13,19 @@
     const BAD_DATE_MESSAGE = 'Bad date, should be a UTC date in YYYY-MM-DD hh:mm:ss';
     const NO_IMAGER_WITH_NAME_MESSAGE = 'No imager with that name';
 
-    public static function getVersion(){
+    public static function getVersion(): int {
         return 1;
     }
 
-    /**
-     * @param $plateType
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createPlateType($plateType): array {
+	/**
+	 * @param array $plateType
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createPlateType(array $plateType): array {
         Log::debug('In PlateImport::createPlateType');
         foreach($plateType as $k=>$v){
             Log::debug('- '.$k.'='.$v);
@@ -80,75 +80,76 @@
         return $plateType;
     }
 
-    /**
-     * @param $user
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createUser($user): array {
+	/**
+	 * @param array $user
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createUser(array $user): array {
         Log::debug('In PlateImport::createUser');
         $user=UserManagement::createUser($user);
         Log::debug('Returning from PlateImport::createUser');
         return $user;
     }
 
-    /**
-     * Creates an imager, or finds an existing one, and returns the supplied parameters with the imager ID in receiversId.
-     * @param $imager
-     * @return array
-     * @throws BadRequestException if nominalTemperature is not numeric, or if plateCapacity is not an integer greater than 0.
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException if imager already exists but temperature or capacity do not match
-     */
-    public static function createImager($imager): array {
+	/**
+	 * Creates an imager, or finds an existing one, and returns the supplied parameters with the imager ID in receiversId.
+	 * @param array $imager
+	 * @return array
+	 * @throws BadRequestException if nominalTemperature is not numeric, or if plateCapacity is not an integer greater than 0.
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException if imager already exists but temperature or capacity do not match
+	 */
+    public static function createImager(array $imager): array {
         Log::debug('In PlateImport::createImager');
         $imager=ImagingManagement::createImager($imager);
         Log::debug('Returning from PlateImport::createImager');
         return $imager;
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException|ForbiddenException
-     */
-    public static function createScoringSystem($params): array {
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createScoringSystem(array $params): array {
         Log::debug('In PlateImport::createScoringSystem');
         $system=ImageScoring::createScoringSystem($params);
         Log::debug('Returning from PlateImport::createScoringSystem');
         return $system;
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getScoringSystem($params): array {
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getScoringSystem(array $params): array {
         Log::debug('In PlateImport::getScoringSystem');
         $system=ImageScoring::getScoringSystem($params);
         Log::debug('Returning from PlateImport::getScoringSystem');
         return $system;
     }
 
-    /**
-     * @param $proteins
-     * @param $projectOwnerId
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createMultipleProteins($proteins, $projectOwnerId): array {
+	/**
+	 * @param array $proteins
+	 * @param int $projectOwnerId
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createMultipleProteins(array $proteins, int $projectOwnerId): array {
         Log::debug('In PlateImport::createMultipleProteins');
         foreach ($proteins as &$protein) {
             $protein=static::createProteinAndConstructs($protein, $projectOwnerId);
@@ -167,7 +168,7 @@
      * @throws NotFoundException
      * @throws ForbiddenException
      */
-    public static function createProteinAndConstructs($protein, $projectOwnerId): array {
+    public static function createProteinAndConstructs(array $protein, int $projectOwnerId): array {
         Log::debug('In PlateImport::createProteinAndConstructs');
         static::require(['name','constructs'], $protein);
         session::becomeAdmin();
@@ -304,16 +305,16 @@
         return $protein;
     }
 
-    /**
-     * @param $plate
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws ForbiddenException
-     * @throws NotModifiedException
-     */
-    public static function createPlate($plate): array {
+	/**
+	 * @param array $plate
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function createPlate(array $plate): array {
         Log::debug('In PlateImport::createPlate');
         static::require(['barcode','scoringSystemName','plateType','owner'],$plate);
         session::becomeAdmin();
@@ -388,15 +389,15 @@
         return $plate;
     }
 
-    /**
-     * @param $imageBatch
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws ForbiddenException
-     */
-    public static function createImageBatch($imageBatch){
+	/**
+	 * @param array $imageBatch
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImageBatch(array $imageBatch): array {
         static::require(['dateTimeUtc','plateBarcode','lightType','imagerName'],$imageBatch);
         try {
             session::becomeAdmin();
@@ -495,28 +496,28 @@
         return $imageBatch;
     }
 
-    /**
-     * @param $image
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws ForbiddenException
-     */
-    public static function createImage($image){
+	/**
+	 * @param array $image
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImage(array $image): array {
         Log::debug('In PlateImport::createImage');
         $image=ImagingManagement::createImage($image);
         Log::debug('Returning from PlateImport::createImage');
         return $image;
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getScreenByName($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getScreenByName(array $params): array {
         Log::debug('In PlateImport::getScreenByName');
         static::require('name', $params);
         session::becomeAdmin();
@@ -540,13 +541,13 @@
         return $screen;
     }
 
-    /**
-     * @param $params
-     * @return ?array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    public static function getProjectByName($params): ?array {
+	/**
+	 * @param array $params
+	 * @return ?array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getProjectByName(array $params): ?array {
         Log::debug('In PlateImport::getProjectByName');
         static::require('name', $params);
         session::becomeAdmin();
@@ -560,14 +561,14 @@
 		return $project;
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
 	 * @throws ServerException
-     */
-    public static function createProject($params): array {
+	 */
+    public static function createProject(array $params): array {
         Log::debug('In PlateImport::createProject');
         static::require(['name','ownerId','description'], $params);
         session::becomeAdmin();
@@ -616,7 +617,7 @@
      *   ]
      * }
      */
-    public static function createScreen($params): array {
+    public static function createScreen(array $params): array {
         session::becomeAdmin();
         static::require(['name','rows','cols','conditions','projectId'], $params);
         if(empty($params['conditions'])){
@@ -676,7 +677,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function getPlateForReimport($params): array {
+    public static function getPlateForReimport(array $params): array {
         $pattern='';
         if(isset($params['imagerType'])){
             if('formulatrix'==strtolower($params['imagerType'])){
