@@ -20,15 +20,15 @@
         array('color'=>'0064fa', 'index'=>'9', 'hotkey'=>'1', 'name'=>'Crystals')
     );
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createScores($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createScores(array $params): array {
         Log::debug('In RigakuImport::createScores');
             foreach($params as $k=>$v){
                 if(is_array($v)){
@@ -52,39 +52,39 @@
 
     /**
      * @throws ServerException
-     * @throws NotFoundException
-     * @throws BadRequestException
+	 * @throws BadRequestException
      */
-    public static function getScores(){
+    public static function getScores(): array {
         Log::debug('In RigakuImport::getScores');
         $scores=ImageScoring::getScoresWithScoringSystemName(static::SCORING_SYSTEM_NAME);
         Log::debug('Returning from RigakuImport::getScores');
         return $scores;
     }
 
-    /**
-     * @param $params
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getImagingProfiles($params){
+	/**
+	 * @param array $params
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getImagingProfiles(array $params): ?array {
         Log::debug('In getImagingProfiles');
         $profiles=static::createImagingProfiles($params);
         Log::debug('Returning from getImagingProfiles');
         return $profiles;
     }
 
-    /**
-     * @param $params
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws ForbiddenException
-     */
-    public static function createImagingProfiles($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImagingProfiles(array $params): array {
         Log::debug('In createImagingProfiles');
         static::require('profiles',$params);
         session::becomeAdmin();
@@ -143,7 +143,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function createUser($user){
+    public static function createUser(array $user): array{
         Log::debug('In RigakuImport::createUser');
         foreach($user as $k=>$v){
             Log::debug('- '.$k.'='.$v);
@@ -167,15 +167,15 @@
         return $user;
     }
 
-    /**
-     * @param $user
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getUser($user){
+	/**
+	 * @param array $user
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getUser(array $user): array {
         return static::createUser($user);
     }
 
@@ -185,47 +185,46 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function createImager($params){
+    public static function createImager(array $params): array {
         Log::debug('In RigakuImport::createImager');
         static::require(['name','nominalTemperature'], $params);
         $params['manufacturerName']='Rigaku';
         $imager=ImagingManagement::createImager($params);
-        Log::debug('Returning from FormulatrixImport::createImager');
+        Log::debug('Returning from RigakuImport::createImager');
         return $imager;
     }
 
-    /**
-     * @param $plateType
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getPlateType($plateType){
+	/**
+	 * @param array $plateType
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getPlateType(array $plateType): array {
         return static::createPlateType($plateType);
     }
 
-    /**
-     * @param $plateType
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createPlateType($plateType){
+	/**
+	 * @param array $plateType
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createPlateType(array $plateType): array {
         return PlateImport::createPlateType($plateType);
     }
 
-    /**
-     * @param $params
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getScreenByName($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getScreenByName(array $params): array {
         return PlateImport::getScreenByName($params);
     }
 
@@ -235,7 +234,7 @@
      * @throws ServerException
      * @throws NotFoundException
      */
-    public static function promoteScreenToStandard($params){
+    public static function promoteScreenToStandard(array $params): array {
         static::require('screenId', $params);
         session::becomeAdmin();
         $screenId=$params['screenId'];
@@ -245,14 +244,13 @@
         return screen::getById($screenId);
     }
 
-    /**
-     * @param $params
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getPlateByBarcode($params){
+	/**
+	 * @param array $params
+	 * @return array|mixed
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getPlateByBarcode(array $params): ?array {
         Log::debug('In getPlateByBarcode');
         static::require('barcode',$params);
         $barcode=$params['barcode'];
@@ -264,14 +262,14 @@
         return $plate;
     }
 
-    /**
-     * @param $params
-     * @return mixed|null
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getInspectionsForPlate($params){
+	/**
+	 * @param array $params
+	 * @return mixed|null
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getInspectionsForPlate(array $params): ?array {
         static::require('barcode', $params);
         $barcode=$params['barcode'];
         session::becomeAdmin();
@@ -300,7 +298,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function createInspection($params){
+    public static function createInspection(array $params): array {
         Log::debug('In createInspection');
         static::require('plateBarcode',$params);
         static::require('imagedDateTime',$params);
@@ -383,60 +381,60 @@
         return $inspection;
     }
 
-    /**
-     * @param $plate
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws NotModifiedException
-     * @throws ServerException
-     */
-    public static function createPlate($plate){
+	/**
+	 * @param array $plate
+	 * @return mixed
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function createPlate(array $plate): array {
         $plate['scoringSystemName']=self::SCORING_SYSTEM_NAME;
         return PlateImport::createPlate($plate);
     }
 
-    /**
-     * @throws NotFoundException
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-    public static function createImages($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function createImages(array $params): array {
         Log::debug('In createImages');
         return ImagingManagement::createImages($params);
     }
 
-    /**
-     * @param $params
-     * @return array|null
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    public static function getProject($params){
+	/**
+	 * @param array $params
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getProject(array $params): ?array {
         static::require('name', $params);
         return PlateImport::getProjectByName($params);
     }
 
-    /**
-     * @param $params
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createProject($params){
+	/**
+	 * @param array $params
+	 * @return mixed
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+    public static function createProject(array $params): array {
         return PlateImport::createProject($params);
     }
 
-    /**
-     * @param $params
-     * @return array[]
-     * @throws BadRequestException
-     */
-    public static function updateDiskSpaces($params){
+	/**
+	 * @param array $params
+	 * @return array[]
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function updateDiskSpaces(array $params): array {
         $updatedDrives=Device::updateDiskSpaces($params);
         $content=array(
             'total'=>count($updatedDrives),
@@ -446,14 +444,16 @@
         return $content;
     }
 
-    /**
-     * @throws NotFoundException
-     * @throws ForbiddenException
-     * @throws BadRequestException
-     * @throws NotModifiedException
-     * @throws ServerException
-     */
-    public static function createScreen($params){
+	/**
+	 * @param array $params
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function createScreen(array $params): array {
         if(!isset($params['projectId'])){
             session::becomeAdmin();
             $params['projectId']=baseproject::getSharedProjectId();
@@ -471,7 +471,7 @@
      * @throws ForbiddenException
      * @throws ServerException
      */
-    public static function getPlateForReimport(){
+    public static function getPlateForReimport(): ?array {
         return PlateImport::getPlateForReimport(['imagerType'=>'Rigaku']);
     }
 
