@@ -19,15 +19,15 @@ class WisCrimsImport extends Device {
         array('index'=>7, 'color'=>'8b4513', 'name'=>'Salt')
     );
 
-    /**
-     * @param $params
-     * @return array[]
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function createImages($params){
+	/**
+	 * @param array $params
+	 * @return array[]
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function createImages(array $params): array {
         static::require('images',$params);
         $createdImages=[];
         foreach ($params['images'] as $image){
@@ -45,7 +45,7 @@ class WisCrimsImport extends Device {
      * @throws NotFoundException
      * @throws ForbiddenException
      */
-    public static function createImage($image){
+    public static function createImage(array $image): array {
         if(isset($image['images'])){
             return static::createImages($image);
         }
@@ -165,8 +165,6 @@ class WisCrimsImport extends Device {
         dropimage::update($inspectionImageId, array(
             'pixelheight'=>$height,
             'pixelwidth'=>$width,
-//            'micronsperpixelx'=>$micronsPerPixel,
-//            'micronsperpixely'=>$micronsPerPixel
             'imagepath'=>str_replace($imageStore,'',$newImagePath),
             'thumbnailpath'=>str_replace($imageStore,'',$newThumbPath),
         ));
@@ -174,24 +172,24 @@ class WisCrimsImport extends Device {
 		return dropimage::getById($inspectionImageId);
     }
 
-    private static function stripUUencodingHeaderAndFooterLines($rawString){
+    private static function stripUUencodingHeaderAndFooterLines(string $rawString): string {
         $parts=explode("\n", $rawString, 2);
         $headerlessString=$parts[1];
         $parts=explode("\nend", $headerlessString);
 		return $parts[0];
     }
 
-    /**
-     * Creates multiple plates.
-     * @param $params
-     * @return array[]
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws NotModifiedException
-     * @throws ServerException
-     */
-    public static function createPlates($params){
+	/**
+	 * Creates multiple plates.
+	 * @param array $params
+	 * @return array[]
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function createPlates(array $params): array {
         if(isset($params['plateType'])){
             //This is a single plate
             return static::createPlate($params);
@@ -214,7 +212,7 @@ class WisCrimsImport extends Device {
      * @throws ServerException
      * @throws NotModifiedException
      */
-    public static function createPlate($plate){
+    public static function createPlate(array $plate): array {
         session::becomeAdmin();
         if(isset($plate['plates'])){ return static::createPlates($plate); }
         static::require(['scoringSystemName','plateType','barcode','owner'],$plate);
@@ -269,7 +267,7 @@ class WisCrimsImport extends Device {
      * @throws NotModifiedException
      * @throws ServerException
      */
-    public static function createProteinAndConstruct($limsPlateId, $proteinConstruct, $owner){
+    public static function createProteinAndConstruct(int $limsPlateId, array $proteinConstruct, array $owner): void {
         static::require('proteinName',$proteinConstruct);
         if(!isset($proteinConstruct['proteinAcronym'])) {
             $proteinConstruct['proteinAcronym']='';
@@ -380,7 +378,7 @@ class WisCrimsImport extends Device {
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function createUser($user){
+    public static function createUser(array $user): array {
         Log::debug('In WisCrimsImport::createUser');
         static::require(['name','username','emailAddress'],$user);
         $user=UserManagement::createUser($user);
@@ -397,7 +395,7 @@ class WisCrimsImport extends Device {
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function createPlateType($plateType){
+    public static function createPlateType(array $plateType): array {
         Log::debug('In WisCrimsImport::createPlateType');
         $plateType=PlateImport::createPlateType($plateType);
         Log::debug('Returning from WisCrimsImport::createPlateType');
@@ -412,7 +410,7 @@ class WisCrimsImport extends Device {
      * @throws NotFoundException
      * @throws ServerException
      */
-    private static function getScoringSystem(){
+    private static function getScoringSystem(): array {
         $crimsSS=crystalscoringsystem::getByName('CRIMS');
         if(!empty($crimsSS)){
             return $crimsSS;
@@ -438,16 +436,16 @@ class WisCrimsImport extends Device {
         return $crimsSS;
     }
 
-    /**
-     * Returns a dummy inspection for the plate, creating it if necessary.
-     * @param $plate array The plate - requires name, id
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    private static function getDummyPlateInspectionForPlate($plate){
+	/**
+	 * Returns a dummy inspection for the plate, creating it if necessary.
+	 * @param $plate array The plate - requires name, id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    private static function getDummyPlateInspectionForPlate(array $plate): array {
         $plateBarcode=$plate['name'];
         $dummyInspection=imagingsession::getByName($plateBarcode.'_dummy');
         if(!$dummyInspection){
@@ -476,7 +474,7 @@ class WisCrimsImport extends Device {
      * @throws NotFoundException
      * @throws ServerException
      */
-    private static function handleInterestingDrop($drop, $limsPlate, $limsInspection){
+    private static function handleInterestingDrop(array $drop, array $limsPlate, array $limsInspection): void {
         static::require(['rowNumber','columnNumber','dropNumber'],$drop);
         $row=1*$drop['rowNumber'];
         $col=1*$drop['columnNumber'];
@@ -503,16 +501,16 @@ class WisCrimsImport extends Device {
         }
     }
 
-    /**
-     * @param $limsInspectionId
-     * @param $wellDropId
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    private static function createDummyImage($limsInspectionId, $wellDropId){
+	/**
+	 * @param int $limsInspectionId
+	 * @param int $wellDropId
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    private static function createDummyImage(int $limsInspectionId, int $wellDropId): array {
         $wellDrop=welldrop::getById($wellDropId);
         if(!$wellDropId){ throw new NotFoundException("No well drop with ID $wellDropId"); }
         $plateWell=platewell::getById($wellDrop['platewellid']);
