@@ -540,7 +540,7 @@ try {
  * @throws NotFoundException
  * @throws ServerException
  */
-function importImagingTask($imagingTask){
+function importImagingTask(array $imagingTask): bool {
 
 	global $rm, $ri, $lightPaths, $copyToIceBearStore, $fxRoot;
 
@@ -1091,7 +1091,7 @@ function importImagingTask($imagingTask){
  * @return array The ImagingTasks
  * @throws ServerException
  */
-function getFormulatrixImagingTasksForPlateBarcode($barcode){
+function getFormulatrixImagingTasksForPlateBarcode(string $barcode): array {
     Log::write(Log::LOGLEVEL_DEBUG, 'In getFormulatrixImagingTasksForPlateBarcode, $barcode='.$barcode);
     global $rm;
 
@@ -1159,7 +1159,7 @@ function getTimeOfNewestLimsImagingSession(){
  * @param string $imagerName The Formulatrix serial, e.g., RI1000-1234.
  * @throws Exception
  */
-function importImager($imagerName){
+function importImager(string $imagerName): void {
 	Log::write(Log::LOGLEVEL_DEBUG, 'In importImager, imagerName='.$imagerName);
 	global $ri, $sharedProjectId;
 	$imagerType=explode('-', $imagerName)[0];
@@ -1196,7 +1196,7 @@ function importImager($imagerName){
  * @throws NotFoundException
  * @throws ServerException
  */
-function importCaptureProfileVersion($captureProfileVersionId){
+function importCaptureProfileVersion(int $captureProfileVersionId): void {
 	Log::write(Log::LOGLEVEL_DEBUG, 'In importCaptureProfileVersion, id='.$captureProfileVersionId);
 	global $rm, $sharedProjectId;
 	$stmt=$rm->prepare('SELECT CaptureProfileVersion.ID, CaptureProfileVersion.CaptureProfileID, CaptureProfile.CurrentCaptureProfileVersionID, CaptureProfile.Name
@@ -1281,7 +1281,7 @@ function importCaptureProfileVersion($captureProfileVersionId){
  * @throws NotFoundException
  * @throws ServerException
  */
-function importCaptureProfile($captureProfileId){
+function importCaptureProfile(int $captureProfileId): void {
 	Log::write(Log::LOGLEVEL_DEBUG, 'In importCaptureProfile, id='.$captureProfileId);
 	global $rm, $sharedProjectId;
 	$stmt=$rm->prepare('SELECT Name, CurrentCaptureProfileVersionID
@@ -1322,7 +1322,7 @@ function importCaptureProfile($captureProfileId){
  * @throws NotFoundException
  * @throws ServerException
  */
-function importPlate($barcode){
+function importPlate(string $barcode): void {
 	Log::write(Log::LOGLEVEL_DEBUG, 'In importPlate, barcode='.$barcode);
 	global $rm, $scoringSystem, $unknownUsernames, $defaultPlateOwnerUsername;
 	$stmt=$rm->prepare('SELECT Plate.ID, Containers.Name AS PlateTypeName, Users.Name AS UserName, Users.EmailAddress
@@ -1436,7 +1436,7 @@ function importScoringSystem(){
  * @throws NotFoundException
  * @throws ServerException
  */
-function importPlateType($plateTypeName){
+function importPlateType(string $plateTypeName): void {
 	Log::write(Log::LOGLEVEL_DEBUG, 'In importPlateType, plateTypeName='.$plateTypeName);
 	global $rm;
 
@@ -1481,7 +1481,7 @@ function importPlateType($plateTypeName){
  * @throws NotFoundException
  * @throws ServerException
  */
-function importUser($emailAddress){
+function importUser(string $emailAddress): mixed {
 	global $rm;
 	$stmt=$rm->prepare('SELECT Name FROM Users WHERE EmailAddress=:email');
 	$stmt->execute(array(':email'=>$emailAddress));
