@@ -1,17 +1,17 @@
 <?php class autoprocessingresultparameter extends baseobject {
 
-    protected static $fields=array(
+    protected static array $fields=array(
         'name'=>validator::REQUIRED,
         'autoprocessingresultid'=>validator::REQUIRED,
         'parametername'=>validator::REQUIRED,
         'parametervalue'=>validator::ANY
     );
 
-    protected static $helpTexts=array(
+    protected static array $helpTexts=array(
 
     );
 
-    public static $defaultSortOrder='autoprocessingresultparameter.name';
+    public static string $defaultSortOrder='autoprocessingresultparameter.name';
 
     /**
      * @return bool
@@ -21,12 +21,12 @@
         return session::isShipper() || session::isAdmin();
     }
 
-    /**
-     * @param $id
-     * @return bool
-     * @throws NotFoundException
-     */
-    public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 * @throws NotFoundException
+	 */
+    public static function canUpdate(int $id): bool {
         return session::isShipper() || session::isAdmin();
     }
 
