@@ -1,6 +1,6 @@
 <?php class beamline extends baseobject {
 
-    protected static $fields=array(
+    protected static array $fields=array(
         'name'=>validator::REQUIRED,
         'shipmentdestinationid'=>array(validator::REQUIRED, validator::INTEGER),
         'detectormanufacturer'=>validator::ANY,
@@ -8,23 +8,23 @@
         'detectortype'=>validator::ANY,
     );
 
-    protected static $helpTexts=array(
+    protected static array $helpTexts=array(
 
     );
 
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS beamline.*, shipmentdestination.name AS shipmentdestinationname
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS beamline.*, shipmentdestination.name AS shipmentdestinationname
         FROM beamline, shipmentdestination, project
         WHERE beamline.shipmentdestinationid=shipmentdestination.id
             AND beamline.projectid=project.id
     ';
-    protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS beamline.*, shipmentdestination.name AS shipmentdestinationname
+    protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS beamline.*, shipmentdestination.name AS shipmentdestinationname
         FROM beamline, shipmentdestination, project
         WHERE beamline.shipmentdestinationid=shipmentdestination.id
             AND beamline.projectid=project.id
     ';
-    public static $defaultSortOrder='shipmentdestination.name, beamline.name';
+    public static string $defaultSortOrder='shipmentdestination.name, beamline.name';
 
-    public static function create(array $request = array()): array {
+    public static function create(array $request=[]): array {
 		shipment::setShipperAdmin();
         $sharedProject=project::getByName(baseproject::SHARED);
 		if(!$sharedProject){
@@ -44,12 +44,12 @@
         return session::isShipper() || session::isAdmin();
     }
 
-    /**
-     * @param $id
-     * @return bool
-     * @throws NotFoundException
-     */
-    public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 * @throws NotFoundException
+	 */
+    public static function canUpdate(int $id): bool {
         return session::isShipper() || session::isAdmin();
     }
 
