@@ -1,27 +1,27 @@
 <?php class construct extends protein { //Extend protein, which extends baseobject - same restrictions on canCreate
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'description'=>validator::REQUIRED,
 			'proteinid'=>array(validator::REQUIRED, validator::INTEGER),
 	);
 
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this construct',
 			'description'=>'Short description of this construct',
 			'proteinid'=>'The database ID of the parent protein',
 	);
 	
 	
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS construct.*, project.name AS projectname, project.isarchived AS isarchived, 
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS construct.*, project.name AS projectname, project.isarchived AS isarchived, 
 			protein.name AS proteinname, protein.proteinacronym as proteinacronym
 			FROM construct, protein, project WHERE project.id=construct.projectid AND protein.id=construct.proteinid';
-	protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS construct.*, project.name AS projectname, project.isarchived AS isarchived, 
+	protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS construct.*, project.name AS projectname, project.isarchived AS isarchived, 
 			protein.name AS proteinname, protein.proteinacronym as proteinacronym
 			FROM construct, protein, project WHERE project.id=construct.projectid AND protein.id=construct.proteinid';
 	
 	
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		if(!isset($request['proteinid'])){ throw new BadRequestException('No parent protein specified'); }
 		$protein=protein::getById($request['proteinid']);
 		if(!$protein){
@@ -50,21 +50,19 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getByName($name, $request=array()): ?array {
+	public static function getByName(string $name, array $request=[]): ?array {
 		return self::getByProperty('name', $name, $request);
 	}
 
-    /**
-     * Gets the sequences for this construct.
-     * @param int $id The construct ID
-     * @param array $request The request parameters, e.g., pagination
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused Called by API forward_static_call_array
-     */
-	public static function getsequences($id,$request=array()){
+	/**
+	 * Gets the sequences for this construct.
+	 * @param int $id The construct ID
+	 * @param array $request The request parameters, e.g., pagination
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getsequences(int $id, array $request=[]): ?array {
 		return sequence::getByProperty('constructid',$id,$request);
 	}
 }
\ No newline at end of file
