@@ -2,17 +2,17 @@
 
 class container extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
 		'containertypeid'=>array(validator::REQUIRED, validator::INTEGER),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'A unique identifier for the container',
 		'containertypeid'=>'The type of container, e.g., Unipuck',
 	);
 
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS container.*,
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS container.*,
 				containercategory.id AS containercategoryid, 
 				containercategory.name AS containercategoryname, 
 				containertype.name AS containertypename,
@@ -22,7 +22,7 @@ class container extends baseobject {
 			WHERE containertype.id=container.containertypeid 
 			AND containercategory.id=containertype.containercategoryid 
 			AND container.projectid=project.id';
-	protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS container.*,
+	protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS container.*,
 				containercategory.id AS containercategoryid, 
 				containercategory.name AS containercategoryname, 
 				containertype.name AS containertypename,
@@ -33,7 +33,7 @@ class container extends baseobject {
 			AND containercategory.id=containertype.containercategoryid 
 			AND container.projectid=project.id ';
 
-	protected static $sharedProjectOverride=true;
+	protected static bool $sharedProjectOverride=true;
 
     /**
      * @param array $request
@@ -43,7 +43,7 @@ class container extends baseobject {
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		$project=project::getByName(baseproject::SHARED);
 		if(!$project){
 			throw new NotFoundException('Could not read shared project.');
@@ -91,7 +91,7 @@ class container extends baseobject {
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function update($id,$request=array()): array {
+	public static function update(int $id, array $request=[]): array {
 	    $container=static::getById($id);
 	    if(isset($request['action']) && 'unpackAll'==$request['action']){
 	        //get all containercontents where $id is parent
@@ -124,15 +124,15 @@ class container extends baseobject {
 		return !empty($creatableCategories);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function getfullcontents($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function getfullcontents(int $id, array $request=[]): array {
 		$request['recursive']='yes';
 		$rows=static::getcontents($id,$request);
 		return array(
@@ -141,15 +141,15 @@ class container extends baseobject {
 		);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function getcontents($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function getcontents(int $id, array $request=[]): array {
 		if(!isset($request['recursive'])){
             return containercontent::getByProperties(array(
                     'parent'=>$id,
@@ -161,15 +161,15 @@ class container extends baseobject {
 		return container::getContentsRecursively($parent);
 	}
 
-    /**
-     * @param $id
-     * @param $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getparentcontainer($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function getparentcontainer(int $id, array $request=[]): array {
         $containerContent=containercontent::getByProperties(array(
             'parent'=>$id,
             'iscurrent'=>1
@@ -180,15 +180,15 @@ class container extends baseobject {
         return container::getById($containerContent['parent']);
     }
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     * @throws NotFoundException
-     */
-	public static function gethistoricalcontents($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function gethistoricalcontents(int $id, array $request=[]): array {
 		return containercontent::getByProperties(array(
 				'parent'=>$id,
 				'iscurrent'=>0
@@ -202,7 +202,7 @@ class container extends baseobject {
      * @throws ServerException
      * @throws NotFoundException
      */
-	public static function getContentsRecursively($parent){
+	public static function getContentsRecursively(array $parent): array {
 	    if(isset($parent['positions'])){
             $numPositions=$parent['positions'];
             $positions=array_fill(0,(int)$numPositions+1,null);
