@@ -1,11 +1,11 @@
 <?php class containercategory extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
 		'userscancreate'=>validator::BOOLEAN
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'A unique identifier for the container category',
 		'userscancreate'=>'If false, only admins and technicians can create containers in this category',
 	);
@@ -18,7 +18,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		if(!static::canCreate()){
 			throw new ForbiddenException('Only administrators and technicians can create containers');
 		}
@@ -30,11 +30,12 @@
         return parent::createByClassName($request,'containercategory');
 	}
 
-    /**
-     * @return bool
-     * @throws BadRequestException
-     * @throws NotFoundException
-     */
+	/**
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
 	public static function canCreate(): bool {
 		if(session::isAdmin()){ return true; }
 		$grp=usergroup::getByName(usergroup::TECHNICIANS);
