@@ -1,6 +1,6 @@
 <?php class crystalscore extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'crystalscoringsystemid'=>array(validator::REQUIRED, validator::INTEGER),
 			'label'=>validator::REQUIRED,
@@ -9,7 +9,7 @@
 			'hotkey'=>array(validator::REQUIRED, validator::INTEGER),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this score. Created automatically',
 			'label'=>'Label shown to users',
 			'color'=>'The highlight colour for this score',
@@ -17,7 +17,7 @@
 			'hotkey'=>'The hotkey for this score in the drop viewer (0-9 only)'
 	);
 
-	public static $defaultSortOrder='scoreindex ASC';
+	public static string $defaultSortOrder='scoreindex ASC';
 
     /**
      * @param array $request
@@ -27,7 +27,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		$project=project::getByName(baseproject::SHARED);
 		if(!$project){
 			throw new NotFoundException('Could not read shared project');
