@@ -1,6 +1,6 @@
 <?php class dataset extends baseobject {
 
-    protected static $fields=array(
+    protected static array $fields=array(
         'name'=>validator::REQUIRED,
 		'collecteddatetime'=>validator::DATETIME,
         'crystalid'=>array(validator::REQUIRED, validator::INTEGER),
@@ -20,12 +20,12 @@
         'wavelength'=>validator::FLOAT
     );
 
-    protected static $aliasedColumns=array(
+    protected static array $aliasedColumns=array(
         'proteinacronym',
         'shipmentid'
     );
 
-    protected static $helpTexts=array(
+    protected static array $helpTexts=array(
         'crystalid'=>'The crystal from which this dataset came',
         'diffractionrequestid'=>'The diffraction request from which this dataset came',
         'starrating'=>'A subjective score of this dataset\'s importance',
@@ -33,7 +33,7 @@
         'datalocation'=>'The path, URL, or DOI where the raw data can be found'
     );
 
-    protected static $normalSelect='SELECT dataset.*, ROUND(dataset.bestresolution, 2) AS bestresolution,
+    protected static string $normalSelect='SELECT dataset.*, ROUND(dataset.bestresolution, 2) AS bestresolution,
         ROUND(dataset.wavelength, 4) AS wavelength,
        protein.proteinacronym, protein.name AS proteinname, protein.id AS proteinid, 
        construct.name AS constructname, construct.id AS constructid,
@@ -57,7 +57,7 @@
         WHERE 1=1
     ';
 
-    protected static $adminSelect='SELECT dataset.*, ROUND(dataset.bestresolution, 2) AS bestresolution, 
+    protected static string $adminSelect='SELECT dataset.*, ROUND(dataset.bestresolution, 2) AS bestresolution, 
 	        ROUND(dataset.wavelength, 4) AS wavelength,
            crystal.name AS crystalname, crystal.dropimageid, pdbdeposition.name AS pdbcode, project.owner AS projectownerid,
          protein.proteinacronym, protein.name AS proteinname, protein.id AS proteinid, 
@@ -81,23 +81,23 @@
         WHERE 1=1
     ';
 
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
 		$dataset=parent::getById($id);
 		$dataset['locations']=static::getdatasetlocations($id);
 		return $dataset;
 	}
 
-	public static function getAll(array $request = array()): ?array {
+	public static function getAll(array $request=[]): ?array {
 		$result=parent::getAll($request);
 		return static::addLocations($result);
 	}
 
-	public static function getByProperty($key, $value, $request = array()): ?array {
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		$result=parent::getByProperty($key, $value, $request);
 		return static::addLocations($result);
 	}
 
-	public static function getByProperties(array $keyValuePairs, array $request = array()): ?array {
+	public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
 		$result=parent::getByProperties($keyValuePairs, $request);
 		return static::addLocations($result);
 	}
@@ -106,7 +106,8 @@
 	 * @throws ServerException
 	 * @throws BadRequestException
 	 */
-	private static function addLocations($result){
+	private static function addLocations(?array $result): ?array {
+		if(!$result){ return  $result; }
 		foreach($result['rows'] as &$row){
 			$locations=static::getdatasetlocations($row['id']);
 			if(empty($locations)){
@@ -118,15 +119,12 @@
 		return $result;
 	}
 
-	public static function create(array $request = array()): array {
+	public static function create(array $request=[]): array {
 		shipment::setShipperAdmin();
         $crystalId=$request['crystalid'];
         if(!$crystalId){ throw new BadRequestException("Crystal ID not specified"); }
         $crystal=crystal::getById($crystalId);
         if(!$crystal){ throw new NotFoundException("Crystal not found"); }
-        if(session::getUserId() !==1*$crystal['projectownerid'] && session::isShipper() && !session::isAdmin()){
-            throw new ForbiddenException('Only the project owner can manage datasets');
-        }
 		$dataLocation=$request['datalocation'].'';
 		$request['datalocation']='-'; //TODO When dropping datalocation column, unset $request['datalocation']
         $request['projectid']=$crystal['projectid'];
@@ -138,74 +136,59 @@
         return $ret;
     }
 
-    public static function update($id, $request=array()): array {
+    public static function update(int $id, array $request=[]): array {
 		shipment::setShipperAdmin();
         $dataset=static::getById($id);
         if(!$dataset){ throw new NotFoundException('Dataset does not exist or you do not have permission to see it'); }
-        if(!session::isShipper() && !session::isAdmin() && (int)($dataset['projectownerid'])!==session::getUserId()){
-            throw new ForbiddenException('Only the project owner can modify datasets');
-        }
         $ret=parent::update($id, $request);
 		shipment::revertShipperAdmin();
         return $ret;
     }
 
-    public static function delete($id): array {
-        $deposition=static::getById($id);
-        if(!$deposition || session::isAdmin()){
-            return parent::delete($id);
-        }
-        $crystal=crystal::getById($deposition['crystalid']);
-        if(!$crystal || (session::getUserId()!==1*$crystal['projectownerid'] && !session::isAdmin())){
-            throw new ForbiddenException('Only the project owner can manage datasets');
-        }
-        return parent::delete($id);
-    }
-
     /**
      * @return bool
-     * @throws NotFoundException
-     */
+	 */
     public static function canCreate(): bool {
         return true; //but checked in create()
     }
 
-    /**
-     * @param $id
-     * @return bool
-     * @throws NotFoundException
-     */
-    public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 */
+    public static function canUpdate(int $id): bool {
         return true; //but checked in create()
     }
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function getautoprocessingresults($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getautoprocessingresults(int $id, array $request=[]): ?array {
         return autoprocessingresult::getByProperty('datasetid', $id, $request);
     }
 
 	/**
-	 * @throws ServerException
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
 	 * @throws BadRequestException
+	 * @throws ServerException
 	 */
-	public static function getdatasetlocations($id, $request=array()): ?array {
+	public static function getdatasetlocations(int $id, array $request=[]): ?array {
 		return datasetlocation::getByProperty('datasetid', $id, $request);
 	}
 
-    /**
-     * @param $parentId
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function updateFileNoteAndRecordingProjectIds($parentId){
+	/**
+	 * @param int $parentId
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function updateFileNoteAndRecordingProjectIds(int $parentId): void {
         parent::updateFileNoteAndRecordingProjectIds($parentId);
     }
 
@@ -219,7 +202,7 @@
      * @throws BadRequestException
      * @throws ForbiddenException
      */
-    public static function setBestResolutionFromAutoProcessingResults($id){
+    public static function setBestResolutionFromAutoProcessingResults(int $id): void {
         $results=static::getautoprocessingresults($id);
         if(!$results){ return; }
         $bestResolution=999999;
