@@ -1,6 +1,6 @@
 <?php class diffractionrequest extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
 		'crystalid'=>array(validator::REQUIRED, validator::INTEGER),
 		'shipmentid'=>validator::INTEGER,
@@ -14,7 +14,7 @@
 	    'comment'=>validator::ANY,
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'The name of the shipment destination',
 		'crystalid'=>'The ID of the crystal to which this comment relates',
 		'shipmentid'=>'The ID of the shipment - crystal may be shipped several times with different comments',
@@ -31,7 +31,7 @@
 	const KEEP_CRYSTAL='keep';
 	const WASH_CRYSTAL='wash';
 	
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		$crystal=crystal::getById($request['crystalid']);
 		$request['projectid']=$crystal['projectid'];
 		$request['name']='crystal'.$crystal['id'].'_diffreq_'.microtime();
@@ -42,16 +42,16 @@
 		return parent::create($request);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
 	    $diffractionRequest=static::getById($id);
 	    if(!$diffractionRequest){ throw new NotFoundException('No diffractionrequest with ID '.$id); }
 	    if(isset($request['shipmentid'])){
@@ -89,7 +89,7 @@
 	 * @throws NotFoundException
 	 * @throws ServerException
 	 */
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
         $dr=parent::getById($id);
         if(!$dr && session::isShipper()){
             try {
@@ -104,14 +104,14 @@
         return $dr;
     }
 
-    /**
-     * @param $id
-     * @return bool
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function canUpdate(int $id): bool {
 	    return parent::canUpdate($id) || session::isShipper();
     }
 
