@@ -1,15 +1,11 @@
 <?php class dropimage extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'imagingsessionid'=>array(validator::REQUIRED, validator::INTEGER),
 			'welldropid'=>array(validator::REQUIRED, validator::INTEGER),
-//            'pixelheight'=>array(validator::REQUIRED, validator::INTEGER),
-//            'pixelwidth'=>array(validator::REQUIRED, validator::INTEGER),
             'pixelheight'=>array(validator::INTEGER),
             'pixelwidth'=>array(validator::INTEGER),
-//			'micronsperpixelx'=>array(validator::REQUIRED,validator::FLOAT),
-//			'micronsperpixely'=>array(validator::REQUIRED,validator::FLOAT),
 			'micronsperpixelx'=>array(validator::FLOAT),
 			'micronsperpixely'=>array(validator::FLOAT),
             'latestcrystalscoreid'=>validator::INTEGER,
@@ -22,7 +18,7 @@
 
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this drop image',
 			'imagingsessionid'=>'The imaging session where this image was taken',
 			'welldropid'=>'The drop that was imaged',
@@ -35,15 +31,15 @@
 			'thumbnailpath'=>'Path from image store to thumbnail',
 	);
 	
-	public static $defaultSortOrder='platewell.row, platewell.col, welldrop.dropnumber, imagingsession.imageddatetime';
+	public static string $defaultSortOrder='platewell.row, platewell.col, welldrop.dropnumber, imagingsession.imageddatetime';
 	
-	protected static $adminSelect="SELECT SQL_CALC_FOUND_ROWS dropimage.*, imagingsession.imageddatetime, imagingsession.lighttype,
+	protected static string $adminSelect="SELECT SQL_CALC_FOUND_ROWS dropimage.*, imagingsession.imageddatetime, imagingsession.lighttype,
 			CONCAT('/api/dropimagefile/',dropimage.id,'/full.',SUBSTRING_INDEX(dropimage.imagepath,'.',-1) ) AS fullimageurl, 
 			CONCAT('/api/dropimagethumb/',dropimage.id,'/thumb.',SUBSTRING_INDEX(dropimage.thumbnailpath,'.',-1)) AS thumbnailurl,
 			platewell.id AS platewellid, platewell.row, platewell.col, welldrop.dropnumber
 			FROM dropimage, welldrop, platewell, imagingsession 
 			WHERE dropimage.welldropid=welldrop.id AND welldrop.platewellid=platewell.id AND dropimage.imagingsessionid=imagingsession.id";
-	protected static $normalSelect="SELECT SQL_CALC_FOUND_ROWS dropimage.*, imagingsession.imageddatetime, imagingsession.lighttype, 
+	protected static string $normalSelect="SELECT SQL_CALC_FOUND_ROWS dropimage.*, imagingsession.imageddatetime, imagingsession.lighttype, 
 			CONCAT('/api/dropimagefile/',dropimage.id,'/full.',SUBSTRING_INDEX(dropimage.imagepath,'.',-1) ) AS fullimageurl, 
 			CONCAT('/api/dropimagethumb/',dropimage.id,'/thumb.',SUBSTRING_INDEX(dropimage.thumbnailpath,'.',-1)) AS thumbnailurl,
 			platewell.id AS platewellid, platewell.row, platewell.col, welldrop.dropnumber,
@@ -51,11 +47,11 @@
 			FROM dropimage, welldrop, platewell, imagingsession 
 			WHERE dropimage.welldropid=welldrop.id AND welldrop.platewellid=platewell.id AND dropimage.imagingsessionid=imagingsession.id ";
 	
-	private static $THUMBNAIL_MAXHEIGHT=120;
-	private static $THUMBNAIL_MAXWIDTH=150;
+	private static int $THUMBNAIL_MAXHEIGHT=120;
+	private static int $THUMBNAIL_MAXWIDTH=150;
 	
 	
-	public static function getSelectClause(){
+	public static function getSelectClause(): string {
 		return static::$normalSelect;
 	}
 	
@@ -63,7 +59,7 @@
 		return ''; //Images are publicly accessible, nothing in the metadata worth hiding.
 	}
 	
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		
 		//Formulatrix importer doesn't have a $_FILES record.
 		if(empty($_FILES) || empty($_FILES['dropimage'])){
@@ -208,7 +204,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function update($id,$request=array()): array {
+	public static function update(int $id, array $request=[]): array {
 
         $defaultProjectId=baseproject::getDefaultProjectId();
         $wasAdmin=session::isAdmin();
@@ -258,15 +254,15 @@
         return $ret;
 	}
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function delete($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function delete(int $id): array {
 		$dropImage=static::getById($id);
 		if(!$dropImage){
 			throw new NotFoundException('No drop image with ID '.$id);
@@ -306,27 +302,27 @@
 		return $ret;
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
 	 * @throws ServerException
-     */
-    public static function getscores($id, array $request=array()) {
+	 */
+    public static function getscores(int $id, array $request=[]): ?array {
         $request['dropimageid']=$id;
         return scoreofdropimage::getByProperty('dropimageid', $id, $request);
     }
 
-    /**
-     * @param $id
-     * @return void
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    private static function carryForwardScores($id){
+	/**
+	 * @param int $id
+	 * @return void
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    private static function carryForwardScores(int $id): void {
 	    $dropImage=static::getById($id);
 	    if(!$dropImage){ throw new NotFoundException('No drop image with ID '.$id); }
 	    $wellDropId=$dropImage['welldropid'];
