@@ -4,7 +4,7 @@ use JetBrains\PhpStorm\NoReturn;
 
 class dropimagefile extends dropimage {
 	
-	#[NoReturn] public static function getById($id): ?array {
+	#[NoReturn] public static function getById(int $id): ?array {
 		$img=dropimage::getById($id);
 		$file=fopen($img['imagestorepath'].$img['imagepath'],'rb');
 		header('Content-Type: image/jpeg');
@@ -13,29 +13,29 @@ class dropimagefile extends dropimage {
 		exit;
 	}
 
-	public static function getByName($name): ?array {
+	public static function getByName(string $name): ?array {
 		return dropimage::getByName($name);
 	}
 
-	public static function getByNameLike($searchTerms, $request=array()): ?array {
+	public static function getByNameLike(string $searchTerms, array $request=[]): ?array {
 		return dropimage::getByNameLike($searchTerms, $request);
 	}
 
-	public static function getByProperty($key, $value, $request=array()): array {
+	public static function getByProperty(string $key, string $value, array $request=[]): array {
 		return dropimage::getByProperty($key, $value, $request);
 	}
 
-	public static function getByProperties(array $keyValuePairs, array $request=array()): array {
+	public static function getByProperties(array $keyValuePairs, array $request=[]): array {
 		return dropimage::getByProperties($keyValuePairs, $request);
 	}
 
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		throw new BadRequestException('Create a dropimage instead');
 	}
-	public static function update($id,$request=array()): array {
+	public static function update(int $id,array $request=[]): array {
 		throw new BadRequestException('Update the dropimage instead');
 	}
-	public static function delete($id): array {
+	public static function delete(int $id): array {
 		throw new BadRequestException('Delete the dropimage instead');
 	}
 	
