@@ -1,6 +1,6 @@
 <?php class imager extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
 		'friendlyname'=>validator::REQUIRED,
 		'manufacturer'=>validator::REQUIRED,
@@ -14,7 +14,7 @@
 		'isinuse'=>validator::BOOLEAN
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'A unique identifier for the imager',
 		'friendlyname'=>'A human-friendly name like "20-degree imager"',
 		'manufacturer'=>'The manufacturer name',
@@ -28,7 +28,7 @@
         'isinuse'=>'Whether the imager is installed. Set false when retiring the imager.'
 	);
 	
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		$project=project::getByName(baseproject::SHARED);
 		if(!$project){
 			throw new NotFoundException('Could not read shared project');
@@ -37,7 +37,17 @@
         return parent::createByClassName($request,'imager');
 	}
 
-    public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
         if(isset($request['isinuse']) && 0===1*$request['isinuse']){
             $plates=imager::getplates($id, $request);
             if(isset($plates['rows'])){
@@ -49,42 +59,36 @@
         return parent::update($id, $request);
     }
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getimagingsessions($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getimagingsessions(int $id, array $request=[]): ?array {
 		return imagingsession::getByProperty('imagerid', $id, $request);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getplates($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getplates(int $id, array $request=[]): ?array {
 		return plate::getByProperty('locationid', $id, $request);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getimagerloadlogs($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getimagerloadlogs(int $id, array $request=[]): ?array {
 		return imagerloadlog::getByProperty('imagerid', $id, $request);
 	}
 	
