@@ -1,6 +1,6 @@
 <?php class imagerloadlog extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
 		'imagerid'=>array(validator::REQUIRED, validator::INTEGER),
 		'loadingdate'=>array(validator::REQUIRED, validator::DATE),
@@ -8,7 +8,7 @@
 		'platesexpired'=>array(validator::REQUIRED, validator::INTEGER),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'A unique name for the log entry in the form imagerNNNNNN_YYYY-MM-DD',
 		'imagerid'=>'The imager',
 		'loadingdate'=>'The date of this imager loading record',
@@ -16,22 +16,22 @@
 		'platesexpired'=>'How many plates in the imager have no inspections scheduled',
 	);
 
-    /**
-     * @param array $request
-     * @return array|void
-     * @throws BadRequestException
-     */
-	public static function create(array $request=array()): array {
+	/**
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function create(array $request=[]): array {
 		throw new BadRequestException('Create not implemented on imagerloadlog. Call log() instead.');
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array|void
-     * @throws BadRequestException
-     */
-	public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function update(int $id, array $request=[]): array {
 		throw new BadRequestException('Update not implemented on imagerloadlog. Call log() instead.');
 	}
 
@@ -43,7 +43,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function log($request=array()){
+	public static function log(array $request=[]): array {
 		foreach(static::$fields as $k=>$v){
 			if('name'==$k){ continue; }
 			//just check they all exist. Full validation is done in parent create or update.
