@@ -1,13 +1,13 @@
 <?php class imagingparameters extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'manufacturer'=>validator::REQUIRED,
 			'manufacturerdatabaseid'=>array(validator::REQUIRED,validator::INTEGER),
 			'currentversionid'=>array(validator::INTEGER)
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this set of imaging parameters',
 			'manufacturer'=>'The name of the imager manufacturer',
 			'manufacturerdatabaseid'=>'The ID of this version in the imager manufacturer database',
