@@ -1,26 +1,25 @@
 <?php class imagingparametersversion extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'manufacturerdatabaseid'=>array(validator::REQUIRED,validator::INTEGER),
 			'imagingparametersid'=>array(validator::REQUIRED,validator::INTEGER)
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this set of imaging parameters',
 			'manufacturerdatabaseid'=>'The ID of this version in the imager manufacturer database',
 			'imagingparametersid'=>'The database ID of the parent Imaging Parameters, of which this is a version'
 	);
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function getimagersettings($id,$request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getimagersettings(int $id,array $request=[]): ?array {
 		return imagingsetting::getByProperty('imagingparametersversionid', $id, $request);
 	}
 	
