@@ -1,6 +1,6 @@
 <?php class imagingsession extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'temperature'=>array(validator::REQUIRED, validator::INTEGER),
 			'manufacturerdatabaseid'=>array(validator::REQUIRED,validator::INTEGER),
@@ -11,7 +11,7 @@
 			'lighttype'=>validator::REQUIRED,
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this plate type',
 			'temperature'=>'The incubation temperature',
 			'manufacturerdatabaseid'=>'The ID of this imaging session in the imager manufacturer database',
@@ -22,7 +22,7 @@
 			'lighttype'=>'Whether visible or UV light was used',
 	);
 	
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS imagingsession.*, 
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS imagingsession.*, 
 				plate.name AS platename, plate.description as platedescription, plate.platetypeid AS platetypeid, plate.ownerid AS plateownerid, user.fullname AS ownername,
 				plate.screenid AS screenid, plate.offsetinscreenx AS offsetinscreenx, plate.offsetinscreeny AS offsetinscreeny, 
 				plate.crystalscoringsystemid AS crystalscoringsystemid,
@@ -31,7 +31,7 @@
 				project.name AS projectname, project.isarchived AS isarchived
 			FROM imagingsession, plate, imager, project, user
 			WHERE project.id=imagingsession.projectid AND plate.id=imagingsession.plateid AND imager.id=imagingsession.imagerid AND user.id=plate.ownerid ';
-	protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS imagingsession.*, 
+	protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS imagingsession.*, 
 				plate.name AS platename, plate.description as platedescription, plate.platetypeid AS platetypeid, plate.ownerid AS plateownerid, user.fullname AS ownername,
 				plate.screenid AS screenid, plate.offsetinscreenx AS offsetinscreenx, plate.offsetinscreeny AS offsetinscreeny, 
 				plate.crystalscoringsystemid AS crystalscoringsystemid, 
@@ -54,7 +54,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		if(!isset($request['plateid'])){ throw new BadRequestException('No plate ID provided to imagingsession::create'); }
 		$plate=plate::getById($request['plateid']);
 		if(!$plate){ throw new BadRequestException('Could not find plate with ID '.$request['plateid']); }
@@ -75,7 +75,7 @@
         return parent::createByClassName($request,'imagingsession');
 	}
 
-	public static function update($id, $request=array()): array {
+	public static function update(int $id, array $request=[]): array {
 		if(isset($request['imagerid'])){
 			$imager=imager::getById($request['imagerid']);
 			$request['temperature']=$imager['temperature'];
@@ -92,7 +92,7 @@
      * @throws ServerException
      * @throws ForbiddenException
      */
-	public static function createWithDummyImages($plateId){
+	public static function createWithDummyImages(int $plateId): array {
 	    $plate=plate::getById($plateId);
 	    if(!$plate){ throw new BadRequestException('Could not find plate with ID '.$plateId); }
 	    
@@ -146,7 +146,7 @@
 	    return $dummyInspection;
 	}
 
-	public static function getByProperty($key, $value, $request = array()): ?array {
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 	    if("imagermanufacturer"===$key){
             if(session::isAdmin()){
                 $sqlStatement=static::$adminSelect;
@@ -164,17 +164,15 @@
         return parent::getByProperty($key, $value, $request);
     }
 
-    /**
-     * Returns the drop image records for the specified imaging session.
-     * @param int $id the ID of the imaging session
-     * @param array|null $request The request parameters, including any pagination or sort order requirements
-     * @return array an array containing the drop image records
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getdropimages($id,$request=array()){
+	/**
+	 * Returns the drop image records for the specified imaging session.
+	 * @param int $id the ID of the imaging session
+	 * @param array $request The request parameters, including any pagination or sort order requirements
+	 * @return array|null an array containing the drop image records
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getdropimages(int $id, array $request=[]): ?array {
 		return dropimage::getByProperty('imagingsessionid', $id, $request);
 	}
 
