@@ -1,6 +1,6 @@
 <?php class imagingsetting extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'imagingparametersversionid'=>array(validator::REQUIRED,validator::INTEGER),
 			'imagerid'=>array(validator::REQUIRED,validator::INTEGER),
@@ -8,7 +8,7 @@
 			'settingvalue'=>validator::REQUIRED,
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this combination of parameters version, imager and setting',
 			'imagingparametersversionid'=>'The ID of the parameters version',
 			'imagerid'=>'The imager',
