@@ -8,7 +8,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-    public static function create(array $request=array()): array {
+    public static function create(array $request=[]): array {
         if(session::isShipper() && !session::isAdmin()){
             session::becomeAdmin();
         }
