@@ -1,24 +1,24 @@
 <?php class pdbdeposition extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'rawdatadoi'=>validator::ANY
 	);
 
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'The PDB code',
 			'rawdatadoi'=>'A DOI or other location for the raw data'
 	);
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function getcrystals($id, $request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function getcrystals(int $id, array $request=[]): ?array {
 	    if(!static::getById($id)){
 	        throw new NotFoundException('That PDB does not exist, or you do not have permission to see it');
 	    }
@@ -40,16 +40,16 @@
     /*
      * Returns the PDB entry. Lower-case PDB codes are preferred, so we enforce that here.
      */
-    public static function getByName($name): ?array {
+    public static function getByName(string $name): ?array {
         return parent::getByName(strtolower($name));
     }
 
-    public static function getByProperty($key, $value, $request = array()): ?array {
+    public static function getByProperty(string $key, string $value, array $request=[]): ?array {
         if('name'==$key){ $value=strtolower($value); }
         return parent::getByProperty($key, $value, $request);
     }
 
-    public static function getByProperties(array $keyValuePairs, array $request = array()): ?array {
+    public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
         if(isset($keyValuePairs['name'])){
             $keyValuePairs['name']=strtolower($keyValuePairs['name']);
         }
@@ -59,7 +59,7 @@
     /*
      * Creates the PDB entry. Lower-case PDB codes are preferred, so we enforce that here.
      */
-    public static function create(array $request = array()): array {
+    public static function create(array $request=[]): array {
 	    $request['name']=strtolower($request['name']);
         return parent::create($request);
     }
