@@ -1,6 +1,6 @@
 <?php class plate extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'description'=>validator::ANY,
 			'platetypeid'=>array(validator::REQUIRED, validator::INTEGER),
@@ -19,7 +19,7 @@
             'bestcrystalscoreid'=>validator::INTEGER
     );
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this plate, typically its barcode',
 			'description'=>'A short description of this plate',
 			'platetypeid'=>'The type of plate used',
@@ -33,7 +33,7 @@
 	        'datedestroyed'=>'When the plate was destroyed'
 	);
 
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS plate.*,project.name AS projectname, project.isarchived AS isarchived, 
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS plate.*,project.name AS projectname, project.isarchived AS isarchived, 
 			platetype.name AS platetypename, platetype.dropmapping as dropmapping, platetype.rows AS `rows`, platetype.cols AS cols, platetype.subs AS subs, user.fullname AS ownername,
 			crystalscore.label as bestscorelabel, crystalscore.scoreindex as bestscoreindex, crystalscore.color as bestscorecolor
 			FROM plate
@@ -42,7 +42,7 @@
 			JOIN user ON user.id=plate.ownerid
 			LEFT JOIN crystalscore ON plate.bestcrystalscoreid=crystalscore.id
 			WHERE 1=1 ';
-	protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS plate.*,project.name AS projectname, project.isarchived AS isarchived, 
+	protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS plate.*,project.name AS projectname, project.isarchived AS isarchived, 
 			platetype.name AS platetypename, platetype.dropmapping as dropmapping, platetype.rows AS `rows`, platetype.cols AS cols, platetype.subs AS subs, user.fullname AS ownername,
 			crystalscore.label as bestscorelabel, crystalscore.scoreindex as bestscoreindex, crystalscore.color as bestscorecolor
 			FROM plate
@@ -53,7 +53,7 @@
 			WHERE 1=1 ';
 	
 	
-    protected static $searchClause='CONCAT(plate.name,": ",plate.description)';
+    protected static string $searchClause='CONCAT(plate.name,": ",plate.description)';
 
 	protected static function getProjectClause(string $accessType, bool $forceSharedProject=false): string {
 		if('readOne'===$accessType){
@@ -79,7 +79,7 @@
      * @throws BadRequestException
 	 * @throws ServerException
      */
-	public static function getById($id): ?array {
+	public static function getById(int $id): ?array {
         $plate=parent::getById($id);
 		if(!$plate){ return $plate; }
 		return static::addImagingStatusByDropPositionNumber($plate);
@@ -91,13 +91,13 @@
      * @throws BadRequestException
 	 * @throws ServerException
      */
-    public static function getByName($name): ?array {
+    public static function getByName(string $name): ?array {
         $plate=parent::getByName($name);
         if(!$plate){ return $plate; }
 		return static::addImagingStatusByDropPositionNumber($plate);
     }
 
-    public static function getByProperty($key, $value, $request = array()): ?array {
+    public static function getByProperty(string $key, string $value, array $request=[]): ?array {
         $plates=parent::getByProperty($key, $value, $request);
         if(!$plates || 1!=$plates['total']){
             return $plates;
@@ -106,13 +106,13 @@
         return $plates;
     }
 
-    /**
-     * @param $plate
-     * @return mixed
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    private static function addImagingStatusByDropPositionNumber($plate){
+	/**
+	 * @param array $plate
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    private static function addImagingStatusByDropPositionNumber(array $plate): array {
         $numDrops=1*$plate['subs'];
         $plate['isimaged']=false;
         $plate['isimagedbydropposition']=array();
@@ -149,7 +149,7 @@
      * @throws NotFoundException
      * @throws ServerException
 	 */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		$ret=parent::createByClassName($request,'plate');
 		if(!$ret){ throw new ServerException('Could not create plate'); }
 		$plate=$ret['created'];
@@ -194,7 +194,7 @@
      * @throws NotModifiedException
      * @throws ServerException
      */
-	public static function update($id, $request=array()): array {
+	public static function update(int $id, array $request=[]): array {
 		$plate=static::getById($id);
 
 		if(isset($request['datedestroyed'])){
@@ -289,7 +289,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function delete($id): array {
+	public static function delete(int $id): array {
 		if(!self::canDelete($id)){
 			throw new ForbiddenException('Either this plate does not exist or you do not have permission to delete it');
 		}
@@ -298,17 +298,16 @@
 		return array('deleted'=>$id);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws BadRequestException
-     * @noinspection PhpUnused
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function getconstructs($id,$request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 * @noinspection PhpUnusedParameterInspection
+	 */
+	public static function getconstructs(int $id, array $request=[]): ?array {
 		$plate=static::getById($id);
 		if(!$plate){ throw new NotFoundException('Plate not found'); }
 		$sqlStatement='SELECT welldrop.constructid 
@@ -330,30 +329,28 @@
 		return $ret;
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getplatewells($id,$request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getplatewells(int $id, array $request=[]): ?array {
 		$request['all']=1;
 		$request['sortby']='name';
 		return platewell::getByProperty('plateid', $id, $request);
 	}
 
-    /**
-     * Gets all the drops in the plate.
-     * @param int $id The plate ID.
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-	public static function getwelldrops($id,$request=array()){
+	/**
+	 * Gets all the drops in the plate.
+	 * @param int $id The plate ID.
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getwelldrops(int $id, array $request=[]): ?array {
 		$request['all']=1;
 		$request['sortby']='name';
 		$sqlStatement='SELECT platewell.row AS `row`, platewell.col AS `col`, welldrop.id AS id,
@@ -390,43 +387,40 @@
 		return $drops;
 	}
 
-    /**
-     * Gets the crystals for the plate.
-     * @param int $id The plate ID.
-     * @param array $request The request parameters, e.g., pagination.
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getcrystals($id,$request=array()){
+	/**
+	 * Gets the crystals for the plate.
+	 * @param int $id The plate ID.
+	 * @param array $request The request parameters, e.g., pagination.
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function getcrystals(int $id, array $request=[]): ?array {
 		return crystal::getByProperty('plateid', $id, $request);
 	}
 
-    /**
-     * Gets the imaging sessions for the plate.
-     * @param int $id The plate ID.
-     * @param array $request The request parameters, e.g., pagination.
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getimagingsessions($id,$request=array()){
+	/**
+	 * Gets the imaging sessions for the plate.
+	 * @param int $id The plate ID.
+	 * @param array $request The request parameters, e.g., pagination.
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getimagingsessions(int $id, array $request=[]): ?array {
 		return imagingsession::getByProperty('plateid', $id, $request);
 	}
 
-    /**
-     * Sets the project ID for the plate, and for its child wells, drops, imaging sessions, images, crystals, and scores.
-     * @param $plateId
-     * @param $projectId
-     * @throws BadRequestException
-     * @throws ServerException
-     * @throws NotFoundException
-     */
-	private static function setProjectId($plateId,$projectId){
+	/**
+	 * Sets the project ID for the plate, and for its child wells, drops, imaging sessions, images, crystals, and scores.
+	 * @param int $plateId
+	 * @param int $projectId
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	private static function setProjectId(int $plateId,int $projectId): void {
 		$result1=database::queryGetAll('SELECT plate.id as pid, platewell.id AS wid, welldrop.id AS did 
 				FROM plate 
 				LEFT JOIN platewell ON platewell.plateid=plate.id 
@@ -469,7 +463,7 @@
 		plate::updateFileNoteAndRecordingProjectIds($plateId);
 	}
 
-    public static function updateFileNoteAndRecordingProjectIds($parentId){
+    public static function updateFileNoteAndRecordingProjectIds(int $parentId): void {
 	    parent::updateFileNoteAndRecordingProjectIds($parentId);
     }
 
@@ -479,10 +473,9 @@
      * @param int $id The ID of the plate.
      * @return bool true if the user can delete the plate, otherwise false.
      * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
+	 * @throws ServerException
      */
-	public static function canDelete($id): bool {
+	public static function canDelete(int $id): bool {
 		if(parent::canDelete($id)){ return true; }
 		$plate=plate::getById($id);
 		if($plate['ownerid']==session::getUserId()){
@@ -491,17 +484,15 @@
 		return false;
 	}
 
-    /**
-     * Gets the best scores for all drops in the plate.
-     * @param int $id The plate ID.
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getdropbestscores($id,$request=array()){
+	/**
+	 * Gets the best scores for all drops in the plate.
+	 * @param int $id The plate ID.
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getdropbestscores(int $id, array $request=[]): ?array {
 		$plate=static::getById($id);
 		$scoringSystemId=$plate['crystalscoringsystemid'];
 		$scores=crystalscoringsystem::getscores($scoringSystemId);
@@ -542,7 +533,7 @@
      * @throws NotModifiedException
      * @throws ServerException
      */
-	private static function updateDestroyed($plateId, $dateDestroyed){
+	private static function updateDestroyed(int $plateId, string $dateDestroyed): array {
 	    if(!static::canUpdateDestroyed($plateId)){
 	        throw new ForbiddenException('Either the plate does not exist, or you do not have permission to update its status.');
 	    }
@@ -597,7 +588,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	private static function canUpdateDestroyed($plateId){
+	private static function canUpdateDestroyed(int $plateId): bool {
 	    if(session::isAdmin() || session ::isTechnician() || session::isPlateDestroyer()){ return true; }
 	    $result=database::queryGetOne(
 	           'SELECT ownerid FROM plate WHERE id=:id',
@@ -622,7 +613,7 @@
      * @throws ServerException
      * @noinspection PhpUnused
      */
-	public static function destroyByName($name, $request=array()){
+	public static function destroyByName(string $name, array $request=[]): array {
         $dateDestroyed=gmdate('Y-m-d');
 	    if(isset($request['datedestroyed'])){
 	        $dateDestroyed=$request['datedestroyed'];
@@ -637,16 +628,16 @@
 	    return plate::updateDestroyed($plate['id'], $dateDestroyed);
 	}
 
-    /**
-     * @param $plateId
-     * @return void
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws NotModifiedException
-     * @throws ServerException
-     */
-    public static function calculateBestScores($plateId){
+	/**
+	 * @param int $plateId
+	 * @return void
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws NotModifiedException
+	 * @throws ServerException
+	 */
+    public static function calculateBestScores(int $plateId): void {
         $plateBestScoreId=database::$nullValue;
         $plateBestProbabilityPercent=database::$nullValue;
 
