@@ -19,7 +19,7 @@
      * @throws ServerException
      * @noinspection PhpUnusedParameterInspection
      */
-    public static function getById($id){
+    public static function getById(int $id): ?array {
         throw new ServerException(self::GET_BY_ID_NOT_IMPLEMENTED_ON_PLATEREIMPORTQUEUE);
     }
 
@@ -28,29 +28,29 @@
      * @throws ServerException
      * @noinspection PhpUnusedParameterInspection
      */
-    public static function getByName($name){
+    public static function getByName(string $name): ?array {
         throw new ServerException(self::GET_BY_NAME_NOT_IMPLEMENTED_ON_PLATEREIMPORTQUEUE);
     }
 
     /**
      * @throws ServerException
      */
-    public static function getAll(){
+    public static function getAll(): ?array {
         throw new ServerException(self::GET_ALL_NOT_IMPLEMENTED_ON_PLATEREIMPORTQUEUE);
     }
 
-    /**
-     * @param $plateId
-     * @return array|bool
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    public static function getByPlateId($plateId){
+	/**
+	 * @param int $plateId
+	 * @return array|bool
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    public static function getByPlateId(int $plateId): ?array {
         $item=database::queryGetOne('SELECT p.ownerid AS ownerid,q.* from plate as p, platereimportqueue AS q 
             WHERE p.id=q.plateid AND q.plateid=:plateid', array(':plateid'=>$plateId));
-        if(!$item){ return false; }
+        if(!$item){ return null; }
         if(session::isAdmin() || $item['ownerid']==session::getUserId()){ return $item; }
-        return false;
+        return $item;
     }
 
 	/**
@@ -87,15 +87,14 @@
         return array('created'=>$newItem);
     }
 
-    /**
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     * @throws NotFoundException
-     */
-    public static function delete($id){
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws ServerException
+	 */
+    public static function delete(int $id): array {
         if(empty($id)){ return array(); }
         $item=database::queryGetOne('SELECT * from platereimportqueue WHERE id=:id', array(':id'=>$id));
         if(!$item){
@@ -115,7 +114,7 @@
      * @throws BadRequestException
      * @throws ServerException
      */
-    public static function getOldestQueueItem($barcodePattern=''){
+    public static function getOldestQueueItem(string $barcodePattern=''): ?array {
         if(!preg_match('/^[ALN_-]*$/', strtoupper($barcodePattern))){
             throw new ServerException(self::BAD_BARCODE_PATTERN_IN_GET_OLDEST_QUEUE_ITEM);
         }
