@@ -1,6 +1,6 @@
 <?php class platetype extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'rows'=>array(validator::REQUIRED, validator::INTEGER),
 			'cols'=>array(validator::REQUIRED, validator::INTEGER),
@@ -9,7 +9,7 @@
 			'defaultdropsize'=>array(validator::ANY),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this plate type',
 			'rows'=>'How many rows of wells these plates have',
 			'cols'=>'How many columns of wells these plates have',
@@ -18,13 +18,14 @@
 			'defaultdropsize'=>'The default size of the drop, e.g., 0.2nL',
 	);
 	
-	public static $rowLabels=array('-','A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z');
+	public static array $rowLabels=array('-','A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z');
 
-    /**
-     * @return bool
-     * @throws BadRequestException
-     * @throws NotFoundException
-     */
+	/**
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
 	public static function canCreate(): bool {
 		if(session::isAdmin()){ return true; }
 		$grp=usergroup::getByName(usergroup::TECHNICIANS);
