@@ -2,35 +2,35 @@
 
 class platewell extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'plateid'=>array(validator::REQUIRED, validator::INTEGER),
 			'row'=>array(validator::REQUIRED, validator::INTEGER),
 			'col'=>array(validator::REQUIRED, validator::INTEGER),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this plate well',
 			'plateid'=>'The parent plate',
 			'row'=>'Row number',
 			'col'=>'Column number',
 	);
 	
-	private static $rowLabels='-ABCDEFGHIJKLMNOPQRSTUVWXYZ';
+	private static string $rowLabels='-ABCDEFGHIJKLMNOPQRSTUVWXYZ';
 
     /**
      * @return string
      * @noinspection PhpUnused
      */
-	public static function getRowLabels(){
+	public static function getRowLabels(): string {
 		return static::$rowLabels;
 	}
 	
-	public static function getWellLabel($rowNumber, $colNumber){
+	public static function getWellLabel(int $rowNumber, int $colNumber): string {
 		return self::$rowLabels[(int)$rowNumber].str_pad($colNumber,2,'0',STR_PAD_LEFT);
 	}
 	
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		if(!isset($request['plateid'])){ throw new BadRequestException('No plate ID supplied to platewell::create'); }
 		$plate=plate::getById($request['plateid']);
 		if(!isset($request['name'])){
