@@ -1,26 +1,27 @@
 <?php class protein extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'description'=>validator::REQUIRED,
             'proteinacronym'=>validator::ANY
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this protein',
 			'proteinacronym'=>'Short code, 3-5 characters. Identifies the protein for synchrotron safety purposes',
 			'description'=>'Short description of this protein',
 	);
 	
-	public static $defaultSortOrder='name ASC';
+	public static string $defaultSortOrder='name ASC';
 
-    /**
-     * Whether the user has permission to create a protein in at least one project. As currently implemented, this
-     * should be administrators, technicians and project owners.
-     * @return bool true if this user can create proteins, otherwise false.
-     * @throws BadRequestException
-     * @throws NotFoundException if the Technicians usergroup does not exist.
-     */
+	/**
+	 * Whether the user has permission to create a protein in at least one project. As currently implemented, this
+	 * should be administrators, technicians and project owners.
+	 * @return bool true if this user can create proteins, otherwise false.
+	 * @throws BadRequestException
+	 * @throws NotFoundException if the Technicians usergroup does not exist.
+	 * @throws ServerException
+	 */
 	public static function canCreate(): bool {
 		if(session::isAdmin()){ return true; }
 		$grp=usergroup::getByName(usergroup::TECHNICIANS);
@@ -42,7 +43,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		if(!session::isAdmin()){
 			$project=project::getById($request['projectid']);
 			if(!$project){
@@ -69,11 +70,10 @@
      * @param array $request Request parameters such as pagination
      * @return array
      * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
+	 * @throws ServerException
      * @noinspection PhpUnused
      */
-	public static function getconstructs($id,$request=array()){
+	public static function getconstructs(int $id, array $request=[]): array {
 		return construct::getByProperty('proteinid',$id,$request);
 	}
 
