@@ -1,6 +1,6 @@
 <?php class screen extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'manufacturer'=>validator::ANY,
 			'catalognumber'=>validator::ANY,
@@ -8,7 +8,7 @@
             'isavailable'=>validator::BOOLEAN
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this screen',
 			'manufacturer'=>'The manufacturer of the screen',
 			'catalognumber'=>'Manufacturer\'s catalogue number',
@@ -16,7 +16,7 @@
             'isavailable'=>'Whether this screen is available for use (affects standard screens only)'
 	);
 
-	public static $defaultSortOrder='screen.isstandard DESC, name ASC';
+	public static string $defaultSortOrder='screen.isstandard DESC, name ASC';
 	
 	private static array $rowLabels=array('-','A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z');
 	
@@ -58,7 +58,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function canUpdate($id): bool {
+	public static function canUpdate(int $id): bool {
 		 if(parent::canUpdate($id)){ return true; }
 		 $groupId=usergroup::getByName(usergroup::TECHNICIANS);
 		 return usergroup::userisingroup($groupId);
@@ -73,7 +73,7 @@
      * @throws NotModifiedException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 
         //Is this a standard screen or an optimization screen?
         if (isset($request['projectid'])) {
@@ -152,14 +152,14 @@
         return $screen;
     }
 
-    /**
-     * @param $filePath
-     * @param $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ServerException
-     */
-    private static function parseScreenFile($filePath, $request): array {
+	/**
+	 * @param string $filePath
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+    private static function parseScreenFile(string $filePath, array $request): array {
 
         $fileContent=@file_get_contents($filePath);
         if(!$fileContent){
@@ -192,16 +192,16 @@
     }
 
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
 	 * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function update($id, $request=array()): array {
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
 		if(isset($request['isstandard']) && $request['isstandard']){
 			$sharedProject=project::getByName(baseproject::SHARED);
 			if(!$sharedProject){
@@ -224,42 +224,41 @@
 		return parent::update($id,$request);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
 	 * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getscreenconditions($id, array $request=array()): array {
+	 */
+	public static function getscreenconditions(int $id, array $request=[]): array {
 		$ret=screencondition::getByProperty('screenid', $id, $request);
 		$screen=static::getById($id);
 		$ret['screen']=$screen;
 		return $ret;
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array|null
-     * @throws BadRequestException
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
 	 * @throws ServerException
-     */
-    public static function getplates($id, array $request=array()): ?array {
+	 */
+    public static function getplates(int $id, array $request=[]): ?array {
 	    return plate::getByProperty('screenid', $id, $request);
     }
 
-    /**
-     * Deletes a screen. This will fail if any plate is using the screen; unset the screen from the plate(s) first.
-     * @param $id
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-    public static function delete($id): array {
+	/**
+	 * Deletes a screen. This will fail if any plate is using the screen; unset the screen from the plate(s) first.
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+    public static function delete(int $id): array {
         $screen=static::getById($id);
         if(!$screen){
             throw new BadRequestException('No screen with ID '.$id.', cannot delete');
@@ -306,12 +305,12 @@
         return array("deleted"=>$deleted);
     }
 
-    /**
-     * @param $fileContent
-     * @return array
-     * @throws BadRequestException
-     */
-    private static function parseCsvFile($fileContent): array {
+	/**
+	 * @param string $fileContent
+	 * @return array
+	 * @throws BadRequestException
+	 */
+    private static function parseCsvFile(string $fileContent): array {
         $delimiter=static::determineCsvDelimiter($fileContent);
         $fileContent=preg_split("/\r\n|\n|\r/", $fileContent);
         $firstRow=str_getcsv($fileContent[0], $delimiter);
@@ -337,12 +336,12 @@
         return $ret;
     }
 
-    /**
-     * @param $fileContent
-     * @return array
-     * @throws BadRequestException
-     */
-	private static function parseCrystalTrakXml($fileContent): array {
+	/**
+	 * @param string $fileContent
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	private static function parseCrystalTrakXml(string $fileContent): array {
 		$xml=simplexml_load_string($fileContent);
 		if(!$xml){ throw new BadRequestException('Detected CrystalTrak XML file but it was not valid XML'); }
 		if(!empty($xml->reservoir_design) && !empty($xml->reservoir_design->format->attributes())){
@@ -521,12 +520,12 @@
         );
 	}
 
-    /**
-     * @param $fileContent
-     * @return array
-     * @throws BadRequestException
-     */
-	private static function parseMimerCsv($fileContent): array {
+	/**
+	 * @param string|array $fileContent
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	private static function parseMimerCsv(string|array $fileContent): array {
 		/* Example CSV format: note that the column order may be different and row 1 may not have the numbers.
 		Incomplete factorial,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
 		Reagent number,PEG 8000,[PEG 8000],[PEG 8000] units,pH_PEG 8000,calcium acetate,[calcium acetate],[calcium acetate] units,pH_calcium acetate,calcium acetate,[calcium acetate],[calcium acetate] units,pH_calcium acetate,"bistris propane, pH7","[bistris propane, pH7]","[bistris propane, pH7] units","pH_bistris propane, pH7","cacodylate, pH 6.5","[cacodylate, pH 6.5]","[cacodylate, pH 6.5] units","pH_cacodylate, pH 6.5",,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
@@ -789,16 +788,14 @@
         );
 	}
 
-    /**
-     * @param $rows
-     * @param $cols
-     * @param $dummyText
-     * @return array
-     * @throws BadRequestException
-     */
-	private static function makeDummyScreenConditions($rows, $cols, $dummyText): array {
-	    $rows=(int)$rows;
-	    $cols=(int)$cols;
+	/**
+	 * @param int $rows
+	 * @param int $cols
+	 * @param string $dummyText
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	private static function makeDummyScreenConditions(int $rows, int $cols, string $dummyText): array {
 	    if(1>$rows || 1>$cols){
 	        throw new BadRequestException('Bad row/column count in makeDummyScreenConditions');
         }
