@@ -1,6 +1,6 @@
 <?php class screencondition extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'wellnumber'=>array(validator::REQUIRED,validator::INTEGER),
 			'row'=>array(validator::REQUIRED,validator::INTEGER),
@@ -9,7 +9,7 @@
 			'description'=>validator::REQUIRED,
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this screen condition',
 			'wellnumber'=>'The well number (typically 1-96)',
 			'row'=>'The plate row',
@@ -18,7 +18,7 @@
 			'description'=>'A human-readable description of the condition',
 	);
 	
-	public static $defaultSortOrder='wellnumber ASC, `row` ASC, `col` ASC';
+	public static string $defaultSortOrder='wellnumber ASC, `row` ASC, `col` ASC';
 
     /**
      * @param array $request
@@ -28,21 +28,21 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		$screen=screen::getById($request['screenid']);
 		$projectId=$screen['projectid'];
 		$request['projectid']=$projectId;
 		return parent::create($request);
 	}
 
-    /**
-     * @param $id
-     * @return bool
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws BadRequestException
-     */
-	public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function canUpdate(int $id): bool {
 		return screen::canUpdate($id);
 	}
 	
