@@ -1,20 +1,20 @@
 <?php class sequence extends protein { //Extend protein, which extends baseobject - same restrictions on canCreate
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'constructid'=>array(validator::REQUIRED, validator::INTEGER),
 			'dnasequence'=>array(validator::DNASEQUENCE),
 			'proteinsequence'=>array(validator::PROTEINSEQUENCE),
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this protein',
 			'constructid'=>'The database ID of the parent construct',
 			'dnasequence'=>'The DNA sequence',
 			'proteinsequence'=>'The protein sequence',
 	);
 	
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 		if(!isset($request['constructid'])){ throw new BadRequestException('No parent construct specified'); }
 		$con=construct::getById($request['constructid']); //NotFoundException if user can't read it
 		if(!session::isAdmin()){
@@ -28,7 +28,7 @@
 		}
 		$request['projectid']=$con['projectid'];
 		static::checkSequences($request);
-		if(!isset($request['proteinsequence']) ||empty($request['proteinsequence'])){
+		if(empty($request['proteinsequence'])){
 		    $request['proteinsequence']=static::dnaToProtein($request['dnasequence']);
 		}
 		$created=baseobject::createByClassName($request,'sequence');
@@ -38,29 +38,28 @@
 		);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws ServerException
-     */
-	public static function update($id, $request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
 		static::checkSequences($request);
 		return parent::update($id,$request);
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getsequences($id,$request=array()){
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getsequences(int $id,array $request=[]): ?array {
 		return sequence::getByProperty('constructid',$id,$request);
 	}
 	
@@ -84,12 +83,12 @@
 		}
 	}
 
-    /**
-     * Given a DNA sequence, returns the protein sequence, or false on failure.
-     * @param string $seq The DNA sequence
-     * @return bool|string|string[]|null
-     */
-	public static function dnaToProtein($seq){
+	/**
+	 * Given a DNA sequence, returns the protein sequence, or false on failure.
+	 * @param string $seq The DNA sequence
+	 * @return string|bool
+	 */
+	public static function dnaToProtein(string $seq): string|bool {
 		//Strip all whitespace and explode into 3-character segments (codons)
 		$seq=strtoupper(preg_replace('/\s/', '', $seq));
 		$dnaParts=array();
@@ -110,7 +109,7 @@
 		return preg_replace('/_/', '', $seq);
 	}
 	
-	private static $codonToAmino=array(
+	private static array $codonToAmino=array(
 		"ATT"=>"I", "ATC"=>"I", "ATA"=>"I", "CTT"=>"L", "CTC"=>"L", "CTA"=>"L", "CTG"=>"L", "TTA"=>"L",
 		"TTG"=>"L", "GTT"=>"V", "GTC"=>"V", "GTA"=>"V", "GTG"=>"V", "TTT"=>"F", "TTC"=>"F", "ATG"=>"M",
 		"TGT"=>"C", "TGC"=>"C", "GCT"=>"A", "GCC"=>"A", "GCA"=>"A", "GCG"=>"A", "GGT"=>"G", "GGC"=>"G",
