@@ -2,7 +2,7 @@
 
 class shipment extends baseobject {
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
 	    'shipmentdestinationid'=>array(validator::REQUIRED, validator::INTEGER),
 	    'idatremotefacility'=>validator::ALPHANUMERIC_PLUS_UNDERSCORE, //but most likely numeric. Just want to catch malicious URI hackery.
@@ -17,7 +17,7 @@ class shipment extends baseobject {
 	    'manifest'=>validator::ANY
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'The name of the shipment',
 	    'shipmentdestinationid'=>'Where the shipment is sent',
 	    'idatremotefacility'=>'The ID of this shipment at the remote facility',
@@ -27,14 +27,14 @@ class shipment extends baseobject {
 	    'shipperid'=>'The local person responsible for the shipment'
 	);
 	
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS shipment.*, shipmentdestination.name AS shipmentdestinationname,
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS shipment.*, shipmentdestination.name AS shipmentdestinationname,
                     user.fullname as shippername
             FROM shipment, shipmentdestination, user, project
             WHERE shipment.shipmentdestinationid=shipmentdestination.id
                 AND shipment.shipperid=user.id
                 AND shipment.projectid=project.id
         ';
-	protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS shipment.*, shipmentdestination.name AS shipmentdestinationname,
+	protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS shipment.*, shipmentdestination.name AS shipmentdestinationname,
                     user.fullname as shippername
             FROM shipment, shipmentdestination, user, project
             WHERE shipment.shipmentdestinationid=shipmentdestination.id
@@ -42,7 +42,7 @@ class shipment extends baseobject {
                 AND shipment.projectid=project.id
         ';
 	
-	public static function getById($id): array {
+	public static function getById(int $id): ?array {
 	    $shipment=parent::getById($id);
 	    if(!empty($shipment['manifest'])){
 	        $shipment['manifest']=static::parseAndSanitizeManifest($shipment['manifest']);
@@ -50,7 +50,8 @@ class shipment extends baseobject {
 		$shipment['beamlines']=static::getCollectionBeamlines($id);
 	    return $shipment;
 	}
-	public static function getByName($name): array {
+
+	public static function getByName(string $name): ?array {
 	    $shipment=parent::getByName($name);
 	    if(!empty($shipment['manifest'])){
 	        $shipment['manifest']=static::parseAndSanitizeManifest($shipment['manifest']);
@@ -58,23 +59,27 @@ class shipment extends baseobject {
 		$shipment['beamlines']=static::getCollectionBeamlines($shipment['id']);
 	    return $shipment;
 	}
-    public static function getAll(array $request=array()): array {
+
+	public static function getAll(array $request=[]): ?array {
         $results=parent::getAll($request);
         return static::stripManifestsFromMultipleResults($results);
     }
-    public static function getByNameLike(string $searchTerms, array $request=array()): array {
+
+    public static function getByNameLike(string $searchTerms, array $request=[]): array {
         $results=parent::getByNameLike($searchTerms, $request);
         return static::stripManifestsFromMultipleResults($results);
     }
-    public static function getByProperties(array $keyValuePairs, array $request=array()): array {
+
+    public static function getByProperties(array $keyValuePairs, array $request=[]): array {
         $results=parent::getByProperties($keyValuePairs, $request);
         return static::stripManifestsFromMultipleResults($results);
     }
-    public static function getByProperty($key, $value, $request=array()): array {
+
+    public static function getByProperty(string $key, string $value, array $request=[]): array {
         $results=parent::getByProperty($key, $value, $request);
         return static::stripManifestsFromMultipleResults($results);
     }
-    private static function stripManifestsFromMultipleResults($results){
+    private static function stripManifestsFromMultipleResults(array $results): array {
         if(empty($results)){ return $results; }
         foreach($results['rows'] as &$row){
             unset($row['manifest']);
@@ -82,11 +87,12 @@ class shipment extends baseobject {
         return $results;
     }
 
-    /**
-     * @return bool
-     * @throws BadRequestException
-     * @throws NotFoundException
-     */
+	/**
+	 * @return bool
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
     public static function canCreate(): bool {
 		if(session::isAdmin()){ return true; }
 		$grp=usergroup::getByName(usergroup::TECHNICIANS);
@@ -96,13 +102,14 @@ class shipment extends baseobject {
 		return false;
 	}
 
-    /**
-     * @param $id
-     * @return bool
-     * @throws NotFoundException
-     * @throws BadRequestException
-     */
-	public static function canUpdate($id): bool	{
+	/**
+	 * @param $id
+	 * @return bool
+	 * @throws NotFoundException
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function canUpdate(int $id): bool	{
 	    return static::canCreate();
 	}
 
@@ -114,7 +121,7 @@ class shipment extends baseobject {
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 	    $sharedProject=project::getByName(baseproject::SHARED);
 		if(!$sharedProject){
 			throw new NotFoundException('Could not read shared project');
@@ -161,7 +168,7 @@ class shipment extends baseobject {
 	    return $shipment;
 	}
 
-	private static function getMxlimsJson($shipment) {
+	private static function getMxlimsJson(array $shipment): string {
 		include_once __DIR__.'/../../vendor/mxlims/ShipmentEncoder/src/v0_6_7ShipmentEncoder.php';
 		try {
 			$encoder=new mxlims\tools\php\ShipmentEncoder\src\v0_6_7ShipmentEncoder();
@@ -215,16 +222,16 @@ class shipment extends baseobject {
 		}
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	public static function update($id,$request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function update(int $id, array $request=[]): array {
 	    $shipment=static::getById($id);
 	    if(!$shipment){ throw new NotFoundException('No shipment with ID '.$id); }
 		if(isset($request['getMxlims'])){
@@ -302,17 +309,15 @@ class shipment extends baseobject {
         return $response;
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @return array|mixed
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @throws Exception
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function getcontainers($id, $request=array()) {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array|mixed
+	 * @throws BadRequestException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function getcontainers(int $id, array $request=[]): ?array {
 	    $shipment=static::getById($id);
 	    if(!empty($shipment['manifest'])){
 	        return $shipment['manifest'];
@@ -337,7 +342,7 @@ class shipment extends baseobject {
 	    return $ret;
 	}
 
-	private static function getCollectionBeamlines($id) {
+	private static function getCollectionBeamlines(int $id): array  {
 		$beamlines=database::queryGetAll('SELECT DISTINCT bl.id AS id, bl.name AS name
 				FROM diffractionrequest AS dr,dataset AS ds, beamline AS bl 
 				WHERE dr.shipmentid=:shipmentid AND ds.diffractionrequestid=dr.id AND ds.beamlineid=bl.id			
@@ -353,41 +358,39 @@ class shipment extends baseobject {
      * @param $manifest
      * @return array
      */
-	private static function parseAndSanitizeManifest($manifest): array {
+	private static function parseAndSanitizeManifest(string $manifest): array {
 		//TODO Replace anything where projectid is not in read-projects with (hidden)
         //if(!session::isAdmin()){
         //}
 	    return json_decode($manifest,true);
 	}
 
-    /**
-     * Allows for retrieving manifest PDF over HTTP via API call shipment/NNN/manifestpdf
-     * @param $id
-     * @param array $request
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     * @noinspection PhpUnusedParameterInspection
-     */
-	public static function getmanifestpdfs($id,$request=array()){
+	/**
+	 * Allows for retrieving manifest PDF over HTTP via API call shipment/NNN/manifestpdf
+	 * @param int $id
+	 * @param array $request
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	public static function getmanifestpdfs(int $id, array $request=[]): void {
 	    static::generateManifestPdf($id);
 	}
 
 
-    /**
-     * Uses the third-party FPDF library to generate a PDF containing the contents of the shipment, suitable for
-     * note-taking during the data collection.
-     * @param $id
-     * @param bool $saveAsIceBearFile
-     * @return int|string the saved file ID if saving to file, otherwise streams the PDF to the browser.
-     * @throws BadRequestException
-     * @throws ForbiddenException
-     * @throws NotFoundException
-     * @throws ServerException
-     */
-	private static function generateManifestPdf($id, bool $saveAsIceBearFile=false): int|string {
+	/**
+	 * Uses the third-party FPDF library to generate a PDF containing the contents of the shipment, suitable for
+	 * note-taking during the data collection.
+	 * @param int $id
+	 * @param bool $saveAsIceBearFile
+	 * @return void the saved file ID if saving to file, otherwise streams the PDF to the browser.
+	 * @throws BadRequestException
+	 * @throws ForbiddenException
+	 * @throws NotFoundException
+	 * @throws ServerException
+	 */
+	private static function generateManifestPdf(int $id, bool $saveAsIceBearFile=false): void {
 	    $shipment=static::getById($id);
 	    if(!$shipment){
 	        throw new NotFoundException('No shipment with ID '.$id);
@@ -629,8 +632,7 @@ class shipment extends baseobject {
 	        ));
 	        $file=$file['created'];
 	        session::revertAdmin();
-	        return $file['id'];
-	    } else {
+		} else {
 	        $pdf->Output();
 	        database::commit();
 	        exit();
@@ -639,7 +641,6 @@ class shipment extends baseobject {
 	}
 
 	/**
-	 * @throws NotFoundException
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
