@@ -1,6 +1,6 @@
 <?php class shipmentdestination extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 		'name'=>validator::REQUIRED,
         'ismanaged'=>validator::BOOLEAN,
         'isavailable'=>validator::BOOLEAN,
@@ -11,7 +11,7 @@
         'geofence'=>validator::GEOFENCE
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 		'name'=>'The name of the shipment destination',
         'ismanaged'=>'Whether IceBear creates and maintains this synchrotron automatically',
         'isavailable'=>'Whether this synchrotron is available as a destination for shipments in IceBear',
@@ -30,7 +30,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function create(array $request=array()): array {
+	public static function create(array $request=[]): array {
 	    if(!static::canCreate()){ throw new ForbiddenException('You cannot create shipment destinations'); }
 	    $request['projectid']=project::getSharedProjectId();
 	    $created=parent::createByClassName($request, 'shipmentdestination');
@@ -40,7 +40,7 @@
         return $created;
 	}
 
-    public static function update($id, $request = array()): array {
+    public static function update(int $id, $request=[]): array {
         $updated=parent::update($id, $request);
         if((isset($request['name']) && 'home'==strtolower($request['name'])) || (isset($request['ishome']) && 1===1*$request['ishome'])){
             shipmentdestination::setHome($id);
@@ -51,8 +51,8 @@
     /**
      * @return bool
      * @throws BadRequestException
-     * @throws NotFoundException
-     */
+     * @throws NotFoundException|ServerException
+	 */
 	public static function canCreate(): bool {
 		if(session::isAdmin()){ return true; }
 		$grp=usergroup::getByName(usergroup::SHIPPERS);
@@ -61,17 +61,15 @@
 		return usergroup::userisingroup($grp['id']);
 	}
 
-    /**
-     * Gets shipments for this shipment destination.
-     * @param int $id The shipment ID.
-     * @param array $request The request parameters, e.g., pagination.
-     * @return array
-     * @throws BadRequestException
-     * @throws NotFoundException
-     * @throws ServerException
-     * @noinspection PhpUnused
-     */
-	public static function getshipments($id, $request=array()){
+	/**
+	 * Gets shipments for this shipment destination.
+	 * @param int $id The shipment ID.
+	 * @param array $request The request parameters, e.g., pagination.
+	 * @return array|null
+	 * @throws BadRequestException
+	 * @throws ServerException
+	 */
+	public static function getshipments(int $id, array $request=[]): ?array {
 	    return shipment::getByProperty('shipmentdestinationid', $id, $request);
 	}
 
@@ -84,7 +82,7 @@
      * @throws NotFoundException
      * @throws ServerException
      */
-	public static function getbeamlines($id, $request=array()){
+	public static function getbeamlines(int $id, array $request=[]): ?array {
         return beamline::getByProperty('shipmentdestinationid', $id, $request);
     }
 
@@ -92,7 +90,7 @@
      * Returns the names of all the shipment handler Javascript files.
      * @return array
      */
-	public static function getHandlerScriptNames(){
+	public static function getHandlerScriptNames(): array {
 	    $files=dir(config::getWwwRoot().'/client/js/model/shipping/handlers/');
 	    $handlers=array();
 	    while (false!==($name=$files->read())) {
@@ -111,7 +109,7 @@
      * @throws BadRequestException
      */
     public static function setHome(int $id): void {
-        database::query('UPDATE shipmentdestination SET ishome=FALSE');
+        database::query('UPDATE shipmentdestination SET ishome=FALSE WHERE ishome<>FALSE');
         database::query('UPDATE shipmentdestination SET ishome=TRUE WHERE id=:id', array(':id'=>$id));
     }
 
