@@ -8,7 +8,7 @@ class task implements crudable {
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function getAll($request=array()): ?array {
+	public static function getAll(array $request=[]): ?array {
 		$parts=array();
 		$params=array();
 		if(session::isAdmin()){
@@ -86,29 +86,32 @@ class task implements crudable {
 		throw new BadRequestException('Not implemented');
 	}
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-	public static function getById($id): ?array {
-		throw new BadRequestException('Not implemented');
-	}
-
-    /**
-     * @param $name
-     * @throws BadRequestException
-     */
-	public static function getByName($name): ?array {
+	/**
+	 * @param int $id
+	 * @return array|null
+	 * @throws BadRequestException
+	 */
+	public static function getById(int $id): ?array {
 		throw new BadRequestException('Not implemented');
 	}
 
 	/**
-	 * @param $name
-	 * @param $value
-	 * @param array $request
+	 * @param string $name
+	 * @return array|null
 	 * @throws BadRequestException
 	 */
-	public static function getByProperty($key, $value, $request=array()): ?array {
+	public static function getByName(string $name): ?array {
+		throw new BadRequestException('Not implemented');
+	}
+
+	/**
+	 * @param string $key
+	 * @param string $value
+	 * @param array $request
+	 * @return array|null
+	 * @throws BadRequestException
+	 */
+	public static function getByProperty(string $key, string $value, array $request=[]): ?array {
 		throw new BadRequestException('Not implemented');
 	}
 
@@ -118,7 +121,7 @@ class task implements crudable {
 	 * @return array|null
 	 * @throws BadRequestException
 	 */
-	public static function getByProperties(array $keyValuePairs, array $request=array()): ?array {
+	public static function getByProperties(array $keyValuePairs, array $request=[]): ?array {
 		throw new BadRequestException('Not implemented');
 	}
 
@@ -129,11 +132,12 @@ class task implements crudable {
 		throw new BadRequestException('Not implemented');
 	}
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-	public static function canUpdate($id): bool {
+	/**
+	 * @param int $id
+	 * @return bool
+	 * @throws BadRequestException
+	 */
+	public static function canUpdate(int $id): bool {
 		throw new BadRequestException('Not implemented');
 	}
 
@@ -141,24 +145,26 @@ class task implements crudable {
      * @param array $request
      * @throws BadRequestException
      */
-	public static function create($request=array()): array {
+	public static function create(array $request=[]): array {
 		throw new BadRequestException('Not implemented');
 	}
 
-    /**
-     * @param $id
-     * @param array $request
-     * @throws BadRequestException
-     */
-	public static function update($id,$request=array()): array {
+	/**
+	 * @param int $id
+	 * @param array $request
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function update(int $id, array$request=[]): array {
 		throw new BadRequestException('Not implemented');
 	}
 
-    /**
-     * @param $id
-     * @throws BadRequestException
-     */
-	public static function delete($id): array {
+	/**
+	 * @param int $id
+	 * @return array
+	 * @throws BadRequestException
+	 */
+	public static function delete(int $id): array {
 		throw new BadRequestException('Not implemented');
 	}
 	
