@@ -1,6 +1,6 @@
 <?php class welldrop extends baseobject { 
 	
-	protected static $fields=array(
+	protected static array $fields=array(
 			'name'=>validator::REQUIRED,
 			'platewellid'=>array(validator::REQUIRED, validator::INTEGER),
 			'constructid'=>validator::INTEGER,
@@ -16,7 +16,7 @@
             'latestcrystalprobabilitypercent'=>validator::FLOAT
 	);
 	
-	protected static $helpTexts=array(
+	protected static array $helpTexts=array(
 			'name'=>'A unique name for this drop',
 			'platewellid'=>'The parent well',
 			'constructid'=>'The protein construct in this drop',
@@ -25,11 +25,11 @@
             'latestcrystalprobabilitypercent'=>'The most recent probability on the most recent image'
 	);
 		
-	protected static $adminSelect='SELECT SQL_CALC_FOUND_ROWS welldrop.*, construct.name AS constructname, protein.id AS proteinid, protein.name AS proteinname
+	protected static string $adminSelect='SELECT SQL_CALC_FOUND_ROWS welldrop.*, construct.name AS constructname, protein.id AS proteinid, protein.name AS proteinname
 			FROM welldrop LEFT JOIN construct ON construct.id=welldrop.constructid LEFT JOIN protein ON protein.id=construct.proteinid
 			LEFT JOIN project ON project.id=welldrop.projectid
 			WHERE 1=1';
-	protected static $normalSelect='SELECT SQL_CALC_FOUND_ROWS welldrop.*, construct.name AS constructname, protein.id AS proteinid, protein.name AS proteinname
+	protected static string $normalSelect='SELECT SQL_CALC_FOUND_ROWS welldrop.*, construct.name AS constructname, protein.id AS proteinid, protein.name AS proteinname
 			FROM welldrop LEFT JOIN construct ON construct.id=welldrop.constructid LEFT JOIN protein ON protein.id=construct.proteinid 
 			LEFT JOIN project ON project.id=welldrop.projectid
 			WHERE 1=1';
@@ -41,7 +41,7 @@
 	 * @throws BadRequestException
 	 * @throws ServerException
 	 */
-	public static function gettimecourseimages(int $id, array $request=array()): ?array {
+	public static function gettimecourseimages(int $id, array $request=[]): ?array {
         return database::queryGetAll(dropimage::getSelectClause().' AND welldropid=:wd
                 ORDER BY imagingsession.imageddatetime ASC',
                 array(':wd'=>$id));
@@ -52,10 +52,9 @@
 	 * @param array $request The request parameters, e.g., pagination.
 	 * @return array|null
 	 * @throws BadRequestException
-	 * @throws NotFoundException
 	 * @throws ServerException
 	 */
-	public static function getcrystals(int $id, array $request=array()): ?array {
+	public static function getcrystals(int $id, array $request=[]): ?array {
 		return crystal::getByProperty('welldropid', $id, $request);
 	}
 
