@@ -7,15 +7,13 @@ if(isset($isDefaultHomepage)) {
 }
 include realpath(__DIR__).'/../_common/header.php'; ?>
 
+<!--suppress HtmlUnknownTarget -->
+<script type="text/javascript" src="homepagebricks.js"></script>
 <script type="text/javascript">
 
-//if $isDefaultHomepage set, admin is setting up new users' homepage, otherwise user is setting up own homepage
-let isDefaultHomepage=<?php echo isset($isDefaultHomepage) ? 'true' : 'false' ?>;
-let apiUrl="<?php echo isset($isDefaultHomepage) ? '/api/homepagedefaultbrick' : '/api/homepageuserbrick' ?>";
-
 let grid=ui.grid(true);
 document.getElementById("configbutton").addEventListener("click", Homepage.toggleConfig);
-Homepage.init();
+Homepage.init(<?php echo isset($isDefaultHomepage) ? 'true' : 'false' ?>);
 </script>
 
-<?php include realpath(__DIR__).'/../_common/footer.php'; ?>
\ No newline at end of file
+<?php include realpath(__DIR__).'/../_common/footer.php';
\ No newline at end of file
