@@ -1,20 +1,20 @@
 <?php $pageTitle='Create a usergroup';
 include realpath(__DIR__).'/../_common/header.php'; ?>
 <script type="text/javascript">
-document.observe("dom:loaded",function(){
+window.addEventListener('DOMContentLoaded',function(){
 
 	
 	ui.grid();
-	var detailsBox=grid.box({ 
-		classes:'r1 c1 h3 w1',
-		title:'Details'
-	});
-	var frm=detailsBox.form({
-		action:'/api/usergroup/',
-		classes:'create',
-		method:'post'
-	});
-	frm.textField({ label:"Name", name:'name' });
+    const detailsBox = grid.box({
+        classes: 'r1 c1 h3 w1',
+        title: 'Details'
+    });
+    const frm = detailsBox.form({
+        action: '/api/usergroup/',
+        classes: 'create',
+        method: 'post'
+    });
+    frm.textField({ label:"Name", name:'name' });
 	frm.textField({ label:"Description", name:'description' });
 
 	frm.dropdown({ label:'Group visibility', name:'groupvisibility',
