@@ -2,24 +2,26 @@
 $showCreateLink=session::canCreateUsergroups();
 include realpath(__DIR__).'/../_common/header.php'; ?>
 <script type="text/javascript">
-document.observe("dom:loaded",function(){
+window.addEventListener('DOMContentLoaded',function(){
 
 
-	var headers=['Name','Description'];
-	var cellTemplates=['<a href="/usergroup/{{id}}">{{name}}</a>','{{description}}'];
-	if(isAdmin){
-// 		headers=['Name','Description','Visibility','Membership','Joining','System','Create<br>Projects','Create<br>Groups'];
-// 		cellTemplates=['<a href="/usergroup/{{id}}">{{name}}</a>','{{description}}','{{groupvisibility}}','{{membershipvisibility}}','{{joining}}',[ui.checkmark,'issystem'],[ui.checkmark,'cancreateprojects'],[ui.checkmark,'cancreateusergroups'] ];
+    let headers = ['Name', 'Description'];
+    let cellTemplates = ['<a href="/usergroup/{{id}}">{{name}}</a>', '{{description}}'];
+    let showFilters=['name','description'];
+    let sortOrders=['name','description'];
+    if(isAdmin){
 		headers=['Name','Description','Visibility','Membership','System','Create<br>Projects','Create<br>Groups'];
 		cellTemplates=['<a href="/usergroup/{{id}}">{{name}}</a>','{{description}}','{{groupvisibility}}','{{membershipvisibility}}',[ui.checkmark,'issystem'],[ui.checkmark,'cancreateprojects'],[ui.checkmark,'cancreateusergroups'] ];
+        showFilters=['name','description','','','','',''];
+        sortOrders=['name','description','groupvisibility','membershipvisibility','','',''];
 	}
 	
 	ui.grid().box({ 
 		classes:'r1 c1 h3 w3',
 		url:'/api/usergroup',
 		headers:headers,
-        showFilters:['name','description','','','','',''],
-        sortOrders:['name','description','groupvisibility','membershipvisibility','','',''],
+        showFilters:showFilters,
+        sortOrders:sortOrders,
 		cellTemplates:cellTemplates
 	});
 
