@@ -1,11 +1,14 @@
 <?php $pageTitle='Create a PDB deposition';
-include realpath(__DIR__).'/../../core/_common/header.php'; 
-$sharedProject=project::getByName(project::SHARED);
+/** @noinspection PhpUnhandledExceptionInspection */
+$sharedProject=project::getByName(baseproject::SHARED);
+if(!$sharedProject){
+	throw new NotFoundException('Could not read shared project');
+}
 $sharedProjectId=$sharedProject['id'];
-?>
+include realpath(__DIR__).'/../../core/_common/header.php'; ?>
 <script type="text/javascript">
 
-document.observe("dom:loaded",function(){
+window.addEventListener('DOMContentLoaded',function(){
 	let grid=ui.grid();
 	let detailsBox=grid.box({
 		classes:'r1 c1 h3 w1',
@@ -22,4 +25,4 @@ document.observe("dom:loaded",function(){
 	
 });
 </script>
-<?php include realpath(__DIR__).'/../../core/_common/footer.php'; ?>
+<?php include realpath(__DIR__).'/../../core/_common/footer.php';
\ No newline at end of file
