@@ -1,13 +1,13 @@
 <?php $pageTitle='Plates';
+/** @noinspection PhpUnhandledExceptionInspection */
 $showCreateLink=session::isAdmin() || plate::canCreate();
 include realpath(__DIR__).'/../../core/_common/header.php'; ?>
 <script type="text/javascript">
-document.observe("dom:loaded",function(){
+window.addEventListener('DOMContentLoaded',function(){
 
-
-	var headers=['Name','Project','Description'];
-	var cellTemplates=['<a href="/plate/{{id}}">{{name}}</a>','<a href="/project/{{projectid}}">{{projectname}}</a>','{{description}}'];
-	ui.grid().box({ 
+    const headers = ['Name', 'Project', 'Description'];
+    const cellTemplates = ['<a href="/plate/{{id}}">{{name}}</a>', [Project.getLink,'name'], '{{description}}'];
+    ui.grid().box({
 		classes:'r1 c1 h3 w3',
 		url:'/api/plate?sortby=id&sortdescending=yes',
 		headers:headers,
@@ -16,7 +16,6 @@ document.observe("dom:loaded",function(){
 		cellTemplates:cellTemplates
 	});
 
-
 });
 </script>
-<?php include realpath(__DIR__).'/../../core/_common/footer.php'; ?>
\ No newline at end of file
+<?php include realpath(__DIR__).'/../../core/_common/footer.php';
\ No newline at end of file
