@@ -1,11 +1,9 @@
 <?php $pageTitle='Wells';
 include realpath(__DIR__).'/../../core/_common/header.php'; ?>
 <script type="text/javascript">
-document.observe("dom:loaded",function(){
+window.addEventListener('DOMContentLoaded',function(){
 
-	ui.grid();
-
-	grid.box({ 
+	ui.grid().box({
 		classes:'r1 c2 h1 w1',
 		title:'Plates',
 		content:'Manage wells and drops through the plate page.'
@@ -13,6 +11,4 @@ document.observe("dom:loaded",function(){
 	
 });
 </script>
-<?php 
-include realpath(__DIR__).'/../../core/_common/footer.php';
-?>
\ No newline at end of file
+<?php include realpath(__DIR__).'/../../core/_common/footer.php';
\ No newline at end of file
