@@ -10,7 +10,7 @@ let projectExtensions={
 			id:'before', 
 			label:'Before', 
 			url:'/api/project/'+data['id']+'/permission', 
-			successHandler:function(){ $("before").next().innerHTML="Tab before default project tabs"; }
+			successHandler:function(){ document.getElementById("before").nextElementSibling().innerHTML="Tab before default project tabs"; }
 		 });
 		*/
 		tabSet.tab({ 
@@ -26,14 +26,17 @@ let projectExtensions={
 			label:'Proteins', 
 			url:'/api/project/'+data['id']+'/protein', 
 			successHandler:function(transport){ projectExtensions.writeProteins(transport.responseJSON.rows);  },
-			failureHandler:function(){ $("proteins_body").innerHTML=""; projectExtensions.writeProteinCreateForm();  }
+			failureHandler:function(){ document.getElementById("proteins_body").innerHTML=""; projectExtensions.writeProteinCreateForm();  }
 		});
 		tabSet.tab({ 
 			id:'crystals', 
-			label:'Crystals', 
-			url:'/api/crystal/projectid/'+data['id']+'?sortby=id&sortdescending=yes', 
-			headers:['Image','Plate','Drop and number'],
-			cellTemplates:[ [Crystal.getThumbnailLink,'id'], '<a href="/plate/{{plateid}}">{{platename}}</a>',  [Crystal.getTextLink,'id'] ],
+			label:'Crystals',
+			url:'/api/crystal/projectid/'+data['id'],
+			sortBy:'id',
+			sortDescending:true,
+			sortOrders: ['-starrating','','',''],
+			headers:['Rating','Image','Plate','Drop and number'],
+			cellTemplates:[ [ui.starRatingCellContents,'starrating'], [Crystal.getThumbnailLink,'id'], '<a href="/plate/{{plateid}}">{{platename}}</a>',  [Crystal.getTextLink,'id'] ],
 		});
 		Dataset.listTab(tabSet, 'projectid', data['id']);
 	},
@@ -48,7 +51,7 @@ let projectExtensions={
 			id:'after', 
 			label:'After', 
 			url:'/api/project/'+data['id']+'/permission', 
-			successHandler:function(){ $("after").next().innerHTML="Tab after default project tabs"; }
+			successHandler:function(){ document.getElementById("after").nextElementSibling().innerHTML="Tab after default project tabs"; }
 		 });
 		*/
 	},
@@ -57,40 +60,73 @@ let projectExtensions={
 		let maxLength=50;
 		let desc=item.description;
 		if(desc.length<=maxLength){ return desc; }
-		desc=desc.substr(0,maxLength-3);
+		desc=desc.substring(0,maxLength-3);
 		let lastSpace=desc.lastIndexOf(" ");
 		if(0<lastSpace){
-			desc=desc.substr(0,lastSpace);
+			desc=desc.substring(0,lastSpace);
 		}
 		return desc+'...';
 	},
 
 	
 	writeProteins:function(rows, proteinIdToOpen, constructIdToOpen){
-		let tab=$("proteins_body");
+		let tab=document.getElementById("proteins_body");
 		tab.innerHTML='';
-		rows.each(function(r){
-			tab.treeItem({
+		rows.forEach(function(r){
+			let ti=tab.treeItem({
 				record:r,
 				id:"protein"+r.id,
-				header:r.name+" (Acronym: "+r.proteinacronym+")",
-				updater:projectExtensions.renderProtein
+				header:projectExtensions.proteinHeader(r.name, r.proteinacronym),
+				updater:function(){ projectExtensions.renderProtein(ti, constructIdToOpen); }
 			});
 			if(1*r.id===1*proteinIdToOpen){
-				ui.doToggleTreeItem($('protein'+r.id));
+				ui.doToggleTreeItem(document.getElementById('protein'+r.id));
 			}
 		});
 		projectExtensions.writeProteinCreateForm();
+		window.setInterval(projectExtensions.setProteinTabWarning, 250);
 	},
+
+	setProteinTabWarning:function (){
+		let tb=document.getElementById("proteins_body");
+		let warnings=tb.querySelectorAll("img.proteinAcronymWarning");
+		numWarnings=warnings.length;
+		if(numWarnings>0){
+			let msg="Protein acronym is not set, for "+numWarnings+" protein";
+			if(1!==numWarnings){ msg+="s"; }
+			tb.warn(msg);
+		} else {
+			tb.unwarn();
+		}
+	},
+
+	proteinHeader:function(name, acronym, treeHeaderOrItem){
+		let content=name+" (Acronym: ";
+		if(acronym) {
+			content+=acronym;
+		} else {
+			content+='<img class="proteinAcronymWarning" alt="" src="/'+'images/icons/darkicons/warning.png" style="height:1.75em;vertical-align: middle;position: relative;top: -.15em;">NOT SET';
+		}
+		content+=")";
+		if(treeHeaderOrItem){
+			if(!treeHeaderOrItem.classList.contains("treehead")){
+				treeHeaderOrItem=treeHeaderOrItem.querySelector(".treehead");
+			}
+			content=content='<span class="toggleitem"></span>'+content;
+			treeHeaderOrItem.innerHTML=content;
+		}
+		return content;
+	},
+
 	renderProtein:function(treeHeader,constructIdToOpen){
-		let ti=treeHeader.up(".treeitem");
-		let tb=ti.down(".treebody");
+		let ti=treeHeader.closest(".treeitem");
+		let tb=ti.querySelector(".treebody");
 		tb.innerHTML='';
 		let protein=ti.record;
-		let f=ti.form({
+		let f=ui.form({
 			action:"/api/protein/"+protein['id'],
 			method:"patch"
-		});
+		}, tb);
 		f.hiddenField('projectid',data['id']);
 		if(canEdit){
 			let nameField=f.textField({
@@ -105,11 +141,13 @@ let projectExtensions={
 				value:protein['proteinacronym'],
 				helpText:'Short code, 3-5 characters. Identifies the protein for synchrotron safety purposes'
 			});
-			nameField.observe("keyup",function(){
-				ti.down("h3").innerHTML='<span class="toggleitem"></span>'+nameField.down("input").value+' (Acronym: '+acronymField.down("input").value+')';
+			nameField.addEventListener("keyup",function(){
+				projectExtensions.proteinHeader(nameField.querySelector("input").value, acronymField.querySelector("input").value, ti);
+//				ti.querySelector("h3").innerHTML='<span class="toggleitem"></span>'+nameField.querySelector("input").value+' (Acronym: '+acronymField.querySelector("input").value+')';
 			});
-			acronymField.observe("keyup",function(){
-				ti.down("h3").innerHTML='<span class="toggleitem"></span>'+nameField.down("input").value+' (Acronym: '+acronymField.down("input").value+')';
+			acronymField.addEventListener("keyup",function(){
+				projectExtensions.proteinHeader(nameField.querySelector("input").value, acronymField.querySelector("input").value, ti);
+//				ti.querySelector("h3").innerHTML='<span class="toggleitem"></span>'+nameField.querySelector("input").value+' (Acronym: '+acronymField.querySelector("input").value+')';
 			});
 
 		}
@@ -122,14 +160,14 @@ let projectExtensions={
 			readOnly:!canEdit
 		});
 		
-		new Ajax.Request('/api/protein/'+protein['id']+'/construct',{
+		new AjaxUtils.Request('/api/protein/'+protein['id']+'/construct',{
 			method:"get",
 			onSuccess:function(transport){ projectExtensions.writeConstructs(transport,constructIdToOpen); },
 			onFailure:function(){ projectExtensions.writeConstructCreateForm(tb); },
 		});
 	},
 	writeProteinCreateForm:function(){
-		let tab=$("proteins_body");
+		let tab=document.getElementById("proteins_body");
 		if(canEdit){
 			let createItem=tab.treeItem({
 				header:'Create a new protein'
@@ -156,7 +194,7 @@ let projectExtensions={
 			});
 			f.createButton({
 				afterSuccess:function(createResponse){
-					new Ajax.Request('/api/project/'+data.id+'/protein',{
+					new AjaxUtils.Request('/api/project/'+data.id+'/protein',{
 						method:'get',
 						onSuccess:function(transport){
 							projectExtensions.writeProteins(transport.responseJSON.rows, createResponse.created.id);
@@ -165,22 +203,22 @@ let projectExtensions={
 				}
 			});
 			f.formField({
-				label:'<img alt="" style="vertical-align: bottom" src="/images/icons/darkicons/warning.png"> Please note!',
+				label:'<img alt="" style="vertical-align: bottom" s'+'rc="/images/icons/darkicons/warning.png"> Please note!',
 				name:'',
 				content:'<div style="width:80%;float:right;text-align:left;line-height:1.5em">The protein acronym is used when shipping your crystals to the synchrotron, to identify the ' +
 					'protein for safety purposes. It should be <b>very short</b> (ideally 3-5 characters), contain <b>no ' +
 					'spaces</b> or special characters, and <b>must match exactly</b> the protein acronym in the ' +
 					'synchrotron\'s safety system at time of shipping. Mismatched acronyms will prevent your crystals from being shipped.</div>'
 			});
-			f.up(".treeitem").addClassName("noprint");
+			f.closest(".treeitem").classList.add("noprint");
 		}
 	},
 	
 	
 	writeConstructs:function(transport,constructIdToOpen){
 		let wrapper;
-		transport.responseJSON.rows.each(function(r){
-			wrapper=$("protein"+r['proteinid']+"_body");
+		transport.responseJSON.rows.forEach(function(r){
+			wrapper=document.getElementById("protein"+r['proteinid']+"_body");
 			wrapper.treeItem({
 				record:r,
 				id:"construct"+r.id,
@@ -188,20 +226,20 @@ let projectExtensions={
 				updater:projectExtensions.renderConstruct
 			});
 			if(1*r.id===1*constructIdToOpen){
-				ui.doToggleTreeItem($("construct"+r.id));
+				ui.doToggleTreeItem(document.getElementById("construct"+r.id));
 			}
 		});
 		projectExtensions.writeConstructCreateForm(wrapper);
 	},
 	renderConstruct:function(treeHeader){
-		let ti=treeHeader.up(".treeitem");
-		let tb=ti.down(".treebody");
+		let ti=treeHeader.closest(".treeitem");
+		let tb=ti.querySelector(".treebody");
 		tb.innerHTML='';
 		let con=ti.record;
-		let f=ti.form({
+		let f=ui.form({
 			action:"/api/construct/"+con['id'],
 			method:"patch"
-		});
+		}, tb);
 		f.hiddenField('constructid',con['id']);
 		if(canEdit){
 			let nameField=f.textField({
@@ -210,8 +248,8 @@ let projectExtensions={
 				value:con['name'],
 				helpText:'Construct name must be unique within this protein',
 			});
-			nameField.observe("keyup",function(){
-				ti.down("h3").innerHTML='<span class="toggleitem"></span>Construct: '+nameField.down("input").value;
+			nameField.addEventListener("keyup",function(){
+				ti.querySelector("h3").innerHTML='<span class="toggleitem"></span>Construct: '+nameField.querySelector("input").value;
 			});
 		}
 		f.textField({
@@ -225,16 +263,16 @@ let projectExtensions={
 	},
 	writeConstructCreateForm:function(wrapper){
 		if(canEdit){
-			let createitem=wrapper.treeItem({
+			let createItem=wrapper.treeItem({
 				header:'Create a new construct'
 			});
-			f=createitem.form({
+			let f=createItem.form({
 				action:"/api/construct",
 				method:"post"
 			});
-			let prot=wrapper.up(".treeitem").record;
+			let protein=wrapper.closest(".treeitem").record;
 			f.hiddenField('projectid',data['id']); 
-			f.hiddenField('proteinid',prot['id']); 
+			f.hiddenField('proteinid',protein['id']);
 			f.textField({
 				label:'Name',
 				name:'name',
@@ -247,10 +285,10 @@ let projectExtensions={
 			});
 			f.createButton({
 				afterSuccess:function(createResponse){
-					new Ajax.Request('/api/project/'+data.id+'/protein',{
+					new AjaxUtils.Request('/api/project/'+data["id"]+'/protein',{
 						method:'get',
 						onSuccess:function(transport){
-							projectExtensions.writeProteins(transport.responseJSON.rows, prot['id'], createResponse.created.id);
+							projectExtensions.writeProteins(transport.responseJSON.rows, protein['id'], createResponse.created.id);
 						}
 					})
 				}
@@ -259,7 +297,7 @@ let projectExtensions={
 	},
 	
 	getSequences:function(constructId){
-		new Ajax.Request('/api/construct/'+constructId+'/sequence',{
+		new AjaxUtils.Request('/api/construct/'+constructId+'/sequence',{
 			method:'get',
 			onSuccess:function(transport){ projectExtensions.getSequences_onSuccess(transport, constructId); },
 			onFailure:function(transport){ projectExtensions.getSequences_onFailure(transport, constructId); },
@@ -277,12 +315,12 @@ let projectExtensions={
 		}
 	},
 	renderSequences:function(sequences, constructId){
-		sequences.each(function(seq){
+		sequences.forEach(function(seq){
 			let f=projectExtensions.generateSequenceBlock(seq);
-			$("construct"+seq.constructid+"_body").appendChild(f);
+			document.getElementById("construct"+seq.constructid+"_body").appendChild(f);
 		});
 		if(canEdit){
-			let f=$("construct"+constructId+"_body").form({
+			let f=document.getElementById("construct"+constructId+"_body").form({
 				action:'/api/sequence/',
 				method:'post',
 				id:"construct"+constructId+"addseqform"
@@ -294,7 +332,7 @@ let projectExtensions={
 			});
 			ff.innerHTML+='&nbsp;';
 			ff.sequence={};
-			ff.down("input").dataset.constructid=constructId;
+			ff.querySelector("input").dataset.constructid=constructId;
 		}
 	},
 
@@ -318,7 +356,7 @@ let projectExtensions={
 			deleteButton='<input type="button" onclick="projectExtensions.deleteSequence(this)" value="Delete" />';
 		}
 		ff.innerHTML+=('<span class="seqpreview">'+seqToShow+"</span><br/>"+viewButton+deleteButton);
-		ff.down("input").dataset.constructid=seq.constructid;
+		ff.querySelector("input").dataset.constructid=seq.constructid;
 		return f;
 	},
 	
@@ -329,24 +367,23 @@ let projectExtensions={
 		if(""!==seq.proteinsequence){ seqToShow=seq.proteinsequence; }
 		if(""===seqToShow){ return "(no DNA or protein sequence)"; }
 		if(seqToShow.length>projectExtensions.sequencePreviewLength){
-			return seqToShow.substr(0,projectExtensions.sequencePreviewLength).toUpperCase()+"...";
+			return seqToShow.substring(0,projectExtensions.sequencePreviewLength).toUpperCase()+"...";
 		}
 		return seqToShow.toUpperCase();
 	},
 	
 	showSequenceWindow:function(btn){
-		let seq=btn.up("label").sequence;
+		let seq=btn.closest("label").sequence;
 		let seqName=seq.name||"";
 		let dnaSeq=seq.dnasequence||"";
 		let proteinSequence=seq.proteinsequence||"";
 		let formAction=seq.id ? '/api/sequence/'+seq.id : '/api/sequence/';
 		let formMethod=seq.id ? 'patch' : 'post';
-		let formClasses=seq.id ? '' : 'create';
 		let boxTitle=seq.name ? 'Sequence: '+seq.name : 'Add a sequence';
 		let buttonLabel=seq.id ? 'Save changes' : 'Add sequence';
 		let buttonAction=projectExtensions.submitSequenceForm;
 		let mb=ui.modalBox({ title:boxTitle, content:'', confirmClose:true });
-		let f=modalBox.form({
+		let f=mb.form({
 			id:'sequenceform',
 			action:formAction,
 			method:formMethod,
@@ -386,42 +423,42 @@ let projectExtensions={
 			fieldValidations['seqname']="required";
 			fieldValidations['dnasequence']="dnaSequence";
 			fieldValidations['proteinsequence']="proteinSequence";
-			$$("#modalBox textarea, #modalBox input[type=text]").each(function(elem){ 
-				elem.onkeyup=function(){ $("modalBox").tainted=true; }; 
+			document.querySelectorAll("#modalBox textarea, #modalBox input[type=text]").forEach(function(elem){
+				elem.onkeyup=function(){ document.getElementById("modalBox").tainted=true; };
 				elem.style.width="70%"; 
 			});
-			$$("#modalBox textarea").each(function(elem){ 
+			document.querySelectorAll("#modalBox textarea").forEach(function(elem){
 				elem.style.height="10em"; 
-				elem.onclick=function(){ $("modalBox").tainted=true; }; 
+				elem.onclick=function(){ document.getElementById("modalBox").tainted=true; };
 			});
-			let psBox=$("proteinsequence");
-			let dsBox=$("dnasequence");
-			psBox.observe("keyup",projectExtensions.onEditProteinSequence);
-			psBox.observe("click",projectExtensions.onEditProteinSequence);
-			dsBox.observe("keyup",projectExtensions.onEditDnaSequence);
-			dsBox.observe("click",projectExtensions.onEditDnaSequence);
+			let psBox=document.getElementById("proteinsequence");
+			let dsBox=document.getElementById("dnasequence");
+			psBox.addEventListener("keyup",projectExtensions.onEditProteinSequence);
+			psBox.addEventListener("click",projectExtensions.onEditProteinSequence);
+			dsBox.addEventListener("keyup",projectExtensions.onEditDnaSequence);
+			dsBox.addEventListener("click",projectExtensions.onEditDnaSequence);
 		}
 	},
 
 	onEditProteinSequence:function(){
-		let psBox=$("proteinsequence");
+		let psBox=document.getElementById("proteinsequence");
 		let seq=psBox.value+"";
-		seq=seq.replace(/[^\*ACDEFGHIKLMNPQRSTVWY]/gi, "").toUpperCase();
+		seq=seq.replace(/[^*ACDEFGHIKLMNPQRSTVWY]/gi, "").toUpperCase();
 		if(""===seq){ return; }
 		psBox.value=Protein.formatProteinSequence(seq);
 	},
 		
 	onEditDnaSequence:function(){
-		let dsBox=$("dnasequence");
+		let dsBox=document.getElementById("dnasequence");
 		let seq=dsBox.value+"";
-		seq=seq.replace(/[^\*ACGT]/gi, "").toUpperCase();
+		seq=seq.replace(/[^*ACGT]/gi, "").toUpperCase();
 		if(""===seq){ return; }
 		dsBox.value=Protein.formatDnaSequence(seq);
 	},
 
 	dnaMatchesProtein:function(){
-		let dnaSequence=$("dnasequence").value.replace(/\s/g,"");
-		let proteinSequence=$("proteinsequence").value.replace(/\s/g,"");
+		let dnaSequence=document.getElementById("dnasequence").value.replace(/\s/g,"");
+		let proteinSequence=document.getElementById("proteinsequence").value.replace(/\s/g,"");
 		if(""===proteinSequence || ""===dnaSequence){ return true; }
 		if(proteinSequence.length*3 !== dnaSequence.length){ return false; }
 		let convertedDna=Protein.dnaToProtein(dnaSequence);
@@ -429,10 +466,10 @@ let projectExtensions={
 	},
 	
 	submitSequenceForm:function(){
-		let sequenceForm=$('sequenceform');
-		let proteinSequenceBox=$('proteinsequence');
-		let dnaSequenceBox=$('dnasequence');
-		let isValid=validator.validate($('seqname'));
+		let sequenceForm=document.getElementById('sequenceform');
+		let proteinSequenceBox=document.getElementById('proteinsequence');
+		let dnaSequenceBox=document.getElementById('dnasequence');
+		let isValid=validator.validate(document.getElementById('seqname'));
 		isValid=validator.validate(proteinSequenceBox) && isValid;
 		isValid=validator.validate(dnaSequenceBox) && isValid;
 		if(!isValid){ return false;	}
@@ -440,23 +477,23 @@ let projectExtensions={
 			if(!confirm("DNA and protein sequences do not match.\n\nClick OK to generate the protein sequence from the DNA sequence.\nClick Cancel to edit by hand.")){
 				return false;
 			}
-			$("proteinsequence").value=Protein.dnaToProtein($("dnasequence").value);
+			document.getElementById("proteinsequence").value=Protein.dnaToProtein(document.getElementById("dnasequence").value);
 		} else if(""===proteinSequenceBox.value && ""!==dnaSequenceBox.value){
 			if(confirm("The protein sequence is empty.\n\nClick OK to generate the protein sequence from the DNA sequence.\nClick Cancel to leave it empty.")){
-				$("proteinsequence").value=Protein.formatProteinSequence(Protein.dnaToProtein($("dnasequence").value));
+				document.getElementById("proteinsequence").value=Protein.formatProteinSequence(Protein.dnaToProtein(document.getElementById("dnasequence").value));
 			}
 		}
-		$("seqsubmit").up("label").addClassName("updating");
+		document.getElementById("seqsubmit").closest("label").classList.add("updating");
 		let method="post";
 		if("post"!==sequenceForm.dataset.ajaxmethod){ method="patch"; }
-		new Ajax.Request(sequenceForm.action,{
+		new AjaxUtils.Request(sequenceForm.action,{
 			method:method,
 			parameters:{
 				csrfToken:csrfToken,
-				name:$("seqname").value,
+				name:document.getElementById("seqname").value,
 				dnasequence:dnaSequenceBox.value,
 				proteinsequence:proteinSequenceBox.value,
-				constructid:$("seqconstructid").value,
+				constructid:document.getElementById("seqconstructid").value,
 			},
 			onSuccess:projectExtensions.submitSequenceForm_onSuccess,
 			onFailure:projectExtensions.submitSequenceForm_onFailure,
@@ -464,24 +501,24 @@ let projectExtensions={
 		
 	},
 	submitSequenceForm_onSuccess:function(transport){
-		$("seqsubmit").up("label").removeClassName("updating");
+		document.getElementById("seqsubmit").closest("label").classList.remove("updating");
 		if(!AjaxUtils.checkResponse(transport)){ return false; }
-		let updated=transport.responseJSON.updated;
-		let created=transport.responseJSON.created;
+		let updated=transport.responseJSON["updated"];
+		let created=transport.responseJSON["created"];
 		if(updated){
-			let seqBox=$("seq"+updated.id);
-			seqBox.down(".label").innerHTML="Sequence: "+updated.name;
-			seqBox.down(".seqpreview").innerHTML=projectExtensions.generateSequencePreviewString(updated);
-			seqBox.down("label").sequence=updated;
+			let seqBox=document.getElementById("seq"+updated.id);
+			seqBox.querySelector(".label").innerHTML="Sequence: "+updated.name;
+			seqBox.querySelector(".seqpreview").innerHTML=projectExtensions.generateSequencePreviewString(updated);
+			seqBox.querySelector("label")["sequence"]=updated;
 		} else if(created){
 			let f=projectExtensions.generateSequenceBlock(created);
-			$("construct"+created.constructid+"addseqform").insert({before:f});	
+			document.getElementById("construct"+created.constructid+"addseqform").prepend(f);
 		}
-		$("modalBox").tainted=false;
+		document.getElementById("modalBox").tainted=false;
 		ui.closeModalBox();
 	},
 	submitSequenceForm_onFailure:function(transport){
-		$("seqsubmit").up("label").removeClassName("updating");
+		document.getElementById("seqsubmit").closest("label").classList.remove("updating");
 		AjaxUtils.checkResponse(transport);
 	},
 
@@ -490,10 +527,10 @@ let projectExtensions={
 			alert("You don't have permission to delete sequences");
 			return false;
 		}
-		let frm=$(elem).up("form");
-		elem.up("label").addClassName("updating");
+		let frm=document.getElementById(elem).closest("form");
+		elem.closest("label").classList.add("updating");
 		window.setTimeout(function(){
-			new Ajax.Request(frm.action, {
+			new AjaxUtils.Request(frm.action, {
 				method:'delete',
 				parameters:{ csrfToken:csrfToken },
 				onSuccess:projectExtensions.deleteSequence_onSuccess,
@@ -504,10 +541,10 @@ let projectExtensions={
 	deleteSequence_onSuccess:function(transport){
 		if(!AjaxUtils.checkResponse(transport)){ return false; }
 		let deletedId=transport.responseJSON['deleted'];
-		$("seq"+deletedId).remove();
+		document.getElementById("seq"+deletedId).remove();
 	},
 	deleteSequence_onFailure:function(transport){
-		$("seqsubmit").up("label").removeClassName("updating");
+		document.getElementById("seqsubmit").closest("label").classList.remove("updating");
 		AjaxUtils.checkResponse(transport);
 		
 	},
