@@ -1,15 +1,15 @@
 <?php $pageTitle='Sequences';
 include realpath(__DIR__).'/../../core/_common/header.php'; ?>
 <script type="text/javascript">
-document.observe("dom:loaded",function(){
+window.addEventListener('DOMContentLoaded',function(){
 
 
-	var headers=['Name','Project'];
-	var cellTemplates=['<a href="/sequence/{{id}}">{{name}}</a>','<a href="/project/{{projectid}}">{{projectname}}</a>'];
+    const headers = ['Name', 'Project'];
+    const cellTemplates = ['<a href="/sequence/{{id}}">{{name}}</a>', [Project.getLink,'name'] ];
 
-	var grid=ui.grid();
+    const grid = ui.grid();
 
-	var infoBox=grid.box({ 
+    grid.box({
 		classes:'r1 c1 h1 w3',
 		content:'This is only for testing and development. Go to the project page for a better way to work with proteins, constructs and sequences.'
 	});
@@ -24,4 +24,4 @@ document.observe("dom:loaded",function(){
 
 });
 </script>
-<?php include realpath(__DIR__).'/../../core/_common/footer.php'; ?>
\ No newline at end of file
+<?php include realpath(__DIR__).'/../../core/_common/footer.php';
\ No newline at end of file
