@@ -1,12 +1,9 @@
 <?php $pageTitle='Create a drop';
 include realpath(__DIR__).'/../../core/_common/header.php'; ?>
 <script type="text/javascript">
+window.addEventListener('DOMContentLoaded',function(){
 
-document.observe("dom:loaded",function(){
-
-	ui.grid();
-
-	grid.box({ 
+	ui.grid().box({
 		classes:'r1 c2 h1 w1',
 		title:'Plates',
 		content:'Manage wells and drops through the plate page.'
@@ -17,5 +14,4 @@ document.observe("dom:loaded",function(){
 
 </script>
 <?php 
-include realpath(__DIR__).'/../../core/_common/footer.php';
-?>
\ No newline at end of file
+include realpath(__DIR__).'/../../core/_common/footer.php';
\ No newline at end of file
