@@ -1214,12 +1214,12 @@ function handleErrorCondition($errorName, $errorMessage, $config){
 }
 
 /**
- * @param $path
- * @param $regex
+ * @param string $path
+ * @param string $regex
  * @return int[]|string[]
  * @throws Exception
  */
-function getDirectoryListingSortedLastModifiedDescending($path, $regex='/.*/'){
+function getDirectoryListingSortedLastModifiedDescending(string $path, string $regex='/.*/'): array {
     Logger::debug('In getDirectoryListingSortedLastModifiedDescending');
     Logger::debug('$path='.$path);
     Logger::debug('$regex='.$regex);
